@@ -12,15 +12,15 @@
 
 #include "config.h"
 #include <stdio.h>
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_audio/ADM_dcainfo.h"
+
 extern "C"
 {
-#include "ADM_lavutil/common.h"
-#include "ADM_lavutil/bswap.h"
-#include "ADM_lavcodec/bitstream.h"
-
+#define INT_BIT (CHAR_BIT * sizeof(int))
+#include "libavcodec/get_bits.h"
 }
+
 #include "ADM_assert.h"
 
 /*
@@ -102,8 +102,13 @@ uint32_t size,len1,len2,flags,sr,framesize=0,index,nbBlocks;
 #endif
                 *syncoff=cur-buf;
                 if(*syncoff) printf("[dts] Dropped %u bytes\n",*syncoff);
-                *chan=dts_channels[flags & 0xf];
-//                if(*chan==5 && (flags & 0X80)) *chan++;
+                get_bits(&s,10);
+                int lfe=get_bits(&s,2);
+                int c;
+                c=dts_channels[flags & 0xf];
+                if(c==5 && lfe) c++; // LFE
+                *chan=c;
+
                 *nbSample=nbBlocks*32;
                 return framesize;
                 
