@@ -17,16 +17,17 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
 #include <math.h>
 
 #include "config.h"
+#include "ADM_assert.h"
 
 #include "fourcc.h"
 #include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiocodec/ADM_audiocodec.h"
-#include "ADM_audiofilter/audiofilter_channel_route.h"
-#include "ADM_libraries/ADM_libwrapper/libwrapper_global.h"
+
+
+extern ADM_Audiocodec *ADM_ad_searchCodec(uint32_t fourcc,	WAVHeader *info,uint32_t extraLength,uint8_t *extraData);
 
 ADM_Audiocodec	*getAudioCodec(uint32_t fourcc,WAVHeader *info,uint32_t extra,uint8_t *extraData)
 {
@@ -64,16 +65,6 @@ ADM_Audiocodec *out = NULL;
 					out= (ADM_Audiocodec *)new ADM_AudiocodecWav(fourcc);
 #endif					
                   			break;
-#ifdef USE_AMR_NB
-				case WAV_AMRNB:
-					if (amrnb->isAvailable())
-					{
-						printf("\n AMR narrow band codec\n");
-						out=(ADM_Audiocodec *)new ADM_AudiocodecAMR(fourcc,info);
-					}
-
-					break;
-#endif
 				case WAV_8BITS:
 					printf("\n 8 BIts pseudo codec\n");
     					out= (ADM_Audiocodec *)new ADM_Audiocodec8Bits(fourcc);
@@ -90,53 +81,20 @@ ADM_Audiocodec *out = NULL;
 					out= (ADM_Audiocodec *)new ADM_AudiocodecWav(fourcc);
 #endif					
                   		break;
-#ifdef USE_AC3
-				case WAV_AC3:
-        				printf("\n Audio codec:  AC3\n");
-
-					out= (ADM_Audiocodec *) new ADM_AudiocodecAC3(fourcc, info);
-                  break;
-#endif
-#ifdef USE_LIBDCA
                 case WAV_DTS:
+#ifdef USE_LIBDCA
 					if (dca->isAvailable())
 					{
-						printf("\n Audio codec:  DTS\n");
+						printf("\n Audio codec:  DTS (libdca)\n");
 						out= (ADM_Audiocodec *) new ADM_AudiocodecDCA(fourcc, info);						
 					}
+#else
+					printf("\n Audio codec:  DTS (avcodec)\n");
+					out= (ADM_Audiocodec *)new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
+#endif
 
 					break;
-#endif
-#ifdef USE_MP3
-				case WAV_MP3:
-				case WAV_MP2:
-        				printf("\n Audio codec:  MP2-3\n");
 
-					out= (ADM_Audiocodec *) new ADM_AudiocodecMP3(fourcc);
-                  break;
-#endif
-#ifdef USE_VORBIS
-				case WAV_OGG:
-						printf("\n Ogg/Vorbis \n");
-						out= (ADM_Audiocodec *) new ADM_vorbis(fourcc,info,
-								extra,extraData);
-						break;
-#endif		
-#ifdef USE_FAAD
-                                case WAV_AAC_HE:
-						printf("\n MP4 audio (HE)\n");
-						out= (ADM_Audiocodec *) new ADM_faad(fourcc,1,info,
-								extra,extraData);
-						break;
-
-				case WAV_AAC:
-				case WAV_MP4:
-                                case 0x706D:  // Weird fourcc/id code used by mencoder
-						printf("\n MP4 audio \n");
-						out= (ADM_Audiocodec *) new ADM_faad(fourcc,0,info,
-								extra,extraData);
-						break;
-#endif
 				case WAV_ULAW:
 						printf("\n ULAW codec\n");
 						out=(ADM_Audiocodec *) new ADM_AudiocodecUlaw(fourcc,info);
@@ -154,6 +112,8 @@ ADM_Audiocodec *out = NULL;
                 printf("\n Audio codec:  ffQDM2\n");
                 out= (ADM_Audiocodec *) new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
                 break;
+            default:
+            	out= ADM_ad_searchCodec(fourcc,info,extra,extraData);
         	}
 
 	if (out == NULL)
@@ -161,23 +121,19 @@ ADM_Audiocodec *out = NULL;
 		printf("\n Unknown codec : %lu",fourcc);
 		out = (ADM_Audiocodec *) new ADM_AudiocodecUnknown(fourcc);
 	}
-        if(info->channels==1)
-        {
-            ch_route.input_type[0] = CH_MONO;
-        }else
-        {
-	   ch_route.input_type[0] = CH_FRONT_LEFT;
-	   ch_route.input_type[1] = CH_FRONT_RIGHT;
-        }
-
+	// For channel mapping, simple case we do it here so that the decoder does not have
+	// to worry.
+	// For more complicated case (channel >2) , it is up to the decoder to do it...
+	switch(info->channels)
+	{
+			case 1: out->channelMapping[0] = CHTYP_MONO;
+					break;
+			case 2: out->channelMapping[0] = CHTYP_FRONT_LEFT;
+					out->channelMapping[1] = CHTYP_FRONT_RIGHT;
+					break;
+			default:break;
+	
+	
+	}
 	return out;
 }
-
-ADM_Audiocodec::ADM_Audiocodec( uint32_t fourcc ) {
-    UNUSED_ARG(fourcc);
-	_init=0;
-}
-
-ADM_Audiocodec::~ADM_Audiocodec()
-{}
-
