@@ -19,18 +19,17 @@
  ***************************************************************************/
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 
 #include "ADM_assert.h"
 #include "prefs.h"
+extern "C" {
 #include "ADM_lavcodec.h"
-#include "ADM_utilities/default.h"
+}
+#include "ADM_default.h"
 
 #include "ADM_codecs/ADM_codec.h"
 #include "ADM_codecs/ADM_ffmp43.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "DIA_coreToolkit.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME  MODULE_CODEC
@@ -42,14 +41,14 @@ extern int ADM_cpu_num_processors(void);
 #define WRAP_Open(x) \
 {\
 AVCodec *codec=avcodec_find_decoder(x);\
-if(!codec) {GUI_Alert(QT_TR_NOOP("Internal error finding codec '"#x"'"));ADM_assert(0);} \
+if(!codec) {GUI_Error_HIG("Codec",QT_TR_NOOP("Internal error finding codec"#x));ADM_assert(0);} \
   codecId=x; \
   _context->workaround_bugs=1*FF_BUG_AUTODETECT +0*FF_BUG_NO_PADDING;/**/ \
   _context->error_concealment=3; \
   if (avcodec_open(_context, codec) < 0)  \
                       { \
                                         printf("[lavc] Decoder init: "#x" video decoder failed!\n"); \
-                                        GUI_Alert("Internal error opening "#x); \
+                                        GUI_Error_HIG("Codec","Internal error opening "#x); \
                                         ADM_assert(0); \
                                 } \
                                 else \
@@ -206,7 +205,7 @@ decoderFF::decoderFF (uint32_t w, uint32_t h):decoders (w, h)
 
   _context->width = _w;
   _context->height = _h;
-  _context->pix_fmt = PIX_FMT_YUV420P;	//PIX_FMT_RGBA32
+  _context->pix_fmt = PIX_FMT_YUV420P;
   //_context->debug=1;
 
   _internalBuffer = new uint8_t[w * h * 3];
@@ -329,7 +328,7 @@ uint8_t   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
       printf ("\n[lavc] null frame\n");
       {
 	// search the last image
-	if (_context->coded_frame && _context->coded_frame->data)
+	if (_context->coded_frame && _context->coded_frame->data && _context->coded_frame->linesize[0])
 	  {
 	    clonePic (_context->coded_frame, out);
 	  }
@@ -412,6 +411,7 @@ uint8_t   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
 
     case PIX_FMT_YUV420P:
     case PIX_FMT_YUVJ420P:
+    case PIX_FMT_YUVA420P:
       // Default is YV12 or I420
       // In that case depending on swap u/v
       // we do it or not
@@ -423,7 +423,7 @@ uint8_t   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
 	case PIX_FMT_RGB24:
 	  out->_colorspace = ADM_COLOR_RGB24;
 	  break;
-    case PIX_FMT_RGBA32:
+    case PIX_FMT_RGB32:
       out->_colorspace = ADM_COLOR_RGB32A;
       break;
     case PIX_FMT_RGB555:
@@ -554,13 +554,6 @@ decoderFFV1::decoderFFV1 (uint32_t w, uint32_t h):decoderFF (w, h)
   _refCopy = 1;			// YUV420 only
   WRAP_Open (CODEC_ID_FFV1);
 }
-
-decoderFFY800::decoderFFY800 (uint32_t w, uint32_t h):decoderFF (w, h)
-{
-  WRAP_Open (CODEC_ID_RAWVIDEO);
-  _context->pix_fmt = PIX_FMT_GRAY8;
-}
-
 decoderFFBmp::decoderFFBmp(uint32_t w, uint32_t h, uint32_t l, uint8_t *d) : decoderFF (w, h)
 {
 	_context->extradata = (uint8_t*)d;
@@ -570,7 +563,7 @@ decoderFFBmp::decoderFFBmp(uint32_t w, uint32_t h, uint32_t l, uint8_t *d) : dec
 
 decoderFFRaw::decoderFFRaw(uint32_t w, uint32_t h, uint32_t bpp) : decoderFF (w, h)
 {
-	_context->bits_per_sample = bpp;
+	_context->bits_per_coded_sample = bpp;
 	WRAP_Open (CODEC_ID_RAWVIDEO);
 }
 
@@ -584,7 +577,7 @@ decoderFF_ffhuff::decoderFF_ffhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t
 {
   _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
-  _context->bits_per_sample=bpp;
+  _context->bits_per_coded_sample = bpp;
   printf ("[lavc] FFhuff: We have %d bytes of extra data\n", l);
   WRAP_Open (CODEC_ID_FFVHUFF);
 
@@ -596,6 +589,7 @@ decoderFFH264::decoderFFH264 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d, u
   _refCopy = 1;			// YUV420 only
   _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
+  decoderMultiThread ();
   if(lowdelay)
     LOWDELAY();
   printf ("[lavc] Initializing H264 decoder with %d extradata\n", l);
@@ -625,7 +619,7 @@ decoderFFhuff::decoderFFhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d,ui
 {
   _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
-  _context->bits_per_sample = bpp;
+  _context->bits_per_coded_sample = bpp;
   WRAP_Open (CODEC_ID_HUFFYUV);
 }
 decoderFFWMV2::decoderFFWMV2 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
@@ -691,7 +685,7 @@ decoderSnow::decoderSnow (uint32_t w, uint32_t h):decoderFF (w, h)
 //*************
 decoderCamtasia::decoderCamtasia (uint32_t w, uint32_t h,uint32_t bpp):decoderFF (w,  h)
 {
-  _context->bits_per_sample = bpp;
+  _context->bits_per_coded_sample = bpp;
   WRAP_Open (CODEC_ID_TSCC);
 }
 //*************
@@ -709,6 +703,12 @@ decoderFFVP6F::decoderFFVP6F (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):d
 {
   WRAP_Open (CODEC_ID_VP6F);
 }
+//*************
+decoderFFVP6A::decoderFFVP6A (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
+{
+  WRAP_Open (CODEC_ID_VP6A);
+}
+
 //************
 decoderFFFLV1::decoderFFFLV1 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
 {
@@ -724,6 +724,10 @@ decoderFFMjpegB::decoderFFMjpegB (uint32_t w, uint32_t h, uint32_t l, uint8_t *
   WRAP_Open (CODEC_ID_MJPEGB);
   //_context->codec_id=CODEC_ID_AMV;
 }
+decoderFraps::decoderFraps(uint32_t w, uint32_t h) : decoderFF (w, h)
+{
+  WRAP_Open (CODEC_ID_FRAPS);
+}
 decoderFFDVBSub::decoderFFDVBSub (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
 {
   _context->sub_id=1;
@@ -792,15 +796,13 @@ void ADM_lavInit(void)
 }
 void adm_lavLogCallback(void  *instance, int level, const char* fmt, va_list list)
 {
-    if(level>1) return;
-    char buf[256];
-  
-    vsnprintf(buf, sizeof(buf), fmt, list);
-    printf("[lavc] %s\n",buf);
+	if (level > AV_LOG_INFO)
+		return;
+
+	char buf[256];
+
+	vsnprintf(buf, sizeof(buf), fmt, list);
+	printf("[lavc] %s\n",buf);
 }
 
-void ADM_lavDestroy(void)
-{
-	av_free_static();
-}
 // EOF
