@@ -252,15 +252,6 @@ public:
   decoderFFV1 (uint32_t w, uint32_t h);
 
 };
-class decoderFFY800:public decoderFF
-{
-protected:
-
-
-public:
-  decoderFFY800 (uint32_t w, uint32_t h);
-};
-
 class decoderFFBmp : public decoderFF
 {
 public:
@@ -349,6 +340,12 @@ protected:
 public:
   decoderFFVP6F (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
 };
+class decoderFFVP6A:public decoderFF
+{
+protected:
+public:
+  decoderFFVP6A (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+};
 class decoderFFFLV1:public decoderFF
 {
 protected:
@@ -374,4 +371,9 @@ public:
   decoderFFMjpegB (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
 };
 
+class decoderFraps : public decoderFF
+{
+public:
+	decoderFraps(uint32_t w, uint32_t h);
+};
 #endif
