@@ -23,32 +23,28 @@
 #include <string.h>
 #include <errno.h>
 
-
 #include "fourcc.h"
-#include "avio.hxx"
 #include "ADM_osSupport/ADM_quota.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_inpics/ADM_pics.h"
 
-#include "ADM_nuv/ADM_nuv.h"
-#include "ADM_h263/ADM_h263.h"
-
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_inputs/ADM_inpics/ADM_pics.h"
+#include "ADM_inputs/ADM_nuv/ADM_nuv.h"
+#include "ADM_inputs/ADM_h263/ADM_h263.h"
 
+#include "DIA_coreToolkit.h"
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
+
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "ADM_encoder/adm_encConfig.h"
-//#include "ADM_gui2/GUI_ui.h"
-#include "ADM_assert.h"
 #include "prefs.h"
 #include "avi_vars.h"
+
 // Ugly but sooo usefull
 extern uint32_t frameStart,frameEnd;
 static uint32_t edFrameStart,edFrameEnd;
-uint8_t loadVideoCodecConf( const char *name);
 const char *getCurrentContainerAsString(void);
 
 uint8_t ADM_Composer::getMarkers(uint32_t *start, uint32_t *end)
@@ -109,7 +105,7 @@ printf("\n **Saving script project **\n");
 
   for (uint32_t i = 0; i < _nb_video; i++)
     {
-        nm=cleanupPath(_videos[i]._aviheader->getMyName() );
+        nm=ADM_cleanupPath(_videos[i]._aviheader->getMyName() );
         if(vop)
         {
           qfprintf(fd,"app.forceUnpack();\n");
@@ -160,33 +156,37 @@ for (uint32_t i = 0; i < _nb_segment; i++)
 	if( avifileinfo ){
 	  aviInfo info;
 		video_body->getVideoInfo(&info);
-		qfprintf(fd,"\napp.video.setFps1000(%u);\n",info.fps1000);
+		qfprintf(fd,"\napp.video.fps1000 = %u;\n",info.fps1000);
 	}
 
 // Filter
 //___________________________
         qfprintf(fd,"\n//** Filters **\n");
         filterSaveScriptJS(fd);
+
 // Video codec
 //___________________________
-uint8_t  *extraData ;
-uint32_t extraDataSize;
+		uint8_t *extraData;
+		uint32_t extraDataSize;
 
-        qfprintf(fd,"\n//** Video Codec conf **\n");
-        videoCodecGetConf(&extraDataSize,&extraData);
-        qfprintf(fd,"app.video.codec(\"%s\",\"%s\",\"",videoCodecGetName(),videoCodecGetMode());
+		qfprintf(fd, "\n//** Video Codec conf **\n");
+		videoCodecGetConf(&extraDataSize, &extraData);
 
-        // Now deal with extra data
-        qfprintf(fd,"%d ",extraDataSize);
-        if(extraDataSize)
-        {
-                for(int i=0;i<extraDataSize;i++)
-                {
-                        qfprintf(fd,"%02x ",extraData[i]);
-                }
+		if (videoCodecGetType() == CodecExternal)
+			qfprintf(fd, "app.video.codecPlugin(\"%s\", \"%s\", \"%s\", \"%s\");\n", videoCodecPluginGetGuid(), videoCodecGetName(), videoCodecGetMode(), extraData);
+		else
+		{
+			qfprintf(fd, "app.video.codec(\"%s\", \"%s\", \"", videoCodecGetName(), videoCodecGetMode());
 
-        }
-        qfprintf(fd,"\");\n");
+			// Now deal with extra data
+			qfprintf(fd, "%d ", extraDataSize);
+
+			if (extraDataSize)
+				for(int i = 0; i < extraDataSize; i++)
+					qfprintf(fd, "%02x ", extraData[i]);
+
+			qfprintf(fd, "\");\n");
+		}
         
 // Audio Source
 //______________________________________________
@@ -208,7 +208,7 @@ uint32_t extraDataSize;
 
         if(source!=AudioAvi)
         {
-                char *nm=cleanupPath(audioName);
+                char *nm=ADM_cleanupPath(audioName);
                 qfprintf(fd,"app.audio.load(\"%s\",\"%s\");\n", audioSourceFromEnum(source),nm); 
                 ADM_dealloc(nm);
         }
@@ -233,7 +233,7 @@ uint32_t extraDataSize;
    qfprintf(fd,"app.audio.normalizeMode=%d;\n",audioGetNormalizeMode());
    qfprintf(fd,"app.audio.normalizeValue=%d;\n",audioGetNormalizeValue());
    qfprintf(fd,"app.audio.delay=%d;\n",audioGetDelay());
-   qfprintf(fd,"app.audio.mixer(\"%s\");\n",getCurrentMixerString());
+   qfprintf(fd,"app.audio.mixer=\"%s\";\n",getCurrentMixerString());
 
     // VBR ?
     if(currentaudiostream)
@@ -241,7 +241,7 @@ uint32_t extraDataSize;
         uint32_t encoding=currentaudiostream->getInfo()->encoding;
         if(currentaudiostream->isVBR() && (encoding==WAV_MP3 || encoding==WAV_MP2))
         {
-            qfprintf(fd,"app.audio.scanVBR();\n");
+            qfprintf(fd,"app.audio.scanVbr();\n");
         }
     }
 
@@ -271,7 +271,7 @@ uint32_t extraDataSize;
   qfprintf(fd,"app.setContainer(\"%s\");\n",getCurrentContainerAsString());
   if(outputname)
   {
-        char *o=cleanupPath(outputname);
+        char *o=ADM_cleanupPath(outputname);
         qfprintf(fd,"setSuccess(app.save(\"%s\"));\n",o);
         ADM_dealloc(o);
   }
