@@ -17,12 +17,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include <math.h>
 
 #include "config.h"
 #include "fourcc.h"
-#include "avio.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 
 #define STUBB _videos[0]._aviheader
@@ -369,8 +368,7 @@ ADM_Composer::getMainHeader (void)
   return STUBB->getMainHeader ();
 }
 
-BITMAPINFOHEADER *
-ADM_Composer::getBIH (void)
+ADM_BITMAPINFOHEADER *ADM_Composer::getBIH (void)
 {
   return STUBB->getBIH ();
 };
