@@ -22,53 +22,40 @@
 #include <string.h>
 #include <fcntl.h>
 #include <errno.h>
-#include <unistd.h>
-#include <pthread.h>
-#define WIN32_CLASH
-//#include <unistd.h>
-#ifdef ADM_WIN32
-#include "sys/stat.h"
-#endif
-#ifdef ADM_BSD_FAMILY
-#include "sys/stat.h"
-#endif
-#include <ADM_assert.h>
 
-#include "config.h"
-#include "fourcc.h"
-#include "avio.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_inpics/ADM_pics.h"
-#include "ADM_nuv/ADM_nuv.h"
-#include "ADM_h263/ADM_h263.h"
-//#include "ADM_3gp/ADM_3gp.h"
-#include "ADM_mp4/ADM_mp4.h"
-#include "ADM_openDML/ADM_openDML.h"
-#include "ADM_avsproxy/ADM_avsproxy.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
-//#include "ADM_dialog/DIA_working.h"
-#include "ADM_ogm/ADM_ogm.h"
-#include "ADM_mpegdemuxer/dmx_video.h"
-#include "ADM_mpegdemuxer/dmx_identify.h"
-#include "ADM_mpegdemuxer/dmx_probe.h"
-#include "ADM_matroska/ADM_mkv.h"
-#include "ADM_flv/ADM_flv.h"
-#include "ADM_amv/ADM_amv.h"
-#include "ADM_asf/ADM_asf.h"
+#if defined(__MINGW32__) || defined(ADM_BSD_FAMILY)
+#include <sys/stat.h>
+#endif
+
 #include "ADM_assert.h"
+#include "fourcc.h"
+#include "ADM_editor/ADM_edit.hxx"
+#include "ADM_inputs/ADM_inpics/ADM_pics.h"
+#include "ADM_inputs/ADM_nuv/ADM_nuv.h"
+#include "ADM_inputs/ADM_h263/ADM_h263.h"
+//#include "ADM_3gp/ADM_3gp.h"
+#include "ADM_inputs/ADM_mp4/ADM_mp4.h"
+#include "ADM_inputs/ADM_openDML/ADM_openDML.h"
+#include "ADM_inputs/ADM_avsproxy/ADM_avsproxy.h"
+#include "DIA_coreToolkit.h"
+#include "ADM_editor/ADM_edit.hxx"
+#include "ADM_videoFilter.h"
+//#include "ADM_dialog/DIA_working.h"
+#include "ADM_inputs/ADM_ogm/ADM_ogm.h"
+#include "ADM_inputs/ADM_mpegdemuxer/dmx_video.h"
+#include "ADM_inputs/ADM_mpegdemuxer/dmx_identify.h"
+#include "ADM_inputs/ADM_mpegdemuxer/dmx_probe.h"
+#include "ADM_inputs/ADM_matroska/ADM_mkv.h"
+#include "ADM_inputs/ADM_flv/ADM_flv.h"
+#include "ADM_inputs/ADM_amv/ADM_amv.h"
+#include "ADM_inputs/ADM_asf/ADM_asf.h"
 #include "prefs.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_EDITOR
 #include "ADM_osSupport/ADM_debug.h"
 
-#ifdef USE_DIVX
-	#include "ADM_codecs/ADM_divx4.h"
-#endif
-#include "ADM_mpegdemuxer/dmx_indexer.h"
+#include "ADM_inputs/ADM_mpegdemuxer/dmx_indexer.h"
 #include "ADM_outputfmt.h"
 //#include "ADM_gui2/GUI_ui.h"
 int DIA_mpegIndexer (char **mpegFile, char **indexFile, int *aid,
@@ -78,6 +65,8 @@ extern uint8_t indexMpeg (char *mpeg, char *file, uint8_t aid);
 
 extern uint8_t loadVideoCodecConf( const char *name);
 extern uint8_t parseScript(char *name);
+extern int ADM_open(const char *path, int oflag, int aflag);
+
 uint8_t UI_SetCurrentFormat( ADM_OUT_FORMAT fmt );
 const char *VBR_MSG = QT_TR_NOOP("Avidemux detected VBR MP3 audio in this file. For keeping audio/video in sync, time map is needed. Build it now?\n\nYou can do it later with \"Audio -> Build VBR Time Map\".");
 //
@@ -351,7 +340,7 @@ thisIsMpeg:
         }
 	/* check for "Read-only file system" */
 	{
-                int fd = open(tmpname,O_CREAT|O_EXCL|O_WRONLY,S_IRUSR|S_IWUSR);
+                int fd = ADM_open(tmpname,O_CREAT|O_EXCL|O_WRONLY,S_IRUSR|S_IWUSR);
                 if( fd >= 0 )
                 {
                     close(fd);
@@ -359,7 +348,7 @@ thisIsMpeg:
                     printf("Filesystem is writable\n");
 		}else if( errno == EROFS ){
 		  char *tmpdir = getenv("TMPDIR");
-#ifdef ADM_WIN32
+#ifdef __WIN32
                         printf("Filesystem is not writable, looking for somewhere else\n");
 			if( !tmpdir )
 				tmpdir = "c:";
@@ -728,17 +717,12 @@ TryAgain:
                                                                         GUI_Error_HIG(QT_TR_NOOP("Could not unpack the video"),QT_TR_NOOP( "Using backup decoder - not frame accurate."));
 									}
 								}
-#if  1 //def USE_DIVX
                                                                 if(count)
                                                                         GUI_Info_HIG(ADM_LOG_IMPORTANT,QT_TR_NOOP("Weird"),QT_TR_NOOP( "The unpacking succeedeed but the index is still not up to date."));
 								printf("\n Switching codec...\n");
 								delete vid->decoder;
 								vid->decoder=getDecoderVopPacked(info.fcc, info.width,info.height,0,NULL);
 								ispacked=1;
-#else
-								GUI_Info_HIG(ADM_LOG_IMPORTANT,QT_TR_NOOP("Troubles ahead"), QT_TR_NOOP("This a VOP packed AVI."));
-#endif
-
 							}
 
 						}
