@@ -14,11 +14,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <config.h>
+#include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
 #include <unistd.h>
 
 #include <time.h>
@@ -30,13 +27,13 @@
 
 #include "fourcc.h"
 #include "avi_vars.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
+#include "DIA_coreToolkit.h"
+#include "ADM_assert.h"
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
 
-#include "ADM_video/ADM_genvideo.hxx"
-//#include "ADM_codecs/ADM_divxEncode.h"
+#include "ADM_videoFilter.h"
+
 #include "ADM_codecs/ADM_ffmpeg.h"
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encffmpeg.h"
@@ -50,7 +47,7 @@
 #define FIRST_PASS_QUANTIZER 2
 
 
-#include "ADM_xvidratectl/ADM_ratecontrol.h"
+#include "ADM_libraries/ADM_xvidratectl/ADM_ratecontrol.h"
 
 static ADM_newXvidRcVBV *_xrc = NULL;
 
@@ -203,7 +200,7 @@ EncoderFFMPEGMpeg1::~EncoderFFMPEGMpeg1 ()
 
 //--------------------------------
 uint8_t
-EncoderFFMPEGMpeg1::configure (AVDMGenericVideoStream * instream)
+EncoderFFMPEGMpeg1::configure (AVDMGenericVideoStream * instream, int useExistingLogFile)
 {
 
   ADM_assert (instream);
