@@ -23,27 +23,49 @@
 #include "ADM_assert.h"
 #include "config.h"
 #include "fourcc.h"
-#include "avio.hxx"
+#include "DIA_fileSel.h"
+#include "ADM_dynamicLoading.h"
 
-#include "ADM_toolkit/toolkit.hxx"
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_video/ADM_videoNull.h"
-#include "ADM_filter/video_filters.h"
+#include "ADM_videoFilter_internal.h"
+#include "ADM_videoFilterDynamic.h"
 #include "ADM_video/ADM_vidPartial.h"
-#include "ADM_userInterfaces/ADM_commonUI/GUI_render.h"
+#include "ADM_userInterfaces/ADM_render/GUI_render.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_PREVIEW
 #include "ADM_osSupport/ADM_debug.h"
 #include "ADM_osSupport/ADM_quota.h"
+#include "ADM_preview.h"
 //
+
+extern ADM_UI_TYPE UI_GetCurrentUI(void);
+
+class ADM_vf_pluginLoader : public ADM_LibWrapper
+{
+	public:
+		VF_getDescriptor		*getDesc;
+		ADM_vf_pluginLoader(const char *file) : ADM_LibWrapper()
+		{
+				getDesc=NULL;
+				if(loadLibrary(file))
+					getDesc=(VF_getDescriptor *)getSymbol("ADM_VF_getDescriptor");
+		};
+};
 // exported vars
-std::vector <FILTER_ENTRY> allfilters;
+std::vector <FilterDescriptor *> allfilters;
+std::vector <FilterDescriptor *> filterCategories[VF_MAX];
+std::vector <ADM_vf_pluginLoader *> pluginLoaderQueue;
+
 uint32_t nb_active_filter=0;
-FILTER  videofilters[MAX_FILTER];
+FILTER  videofilters[VF_MAX_FILTER];
+
+
 
 static uint32_t lastStart=0, lastNb=0;
+static uint32_t tagCount=VF_START_TAG;
 
 extern ADM_Composer *video_body;
 extern AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *conf, AVDMGenericVideoStream *in) ;
@@ -74,17 +96,18 @@ void filterCleanUp( void )
 		  	delete videofilters[i].filter;
 			if(videofilters[i].conf) delete videofilters[i].conf;
              videofilters[i].conf=NULL;
-             videofilters[i].filter=NULL;  		
+             videofilters[i].filter=NULL;
 	}
    nb_active_filter=0;
 }
 void filterListAll( void )
 {
+const char *name;
 	printf("\nVideo filters\n");
 	for(uint32_t i=0;i<allfilters.size();i++)
 	{
-		const char *name = allfilters[ i].filtername;
-		if(allfilters[ i].viewable)
+		name=allfilters[i]->filterName;
+
 		{
 			if(name)
 				printf("\t%s\n",name);
@@ -92,51 +115,143 @@ void filterListAll( void )
 	}
 
 }
+/**
+ *      \fn filterGetTagFromName
+ *      \Brief returns the tag associated with a name, invalid otherwise
+ */
 VF_FILTERS filterGetTagFromName(const char *inname)
 {
-	VF_FILTERS filter=VF_DUMMY;
-	for(uint32_t i=0;i<allfilters.size();i++)
+	const char *name;
+	int max = allfilters.size();
+	VF_FILTERS filter = VF_INVALID;
+
+	for (uint32_t i = 0; i < max; i++)
 	{
-		const char *name=allfilters[ i].filtername;
-		if(allfilters[ i].viewable || allfilters[i].tag==VF_PARTIAL)
+		name = allfilters[i]->filterName;
+
+		if (name && strlen(name) && !strcasecmp(name, inname))
 		{
-			if(name)
-			{
-				if(strlen(name))
-				{
-					if(!strcasecmp(name,inname))
-						return allfilters[ i].tag; 
-				}
-			}
+			filter = allfilters[i]->tag;
+			break;
 		}
 	}
+
 	return filter;
 }
-void registerFilter(const char *name,VF_FILTERS tag,uint8_t viewable
-		,AVDMGenericVideoStream *(*create) (AVDMGenericVideoStream *in, CONFcouple *)
-		,char *filtername)
-{
-//        printf ("*nb_video_filter() = %d, max %d, name = %s\n", nb_video_filter(), (MAX_FILTER-1), name);
-        allfilters.push_back (FILTER_ENTRY (name, create, tag, viewable, filtername));
 
-        if(viewable==1)
-	{
-        	aprintf("\nRegistered filter %lu: %s",allfilters.size(),name);
-	}
+/**
+ * 	\fn tryLoadingFilterPlugin
+ *  \brief try to load the plugin given as argument..
+ */
+
+#define Fail(x) {printf("%s:"#x"\n",file);goto er;}
+
+static bool tryLoadingFilterPlugin(const char *file)
+{
+	ADM_vf_pluginLoader *dll = new ADM_vf_pluginLoader(file);
+	FilterDescriptor *desc = NULL;
+	FilterDescriptor *myDesc = NULL;
+
+	if (!dll->getDesc)
+		Fail(nogetdesc);
+
+	desc = dll->getDesc();
+
+	if (!desc)
+		Fail(GetDescriptor);
+
+	if (desc->apiVersion != ADM_FILTER_API_VERSION)
+		Fail(WrongAPI);
+
+	if (!(desc->uiFlags & UI_GetCurrentUI()))
+		Fail(WrongUI);
+
+	// Duplicate it, just in case...
+	myDesc = new FilterDescriptor();
+
+	memcpy(myDesc, desc, sizeof(*myDesc));
+	myDesc->tag = tagCount++;
+	ADM_assert(myDesc->category < VF_MAX);
+
+	allfilters.push_back(myDesc);
+	filterCategories[myDesc->category].push_back(myDesc);
+	pluginLoaderQueue.push_back(dll); // Needed for cleanup. FIXME TODO Delete it.
+	printf("[Filters] Registered filter %s as %s\n", file, desc->name);
+
+	return true;
+
+er:
+	delete dll;
+
+	return false;
 }
-void registerFilterEx(const char *name,VF_FILTERS tag,uint8_t viewable
-		,AVDMGenericVideoStream *(*create) (AVDMGenericVideoStream *in, CONFcouple *)
-		,const char *filtername,AVDMGenericVideoStream *(*create_from_script) (AVDMGenericVideoStream *in, int n,Arg *args), const char *desc)
+/**
+ * 	\fn ADM_vf_loadPlugins
+ *  \brief load all video plugins
+ */
+uint8_t ADM_vf_loadPlugins(const char *path)
 {
-//    printf ("nb_video_filter = %d, max %d, name = %s\n", nb_video_filter, (MAX_FILTER-1), name);
-        allfilters.push_back (FILTER_ENTRY (name, create, tag, viewable,
-                                            filtername, desc, create_from_script));
+#define MAX_EXTERNAL_FILTER 100
 
-        if(viewable==1)
+#ifdef __WIN32
+#define SHARED_LIB_EXT "dll"
+#elif defined(__APPLE__)
+#define SHARED_LIB_EXT "dylib"
+#else
+#define SHARED_LIB_EXT "so"
+#endif
+
+	char *files[MAX_EXTERNAL_FILTER];
+	uint32_t nbFile;
+
+	memset(files, 0, sizeof(char *)*MAX_EXTERNAL_FILTER);
+	printf("[ADM_vf_plugin] Scanning directory %s\n", path);
+
+	if (!buildDirectoryContent(&nbFile, path, files, MAX_EXTERNAL_FILTER, SHARED_LIB_EXT))
 	{
-        	aprintf("\nRegistered filter %lu: %s",allfilters.size(),name);
+		printf("[ADM_vf_plugin] Cannot parse plugin\n");
+		return 0;
 	}
 
+	for (int i = 0; i < nbFile; i++)
+	{
+		tryLoadingFilterPlugin(files[i]);
+		ADM_dealloc(files[i]);
+	}
+
+	printf("[ADM_vf_plugin] Scanning done\n");
+
+	return 1;
+}
+/**
+ * 	\fn registerFilterEx
+ *  \brief Register a video filter
+ */
+void registerFilterEx(const char *name,const char *filtername,VF_CATEGORY category,
+		AVDMGenericVideoStream *(*create) (AVDMGenericVideoStream *in, CONFcouple *),
+		AVDMGenericVideoStream *(*create_from_script) (AVDMGenericVideoStream *in, int n,Arg *args),
+		const char *descText)
+{
+	int tag;
+
+	if (strcmp(name, "partial") == 0)
+		tag = VF_PARTIAL_FILTER;
+	else
+		tag = tagCount++;
+
+	FilterDescriptor *desc=new FilterDescriptor(tag,filtername,name,
+												descText,
+												category,
+												create,
+												create_from_script);
+
+		ADM_assert(desc->category<VF_MAX);
+
+        allfilters.push_back (desc);
+        filterCategories[desc->category].push_back(desc);
+
+        aprintf("[Filters] Registered filter %s\n",desc->name);
+
 
 }
 /************************** Get the last video filter of the chain ***************************
@@ -244,7 +359,7 @@ void updateVideoFilters(void )
                     AVDMGenericVideoStream *old;
                             old= videofilters[i].filter;
                             tag=videofilters[i].tag;
-  
+
                             videofilters[i].filter=filterCreateFromTag(tag,
                                                 videofilters[i].conf,
                                                 videofilters[i-1].filter);
@@ -257,179 +372,63 @@ void updateVideoFilters(void )
 //
 //	Create a filter from : its tag, its config and an input stream
 //
-
 AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *couple, AVDMGenericVideoStream *in)
 {
-	 AVDMGenericVideoStream *filter;
+	ADM_assert(tag != VF_INVALID);
 
-			ADM_assert(tag!=VF_INVALID);
-                        if(tag>=VF_EXTERNAL_START)
-                        {
-                          // start from the end, it is an external filter 
-                          for(uint32_t i=allfilters.size()-1;i>=0;i--)
-                          {
-                              if(tag==allfilters[i].tag)
-                                {
-                                        filter=allfilters[i].create( in, couple);
-                                        return filter;
-                                }
-                          }
-                        } // else search forward
-                        else
-                        {
-                          for(unsigned int i=0;i<allfilters.size();i++)
-                                  {
-                                          if(tag==allfilters[i].tag)
-                                                  {
-                                                          filter=allfilters[i].create( in, couple);
-                                                          return filter;
-                                                  }
-                                  }
-                        }
-			ADM_assert(0);
-			return NULL;                      
+	AVDMGenericVideoStream *filter = VF_INVALID;
+
+	for (unsigned int i = 0; i < allfilters.size(); i++)
+	{
+		if (tag == allfilters[i]->tag)
+		{
+			filter = allfilters[i]->create(in, couple);
+
+			break;
+		}
+	}
+
+	ADM_assert(filter != VF_INVALID);
+
+	return filter;
 }
+
 /*
 
 
 */
-const FILTER_ENTRY * filterGetEntryFromTag (VF_FILTERS tag)
+const FilterDescriptor * filterGetEntryFromTag (VF_FILTERS tag)
 {
     ADM_assert(tag!=VF_INVALID);
     for(unsigned int i=0;i<allfilters.size();i++)
     {
-        if(tag==allfilters[i].tag)
+        if(tag==allfilters[i]->tag)
         {
-            return &(allfilters[i]);
+            return (allfilters[i]);
         }
     }
     ADM_assert(0);
-    return NULL;                      
+    return NULL;
 }
 
 const char  *filterGetNameFromTag(VF_FILTERS tag)
 {
-    const FILTER_ENTRY * entry = filterGetEntryFromTag (tag);
+    const FilterDescriptor * entry = filterGetEntryFromTag (tag);
     ADM_assert(entry);
     return entry->name;
 }
 /*____________________________________
 	Save and load current set of filters
-	
+
 	We save/load the tag that identifies the filter
 	and a raw hex dump of its config
 		+ comment and name in clear text
-	____________________________________ 
+	____________________________________
 */
 
-/*---------------------------------------*/	 
+/*---------------------------------------*/
 
 
-//______________________________________________________
-// Check and build a confCouple from the args
-// the filter_param arg is a template for that filter
-//______________________________________________________
-CONFcouple *filterBuildCouple(FILTER_PARAM *param,uint32_t nb,Arg *args)
-{
-int found,l;
-int trans[MAXPARAM];
-	if(param->nb>VARIABLE_PARAMS)
-	{
-		// Variable # of parameters
-		// We check we have at least what is required by the template
-		for(int i=0;i<(param->nb-VARIABLE_PARAMS);i++)
-				{
-					l=strlen(param->param[i]);
-					ADM_assert(l);
-					found=-1;
-					for(int j=0;j<nb;j++)
-					{
-						if(!strncasecmp(param->param[i],args[j].arg.string,l))
-						{
-							if(strlen(args[j].arg.string)>l && args[j].arg.string[l]=='=')
-							{
-								found=j;
-								break;
-							}
-						}
-					}
-					if(found==-1)
-					{	
-						printf("Param : %s not found or incorrect\n",param->param[i]);
-						 return NULL;
-					}
-				}
-				// if we get here, it means we found each param, time to build the couples
-				CONFcouple *couple;
-				couple=new CONFcouple(nb);
-				for(int i=0;i<nb;i++)
-				{
-					char *copy=ADM_strdup(args[i].arg.string);
-					// Search "="
-					char *where=strstr(copy,"=");
-					if(!where) ADM_assert(0);
-					*where=0;
-					if(!couple->setCouple(copy,where+1))
-						{
-							printf("Set couple failed\n");
-							delete couple;
-							return NULL;
-						}
-					ADM_dealloc(copy);
-				}
-				return couple;
-	}
-	//********************* Constant # of parameters #################
-	else
-	{
-		if(nb!=param->nb )
-		{
-			printf("# of parameters mismatch: expected %d, got %d\n",nb,param->nb);
-			return NULL;
-		}
-		// For each param check we are ok
-		// the generic form is name=value
-		// name should be the same as in the param array
-		for(int i=0;i<nb;i++)
-		{
-			l=strlen(param->param[i]);
-			ADM_assert(l);
-			found=-1;
-			for(int j=0;j<nb;j++)
-			{
-				if(!strncasecmp(param->param[i],args[j].arg.string,l))
-				{
-					if(strlen(args[j].arg.string)>l && args[j].arg.string[l]=='=')
-					{
-						found=j;
-						trans[i]=j;
-						break;
-					}
-				}
-			}
-			if(found==-1)
-			{	
-				printf("Param : %s not found or incorrect\n",param->param[i]);
-				 return NULL;
-			}
-		}
-		// if we get here, it means we found each param, time to build the couples
-		CONFcouple *couple;
-		couple=new CONFcouple(nb);
-		for(int i=0;i<nb;i++)
-		{
-			l=strlen(param->param[i]);
-			if(!couple->setCouple(param->param[i],args[ trans[i]].arg.string+l+1))
-				{
-					printf("Set couple failed\n");
-					delete couple;
-					return NULL;
-				}
-		}
-		return couple;
-	}
-	
-}
 uint8_t 	filterAddScript(VF_FILTERS tag,uint32_t n,Arg *args)
 {
 	// 1- search filter
@@ -440,24 +439,24 @@ uint8_t 	filterAddScript(VF_FILTERS tag,uint32_t n,Arg *args)
 
 	for(unsigned int i=0;i<allfilters.size();i++)
 	{
-		if(tag==allfilters[i].tag)
+		if(tag==allfilters[i]->tag)
 		{
 			if(nb_active_filter<1)
 			{
   		 		nb_active_filter=1;
-  		 		videofilters[0].filter=  new AVDMVideoStreamNull(video_body,0,info.nb_frames);	
+  		 		videofilters[0].filter=  new AVDMVideoStreamNull(video_body,0,info.nb_frames);
 			}
 			AVDMGenericVideoStream *filter=NULL;
 			CONFcouple *setup=NULL;
-			if(!allfilters[i].create_from_script)
+			if(!allfilters[i]->create_from_script)
 			{
 				printf("That filter cannot be created from script\n");
 				return 0;
 			}
-			filter=allfilters[i].create_from_script(videofilters[nb_active_filter-1].filter,n-1,&(args[1]));
+			filter=allfilters[i]->create_from_script(videofilters[nb_active_filter-1].filter,n-1,&(args[1]));
 			if(!filter) return 0;
 			videofilters[nb_active_filter].filter=filter;
-			videofilters[nb_active_filter].tag=tag;						
+			videofilters[nb_active_filter].tag=tag;
 			filter->getCoupledConf(&setup);
 			videofilters[nb_active_filter].conf=setup;
 			nb_active_filter++;
@@ -476,10 +475,10 @@ void filterSaveScriptJS(FILE *f)
                         qfprintf(f,"app.video.addFilter(");
                         for(unsigned int j=0;j<allfilters.size();j++)
                                 {
-                                        if(tag==allfilters[j].tag)
-                                        {       
-                                                qfprintf(f,"\"%s\"",allfilters[j].filtername);
-                                                break;  
+                                        if(tag==allfilters[j]->tag)
+                                        {
+                                                qfprintf(f,"\"%s\"",allfilters[j]->filterName);
+                                                break;
                                         }
                                 }
                         // get args
@@ -498,9 +497,9 @@ void filterSaveScriptJS(FILE *f)
                                 }
                                 delete couple;
                         }
-                        qfprintf(f,");\n");                      
-                
+                        qfprintf(f,");\n");
+
                 }
-                
-}               	
+
+}
 // EOF
