@@ -13,19 +13,12 @@
  ***************************************************************************/
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
-
-#include "ADM_assert.h"
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
 
-
 #include "fourcc.h"
-#include "ADM_mp4/ADM_mp4.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_inputs/ADM_mp4/ADM_mp4.h"
+#include "ADM_video/ADM_videoInfoExtractor.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_3GP
@@ -33,11 +26,9 @@
 
 extern "C"
 {
-#include "common.h"
-#include "bswap.h"
-#define INT_MAX (0x7FFFFFFF)
-#include "ADM_lavcodec/bitstream.h"
-#include "ADM_lavcodec/golomb.h"
+#define INT_BIT (CHAR_BIT * sizeof(int))
+#include "libavcodec/get_bits.h"
+#include "libavcodec/golomb.h"
 }
 
 #include "ADM_infoExtractor/ADM_h264_tag.h"
@@ -446,7 +437,7 @@ uint8_t extractSPSInfo(uint8_t *data, uint32_t len, h264SpsInfo *info)
                  {
                       get_se_golomb(&s);
                  }
-             }else 
+             }else if(pic_order_cnt_type!=2)
              {
                printf("Error in SPS\n");
                return 0;
@@ -644,3 +635,75 @@ int getH264SliceHeader(uint8_t *buffer, int length, h264SpsInfo *spsInfo, h264Sl
 
 	return 1;
 }
+/**
+    \fn ADM_searchVop
+
+ Search a start vop in it
+ and return also the vop type
+ needed for example to rederive frame type or unpack streams
+*/
+uint32_t ADM_searchVop(uint8_t *begin, uint8_t *end,uint32_t *nb, ADM_vopS *vop,uint32_t *timeincbits)
+{
+	
+	uint32_t off=0;
+	uint32_t globalOff=0;
+	uint32_t voptype;
+	uint8_t code;
+        uint32_t w,h,t;
+        uint32_t modulo,time_inc,vopcoded,vopType;
+	*nb=0;
+	while(begin<end-3)
+	{
+    	if( ADM_findMpegStartCode(begin, end,&code,&off))
+    	{
+        	if(code==0xb6)
+			{
+				// Analyse a bit the vop header
+				uint8_t coding_type=begin[off];
+				coding_type>>=6;
+				//aprintf("\t at %u %d Img type:%s\n",off,*nb,s_voptype[coding_type]);
+				switch(coding_type)
+				{
+					case 0: voptype=AVI_KEY_FRAME;break;
+					case 1: voptype=0;break;
+					case 2: voptype=AVI_B_FRAME;break;
+					case 3: printf("Glouglou\n");voptype=0;break;
+				
+				}
+        	                vop[*nb].offset=globalOff+off-4;
+				vop[*nb].type=voptype;
+
+				
+                                
+                                /* Get more info */
+                                if( extractVopInfo(begin+off, end-begin-off, *timeincbits,&vopType,&modulo,
+                                            &time_inc,&vopcoded))
+                                {
+                                    aprintf(" frame found: vopType:%x modulo:%d time_inc:%d vopcoded:%d\n",vopType,modulo,time_inc,vopcoded);
+                                    vop[*nb].modulo=modulo;
+                                    vop[*nb].timeInc=time_inc;
+                                    vop[*nb].vopCoded=vopcoded;
+                                }
+                                *nb=(*nb)+1;
+                                begin+=off+1;
+				globalOff+=off+1;
+				continue;
+			
+			}
+                else if(code==0x20 && off>=4	) // Vol start
+                {
+                  
+                   if(extractMpeg4Info(begin+off-4,end+4-off-begin,&w,&h,timeincbits))
+                   {
+                      aprintf("Found Vol header : w:%d h:%d timeincbits:%d\n",w,h,*timeincbits);
+                   }
+                  
+                }
+        	begin+=off;
+        	globalOff+=off;
+        	continue;
+    	}
+    	return 1; 
+    }   
+	return 1;
+}
