@@ -6,29 +6,24 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-
 #include <string.h>
-
-#include "math.h"
-
-
+#include <math.h>
 #include <errno.h>
 
-#include <ADM_assert.h>
-#include "default.h"
+#include "ADM_assert.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
 
-
 #include "fourcc.h"
-#include "ADM_avsproxy/ADM_avsproxy.h"
-#include "ADM_avsproxy/ADM_avsproxy_internal.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_avsproxy.h"
+#include "ADM_avsproxy_internal.h"
+
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_3GP
 #include "ADM_osSupport/ADM_debug.h"
 
-#include "ADM_osSupport/TLK_clock.h"
+
 
 
 avsHeader::avsHeader()
