@@ -14,25 +14,18 @@
  *                                                                         *
  ***************************************************************************/
 #include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <string.h>
-
-#include "math.h"
-
-#include "default.h"
+#include <math.h>
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 #include "fourcc.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "DIA_coreToolkit.h"
 
 #include "ADM_flv.h"
 
 // Borrowed from lavformt/flv.h
-#include "ADM_lavformat/flv.h"
+#include "libavformat/flv.h"
 // Borrowed from lavformt/flv.h    
 
 uint32_t ADM_UsecFromFps1000(uint32_t fps1000);
@@ -87,6 +80,143 @@ uint32_t flvHeader::read32(void)
     fread(r,4,1,_fd);
     return (r[0]<<24)+(r[1]<<16)+(r[2]<<8)+r[3]; 
 }
+/**
+    \fn     readFlvString
+    \brief  read pascal like string
+*/
+char *flvHeader::readFlvString(void)
+{
+static char stringz[255];
+    int size=read16();
+    read(size,(uint8_t *)stringz);
+    stringz[size]=0;
+    return stringz;
+}
+
+extern "C" {
+double av_int2dbl(int64_t v);
+}
+
+/**
+    \fn setProperties
+    \brief get a couple key/value and use it if needed...
+*/
+void flvHeader::setProperties(const char *name,float value)
+{
+    if(!strcmp(name,"framerate"))
+    {
+        _videostream.dwRate=(uint32_t)(value*1000);
+        return;
+    }
+    if(!strcmp(name,"width"))
+    {
+        metaWidth=(uint32_t)value;
+    }
+    if(!strcmp(name,"height"))
+    {
+        metaHeight=(uint32_t)value;
+    }
+
+}
+/**
+    \fn parseMetaData
+    \brief
+*/
+uint8_t flvHeader::parseMetaData(uint32_t remaining)
+{
+    uint32_t endPos=ftello(_fd)+remaining;
+    {
+        // Check the first one is onMetaData...
+        uint8_t type=read8();
+
+        if(type!=AMF_DATA_TYPE_STRING) // String!
+            goto endit;
+        char *z=readFlvString();
+        printf("[FlashString] %s\n",z);
+        if(z && strncmp(z,"onMetaData",10)) goto endit;
+        // Normally the next one is mixed array
+        Skip(4);
+        Skip(1);
+        while(ftello(_fd)<endPos-4)
+        {
+
+            char *s=readFlvString();
+            printf("[FlvType] :%d String : %s",type,s);
+            type=read8();
+            switch(type)
+            {
+                case AMF_DATA_TYPE_ARRAY:
+                                    {
+                                            uint32_t len=read32();
+                                            printf("[FLV] Array :");
+                                            for(int i=0;i<len;i++) printf("%02x ",read8());
+                                            printf("\n");
+                                            break;
+                                    }
+                case AMF_DATA_TYPE_DATE: Skip(8+2);break;
+                case AMF_DATA_TYPE_NUMBER:
+                                        {
+                                            float val;
+                                            uint64_t hi,lo;
+                                            hi=read32();lo=read32();
+                                            hi=(hi<<32)+lo;
+                                            val=(float)av_int2dbl(hi);
+                                            printf("->%f\n",val);
+                                            setProperties(s,val);
+                                        }
+                                        ;break;
+                case AMF_DATA_TYPE_STRING: {int r=read16();Skip(r);}break;
+                case AMF_DATA_TYPE_BOOL: read8();break;
+                case AMF_DATA_TYPE_OBJECT: goto endit; // unsupported for the moment
+                default : printf("\n");ADM_assert(0);
+            }
+            printf("\n");
+
+        }
+
+        // Process them...
+    }
+endit:
+    fseeko(_fd,endPos,SEEK_SET);
+    return 1;
+}
+/**
+    \fn extraHeader
+    \brief if returns true means we must skip the remainder
+*/
+bool flvHeader::extraHeader(flvTrak *trk,uint32_t *remain,bool have_cts,int32_t *cts)
+{
+    int type=read8();
+    int r=*remain;
+    r--;
+    if(have_cts)
+    {
+        uint32_t c=read24();
+         *cts=(c+0xff800000)^0xff800000;
+        //printf("Type :%d\n",type);
+        r-=3;
+    }
+    if(!type)
+    {  // Grab extra data
+        if(trk->extraData) 
+        {
+            Skip(r);
+            r=0;
+        }
+        else    
+        {
+            printf("[FLV] found some extradata %lu\n",r);
+            trk->extraData=new uint8_t[r];
+            trk->extraDataLen=r;
+            read(r,trk->extraData);
+            r=0;            
+        }
+        *remain=r;
+        return true;
+    }
+    *remain=r;
+    return false;
+}
 
 /**
       \fn open
@@ -96,7 +226,8 @@ uint32_t flvHeader::read32(void)
 uint8_t flvHeader::open(const char *name)
 {
   uint32_t prevLen, type, size, pts,pos=0;
-  
+  bool firstVideo=true;
+  int32_t cts; 
   _isvideopresent=0;
   _isaudiopresent=0;
   audioTrack=NULL;
@@ -186,9 +317,19 @@ uint8_t flvHeader::open(const char *name)
             {
                setAudioHeader(format,fq,bps,channel);
             }
-            insertAudio(pos+of,remaining,pts);
+            if(format==10)
+            {
+                if(extraHeader(audioTrack,&remaining,false,&cts)) continue;
+            }
+            if(remaining)
+                insertAudio(ftello(_fd),remaining,pts);
           }
           break;
+      case FLV_TAG_TYPE_META:
+                parseMetaData(remaining);
+                remaining=0;
+                break;
+
       case FLV_TAG_TYPE_VIDEO:
           {
             int of=1+4+3+3+1+4;
@@ -198,19 +339,24 @@ uint8_t flvHeader::open(const char *name)
             
             int codec=(flags)&0xf;
             
-            if(codec==FLV_CODECID_VP6)
+            if(codec==FLV_CODECID_VP6 || codec==FLV_CODECID_VP6A)
             {
               read8(); // 1 byte of extraData
               remaining--;
               of++;
             }
-            int first=0;
-            if(!videoTrack->_nbIndex) first=1;
-            insertVideo(pos+of,remaining,frameType,pts);
-            if(first) // first frame..
+            if(firstVideo==true) // first frame..
             {
                 if(!setVideoHeader(codec,&remaining)) return 0;
+                firstVideo=false;
             }
+            if(codec==FLV_CODECID_H264)
+            {
+                if(true==extraHeader(videoTrack,&remaining,true,&cts)) continue;
+
+            }
+            if(remaining)
+                insertVideo(ftello(_fd),remaining,frameType,pts);
             
           }
            break;
@@ -260,30 +406,34 @@ uint8_t flvHeader::setVideoHeader(uint8_t codec,uint32_t *remaining)
     printf("[FLV] Video Codec:%u\n",codec);
      _video_bih.biWidth=_mainaviheader.dwWidth=320;
     _video_bih.biHeight=_mainaviheader.dwHeight=240;
+#define MKFLV(x,t) case FLV_CODECID_##x :  _videostream.fccHandler=_video_bih.biCompression=\
+                            fourCC::get((uint8_t *)#t);break;
+
     switch(codec)
     {
-      case FLV_CODECID_H263:            _videostream.fccHandler=_video_bih.biCompression=fourCC::get((uint8_t *)"FLV1");break;
-      case FLV_CODECID_VP6:             _videostream.fccHandler=_video_bih.biCompression=fourCC::get((uint8_t *)"VP6F");break;
-    //???   case FLV_CODECID_SCREEN:          _videostream.fccHandler=_video_bih.biCompression=fourCC::get((uint8_t *)"VP6F");break;
+        MKFLV(H264,H264);
+        MKFLV(H263,FLV1);
+        MKFLV(VP6,VP6F);
+        MKFLV(VP6A,VP6A);
+
       default :                         _videostream.fccHandler=_video_bih.biCompression=fourCC::get((uint8_t *)"XXX");break;
       
     }
-    if(codec==FLV_CODECID_VP6)
-    {
-        read8();
-        read8();
-        *remaining-=2;
-         
-         _video_bih.biHeight=_mainaviheader.dwHeight=read8()*16;
-         _video_bih.biWidth=_mainaviheader.dwWidth=read8()*16;
-        *remaining-=2; 
-    }
+     if( metaWidth && metaHeight )
+        if( codec==FLV_CODECID_VP6A  || codec==FLV_CODECID_H264 || codec==FLV_CODECID_VP6) 
+        {
+                _video_bih.biHeight=_mainaviheader.dwHeight=metaHeight ;
+                _video_bih.biWidth=_mainaviheader.dwWidth=metaWidth;
+        }
+
     if(codec==FLV_CODECID_H263)
     {
       uint32_t len=*remaining,width,height;
+      uint32_t pos=ftello(_fd);
+
       uint8_t buffer[len];
       read(len,buffer);
-      *remaining=0;
+      fseeko(_fd,pos,SEEK_SET);
        /* Decode header, from h263dec.c / lavcodec*/
       if(extractH263FLVInfo(buffer,len,&width,&height))
       {
@@ -318,6 +468,7 @@ uint8_t   flvHeader::setAudioHeader(uint32_t format,uint32_t fq,uint32_t bps,uin
     case 3: wavHeader.encoding=WAV_PCM;break; 
     case 0: wavHeader.encoding=WAV_LPCM;break;
     case 1: wavHeader.encoding=WAV_MSADPCM;break;
+    case 10:wavHeader.encoding=WAV_AAC;break;
     default:
           printf("[FLV]Unsupported audio codec:%u\n",format);    
   }
@@ -415,8 +566,17 @@ void flvHeader::Dump(void)
 uint8_t flvHeader::close(void)
 {
   if(_filename) ADM_dealloc(_filename);
-  if(videoTrack) delete videoTrack;
-  if(audioTrack) delete audioTrack;
+  if(videoTrack) 
+  {
+        if(videoTrack->extraData) delete [] videoTrack->extraData;
+        delete videoTrack;
+  }
+  if(audioTrack) 
+  {
+     if(audioTrack->extraData) delete [] audioTrack->extraData;
+    delete audioTrack;
+  }
+
   if(_fd) fclose(_fd);
   if(_audioStream) delete _audioStream;
   
@@ -502,9 +662,15 @@ uint8_t  flvHeader::getFrameNoAlloc(uint32_t frame,ADMCompressedImage *img)
 
 uint8_t  flvHeader::getExtraHeaderData(uint32_t *len, uint8_t **data)
 {
-                *len=0; //_tracks[0].extraDataLen;
-                *data=NULL; //_tracks[0].extraData;
-                return 1;            
+        if(videoTrack)
+        {
+                *len=videoTrack->extraDataLen;
+                *data=videoTrack->extraData;
+                return 1;
+        }
+        *len=0;
+        *data=NULL;
+        return 1;
 }
 /*
     __________________________________________________________
