@@ -88,6 +88,7 @@ class flvHeader         :public vidHeader
     uint8_t                 getAudioStreamsInfo(uint32_t *nbStreams, audioInfo **infos);
     flvAudio                *_audioStream;
     /* */
+    uint32_t                metaWidth,metaHeight,metaFps1000;
     
     uint8_t     read(uint32_t len, uint8_t *where);
     uint8_t     read8(void);
@@ -99,9 +100,15 @@ class flvHeader         :public vidHeader
     uint8_t     insertAudio(uint32_t pos,uint32_t size,uint32_t pts);
     uint8_t     setAudioHeader(uint32_t format,uint32_t fq,uint32_t bps,uint32_t channels);
     uint8_t     setVideoHeader(uint8_t codec,uint32_t *remaining);
+    bool        extraHeader(flvTrak *trk,uint32_t *remain,bool have_cts,int32_t *cts);
     
     
     uint8_t     getFrameSize (uint32_t frame, uint32_t * size);
+    uint8_t     parseMetaData(uint32_t remaining);
+    void        setProperties(const char *name,float value);
+    char        *readFlvString(void);
+ 
+
   public:
 
 
