@@ -18,14 +18,14 @@
 
 #include <string.h>
 
-#include "math.h"
+#include <math.h>
 
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 #include "fourcc.h"
-#include "ADM_toolkit/toolkit.hxx"
+
 
 #include "ADM_mkv.h"
 
@@ -130,9 +130,9 @@ entryDesc entry;
         _videostream.fccHandler=_video_bih.biCompression=entry.fcc;
 
         // if it is vfw...
-        if(fourCC::check(entry.fcc,(uint8_t *)"VFWX") && entry.extraData && entry.extraDataLen>=sizeof(BITMAPINFOHEADER))
+        if(fourCC::check(entry.fcc,(uint8_t *)"VFWX") && entry.extraData && entry.extraDataLen>=sizeof(ADM_BITMAPINFOHEADER))
         {
-          memcpy(& _video_bih,entry.extraData,sizeof(BITMAPINFOHEADER));
+          memcpy(& _video_bih,entry.extraData,sizeof(ADM_BITMAPINFOHEADER));
           delete [] _tracks[0].extraData;
           entry.extraData=NULL;
           entry.extraDataLen=0;
@@ -201,6 +201,7 @@ uint8_t entryWalk(ADM_ebml_file *head,uint32_t headlen,entryDesc *entry)
         case  MKV_TRACK_TYPE: entry->trackType=father.readUnsignedInt(len);break;
 
         case  MKV_AUDIO_FREQUENCY: entry->fq=(uint32_t)floor(father.readFloat(len));break;
+        case  MKV_AUDIO_CHANNELS: entry->chan=father.readUnsignedInt(len);break;
         //case MKV_AUDIO_OUT_FREQUENCY:entry->fq=(uint32_t)floor(father.readFloat(len));break;
         case  MKV_VIDEO_WIDTH: entry->w=father.readUnsignedInt(len);break;
         case  MKV_VIDEO_HEIGHT: entry->h=father.readUnsignedInt(len);break;
