@@ -18,14 +18,14 @@
 
 #include <string.h>
 
-#include "math.h"
+#include <math.h>
 
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 #include "fourcc.h"
-#include "ADM_toolkit/toolkit.hxx"
+
 
 #include "ADM_mkv.h"
 
@@ -45,7 +45,8 @@ MKVCC mkvCC[]=
   {"A_AC3",0,WAV_AC3,""}, 
   {"A_AAC/MPEG2/LC",0,WAV_AAC,""},
   {"A_AAC/MPEG4/LC/SBR",0,WAV_AAC,""},
-  
+  {"A_AAC/MPEG4/LC",0,WAV_AAC,""},
+  {"A_PCM/INT/LIT",0,WAV_PCM,""},
   {"A_AAC",0,WAV_AAC,""},
   {"A_VORBIS",0,WAV_OGG,""},
   {"A_DTS",0,WAV_DTS,""},
