@@ -15,19 +15,14 @@
  ***************************************************************************/
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <math.h>
 
-#include "ADM_assert.h"
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
 
-
 #include "fourcc.h"
-#include "ADM_mp4/ADM_mp4.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_mp4.h"
+#include "DIA_coreToolkit.h"
 #include "ADM_codecs/ADM_codec.h"
 
 #include "ADM_mp4Tree.h"
@@ -764,6 +759,7 @@ nextAtom:
                                 left-=4;
                                 if(atomVersion)
                                 {
+                                         #define ADM_NOT_NULL(x)          if(!info.x) info.x=1;
                                     info.samplePerPacket=son.read32();
                                     info.bytePerPacket=son.read32();
                                     info.bytePerFrame=son.read32();
@@ -771,6 +767,10 @@ nextAtom:
                                     printf("[STSD] Bytes per packet  %u\n",info.bytePerPacket);
                                     printf("[STSD] Bytes per frame   %u\n",info.bytePerFrame);
                                     printf("[STSD] Bytes per sample   %u\n",son.read32());
+                                     ADM_NOT_NULL(samplePerPacket);  
+                                    ADM_NOT_NULL(bytePerPacket);
+                                    ADM_NOT_NULL(bytePerFrame);
+
                                     left-=16;
                                 }else
                                 {
@@ -846,10 +846,15 @@ nextAtom:
                                               left=0;
                                         }
                                         break;
+                                    
                                     case MKFCCR('m','s',0,0x55): // why 55 ???
+                                    case MKFCCR('m','s',0,0x11): // why 11 ???
                                     case MKFCCR('m','p','4','a'):
                                     {
-                                              audioCodec(AAC);
+                                              if(entryName==MKFCCR('m','s',0,0x11))
+                                                        audioCodec(MSADPCM)
+                                                else
+                                                        audioCodec(AAC);
                                             if(left>10)
                                             {
                                               adm_atom wave(&son);
@@ -875,6 +880,7 @@ nextAtom:
                                                           }
                                                           break;
                                                        case MKFCCR('m','s',0,0x55):
+                                                       case MKFCCR('m','s',0,0x11):
                                                         {
                                                           // We have a waveformat here
                                                           printf("[STSD]Found MS audio header:\n");
