@@ -16,18 +16,13 @@
  ***************************************************************************/
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
-
-#include "default.h"
+#include "ADM_default.h"
 #include "prefs.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit/filesel.h"
+#include "DIA_coreToolkit.h"
+#include "DIA_fileSel.h"
 #include "ADM_osSupport/ADM_quota.h"
 #include "ADM_userInterfaces/ADM_commonUI/DIA_idx_pg.h"
 #include "ADM_libraries/ADM_utilities/avidemutils.h"
@@ -75,7 +70,7 @@ uint8_t dmx_indexer(const char *mpeg,const char *file,uint32_t preferedAudio,uin
         DIA_progressIndexing *work;
         dmx_demuxer *demuxer;
 
-        char *realname=PathCanonize(mpeg);
+        char *realname=ADM_PathCanonize(mpeg);
         FILE *out;        
         DMX_TYPE mpegType;
         uint8_t  mpegTypeChar;
