@@ -15,23 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 #include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <string.h>
-
-#include "math.h"
-
-#include <ADM_assert.h>
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
 
-
 #include "fourcc.h"
-#include "ADM_openDML/ADM_openDML.h"
-#include "ADM_toolkit/toolkit.hxx"
-
+#include "ADM_openDML.h"
+#include "DIA_coreToolkit.h"
 #include "ADM_odml_audio.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
@@ -244,7 +233,7 @@ uint32_t rd;
 		// now read up each parts...
 		//____________________________
 		
-#ifdef ADM_WIN32
+#ifdef __WIN32
                 
 #define DUMP_TRACK(i) aprintf(" at %I64u (%I64x) size : %I64u (%I64x)\n", \
                                 _Tracks[i].strh.offset,\
