@@ -28,7 +28,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: ADM_xvidratectl.cpp 2862 2007-03-03 17:42:46Z mean $
+ * $Id: ADM_xvidratectl.cpp 3832 2008-03-06 18:32:32Z gruntster $
  *
  *****************************************************************************/
 
@@ -43,21 +43,19 @@
 	to fight most common problems without user's knowladge */
 #define SMART_OVERFLOW_SETTING
 #define VBV
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
 #include <math.h>
 #include <limits.h>
-#include "default.h"
-#include "ADM_osSupport/ADM_misc.h"
+#include "ADM_default.h"
 #include "ADM_osSupport/ADM_quota.h"
 #include "ADM_assert.h"
 #include "ADM_xvidr_internal.h"
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME  MODULE_XVID_RCTL
 #include "ADM_osSupport/ADM_debug.h"
-#include "ADM_osSupport/ADM_misc.h"
 
 // Glueing to avidemux
 #define DPRINTF(a,b, args...) aprintf(b,## args);
@@ -93,7 +91,7 @@
 #define INVARIANT_HEADER_PART_PVOP 2 /* factor 0.5f   */
 #define INVARIANT_HEADER_PART_BVOP 8 /* factor 0.125f */
 
-#include "ADM_xvidratectl/ADM_ratecontrol.h"
+#include "ADM_ratecontrol.h"
 
 /*****************************************************************************
  * Structures
