@@ -21,13 +21,8 @@
 #define __STDC_LIMIT_MACROS
 
 #include "config.h"
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <string.h>
-#include <math.h>
-#include <pthread.h>
-#define WIN32_CLASH
+#include "ADM_default.h"
+#include "ADM_threads.h"
 
 #ifdef USE_FFMPEG
 extern "C" {
@@ -36,32 +31,27 @@ extern "C" {
 #include "avi_vars.h"
 #include "prototype.h"
 
-
-#include "ADM_colorspace/colorspace.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
+//#include "ADM_colorspace/colorspace.h"
+#include "DIA_coreToolkit.h"
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
 
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
-
 #include "ADM_encoder/adm_encoder.h"
-//#include "ADM_codecs/ADM_divxEncode.h"
-//#include "ADM_encoder/adm_encdivx.h"
 
 #include "ADM_codecs/ADM_ffmpeg.h"
 #include "ADM_encoder/adm_encffmpeg.h"
-#include "oplug_mpegFF/oplug_vcdff.h"
+#include "../oplug_mpegFF/oplug_vcdff.h"
 
-#include "DIA_encoding.h"
+#include "ADM_userInterfaces/ADM_commonUI/DIA_encoding.h"
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
-#include "ADM_lavformat/ADM_lavformat.h"
+#include "../ADM_lavformat.h"
 
 #include "ADM_encoder/adm_encConfig.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_mplex/ADM_mthread.h"
+#include "ADM_libraries/ADM_mplex/ADM_mthread.h"
 #include "ADM_toolkit/ADM_audioQueue.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
@@ -72,14 +62,11 @@ static uint8_t *_buffer=NULL,*_outbuffer=NULL;
 static void  end (void);
 extern const char *getStrFromAudioCodec( uint32_t codec);
 
-
-extern SelectCodecType  current_codec;
-
 static char *twoPass=NULL;
 static char *twoFake=NULL;
 
 extern AVDMGenericAudioStream *mpt_getAudioStream(void);
-uint8_t prepareDualPass(uint32_t bufferSize,uint8_t *buffer,char *TwoPassLogFile,DIA_encoding *encoding_gui,Encoder *_encode,uint32_t total);
+uint8_t prepareDualPass(uint32_t bufferSize,uint8_t *buffer,DIA_encoding *encoding_gui,Encoder *_encode,uint32_t total,int reuse);
 uint8_t extractVolHeader(uint8_t *data,uint32_t dataSize,uint32_t *headerSize);
 extern void    UI_purge(void );
 /*
@@ -121,6 +108,7 @@ PacketQueue   *pq = NULL;//("MP4 audioQ",50,2*1024*1024);
 uint32_t    totalAudioSize=0;
 uint32_t sent=0;
 const char *containerTitle;
+int reuse = 0;
 int frameDelay = 0;
 bool receivedFrame = false;
 
@@ -170,17 +158,31 @@ bool receivedFrame = false;
                 strcat(TwoPassLogFile,".stat");
                 _encode->setLogFile(TwoPassLogFile,total);
 
-                if (!_encode->configure (_incoming))
+				dualPass = _encode->isDualPass();
+
+				if (dualPass)
+				{
+					FILE *tmp;
+
+					if ((tmp = fopen(TwoPassLogFile,"rt")))
+					{
+						fclose(tmp);
+
+						if (GUI_Question(QT_TR_NOOP("Reuse the existing log file?")))
+							reuse = 1;
+					}
+				}
+
+                if (!_encode->configure (_incoming, reuse))
                 {
                       GUI_Error_HIG (QT_TR_NOOP("Filter init failed"), NULL);
                      goto  stopit;
-                };
+                }
 
-                dualPass=_encode->isDualPass();
                 if(dualPass)
                 {
                        
-                        if(!prepareDualPass(bitstream.bufferSize,videoBuffer,TwoPassLogFile,encoding_gui,_encode,total))
+                        if(!prepareDualPass(bitstream.bufferSize,videoBuffer,encoding_gui,_encode,total,reuse))
                                 goto stopit;
                 }else
                 {
@@ -279,10 +281,8 @@ bool receivedFrame = false;
 			  {
 				  bitstream.cleanup(frame);
 
-#ifdef USE_X264
-				  if (current_codec == CodecX264)
+				  if (videoCodecGetType() == CodecExternal && strcmp(videoCodecPluginGetGuid(), "32BCB447-21C9-4210-AE9A-4FCE6C8588AE") == 0)
 					  bitstream.dtsFrame = UINT32_MAX;	// let libavformat calculate it
-#endif
 
 				  if (frame + frameDelay >= total)
 				  {
@@ -403,26 +403,16 @@ stopit:
            deleteAudioFilter (audio);
            return r;
 }
-uint8_t prepareDualPass(uint32_t bufferSize,uint8_t *buffer,char *TwoPassLogFile,DIA_encoding *encoding_gui,Encoder *_encode,uint32_t total)
+uint8_t prepareDualPass(uint32_t bufferSize,uint8_t *buffer,DIA_encoding *encoding_gui,Encoder *_encode,uint32_t total,int reuse)
 {
       uint32_t len, flag;
-      FILE *tmp;
-      uint8_t reuse=0,r;
+      uint8_t r;
       ADMBitstream bitstream(0);
 	  int frameDelay = 0;
 	  bool receivedFrame = false;
       
         aprintf("\n** Dual pass encoding**\n");
 
-        if((tmp=fopen(TwoPassLogFile,"rt")))
-        {
-                fclose(tmp);
-                if(GUI_Question(QT_TR_NOOP("\n Reuse the existing log-file ?")))
-                {
-                        reuse=1;
-                }
-        }
-        
         if(!reuse)
         {
                 encoding_gui->setPhasis (QT_TR_NOOP("1st Pass"));
@@ -443,10 +433,8 @@ uint8_t prepareDualPass(uint32_t bufferSize,uint8_t *buffer,char *TwoPassLogFile
 					{
 						bitstream.cleanup(frame);
 
-#ifdef USE_X264
-						if (current_codec == CodecX264)
+						if (videoCodecGetType() == CodecExternal && strcmp(videoCodecPluginGetGuid(), "32BCB447-21C9-4210-AE9A-4FCE6C8588AE") == 0)
 							bitstream.dtsFrame = UINT32_MAX;	// let libavformat calculate it
-#endif
 
 						if (frame + frameDelay >= total)
 						{
