@@ -18,75 +18,41 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
-#include <stdio.h>
-#include <stdlib.h>
 
-#include <string.h>
-#include <math.h>
-#include <pthread.h>
-#define WIN32_CLASH
+#include "config.h"
+
 #ifdef USE_FFMPEG
+#include "ADM_default.h"
+#include "ADM_threads.h"
+
 extern "C" {
 #include "ADM_lavcodec.h"
-};
+}
+
 #include "avi_vars.h"
-#include "prototype.h"
-
-
-#include "ADM_colorspace/colorspace.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
-
+#include "DIA_coreToolkit.h"
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
-
 #include "ADM_encoder/adm_encoder.h"
-//#include "ADM_codecs/ADM_divxEncode.h"
-//#include "ADM_encoder/adm_encdivx.h"
 
-#include "ADM_codecs/ADM_ffmpeg.h"
-#include "ADM_encoder/adm_encffmpeg.h"
-#include "ADM_encoder/adm_encmpeg2enc.h"
-#include "ADM_encoder/adm_encRequant.h"
-#include "oplug_mpegFF/oplug_vcdff.h"
+#include "../oplug_mpegFF/oplug_vcdff.h"
 
-#include "DIA_encoding.h"
+#include "ADM_userInterfaces/ADM_commonUI/DIA_encoding.h"
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
-#include "ADM_lavformat/ADM_lavformat.h"
+#include "../ADM_lavformat.h"
 
 #include "ADM_encoder/adm_encConfig.h"
-#include "ADM_encoder/ADM_vidEncode.hxx"
-
-#include "ADM_osSupport/ADM_threads.h"
-#include "ADM_mplex/ADM_mthread.h"
-#warning REMOVE unistd
-#include "unistd.h"
-
-
-
-static uint8_t *_buffer=NULL,*_outbuffer=NULL;
-static void  end (void);
-extern const char *getStrFromAudioCodec( uint32_t codec);
-
-extern COMPRES_PARAMS ffmpeg1Codec,ffmpeg2DVDCodec,ffmpeg2SVCDCodec,RequantCodec;	
-extern FFcodecSetting ffmpeg1Extra,ffmpeg2DVDExtra,ffmpeg2SVCDExtra;
-extern COMPRES_PARAMS SVCDCodec, DVDCodec,VCDCodec;
-
-extern uint8_t    isMpeg12Compatible (uint32_t fourcc);
-
-
-extern SelectCodecType  current_codec;
-
-static char *twoPass=NULL;
-static char *twoFake=NULL;
-
+#include "ADM_libraries/ADM_mplex/ADM_mthread.h"
 
+static uint8_t *_buffer = NULL, *_outbuffer = NULL;
+static void end(void);
+extern const char *getStrFromAudioCodec(uint32_t codec);
 
+extern SelectCodecType videoCodecGetType(void);
 
+static char *twoPass = NULL;
+static char *twoFake = NULL;
 
 uint8_t oplug_mpegff(const char *name, ADM_OUT_FORMAT type)
 {
@@ -108,7 +74,8 @@ uint32_t  sample_target=0;
 uint32_t  total_sample=0;
 ADMBitstream bitstream(0);
 uint32_t audioSum=0;
-DIA_encoding  *encoding;
+DIA_encoding  *encoding = NULL;
+int reuse = 0;
 
         twoPass=new char[strlen(name)+6];
         twoFake=new char[strlen(name)+6];
@@ -166,7 +133,9 @@ DIA_encoding  *encoding;
                 // Check
                 WAVHeader *hdr=audio->getInfo();	
                 audio_encoding=hdr->encoding;
-                if(current_codec==CodecXVCD ||current_codec==CodecVCD)
+
+                if (videoCodecGetType() == CodecXVCD || videoCodecGetType() == CodecVCD ||
+					(videoCodecGetType() == CodecExternal && strcmp(videoCodecPluginGetGuid(), "85FC9CAC-CE6C-4aa6-9D5F-352D6349BA3E") == 0))	// MPEG-1 plugin
                 {
                         if(hdr->frequency!=44100 ||  hdr->encoding != WAV_MP2)
                         {
@@ -200,51 +169,22 @@ DIA_encoding  *encoding;
             }
          }        
         // Create muxer
-       
-       
-        switch(current_codec)
-        {
-                
-                case CodecXVCD:
-                        encoder=new EncoderFFMPEGMpeg1(FF_MPEG1,&ffmpeg1Codec);
-                        printf("\n Using ffmpeg mpeg1 encoder\n");
-                        break;
-                case CodecXSVCD:
-                        encoder=new EncoderFFMPEGMpeg1(FF_MPEG2,&ffmpeg2SVCDCodec);
-                        printf("\n Using ffmpeg mpeg2 encoder\n");
-                        break;
-                case CodecXDVD:
-                        encoder=new EncoderFFMPEGMpeg1(FF_MPEG2,&ffmpeg2DVDCodec);
-                        printf("\n Using ffmpeg mpeg2 encoder (DVD)\n");
-                        break;
-                case CodecDVD:
-                  encoder=new EncoderMpeg2enc(MPEG2ENC_DVD,&DVDCodec);
-                  printf("\n Using mpeg2enc encoder (DVD)\n");
-                  break;
-                case CodecRequant:
-                  if(!isMpeg12Compatible(avifileinfo->fcc))
-                  {
-                    GUI_Error_HIG("Incompatible Input","The input file must be mpeg2 to be able to use requant!");
-                    return 0; // Fixme, do some cleanup 
-                  }
-                  encoder=new EncoderRequant(&RequantCodec);
-                  printf("\n Using mpeg2 requant\n");
-                  break;
-                break;
-                case CodecSVCD:
-                  encoder=new EncoderMpeg2enc(MPEG2ENC_SVCD,&SVCDCodec);
-                  printf("\n Using mpeg2enc encoder (SVCD)\n");
-                  break;
-                case CodecVCD:
-                  encoder=new EncoderMpeg2enc(MPEG2ENC_VCD,&VCDCodec);
-                  printf("\n Using mpeg2enc encoder (VCD)\n");
-                  break;
-                default:
-                ADM_assert(0);
-      }
+       encoder = getVideoEncoder(_w, _h, 0);
+
+	   if (encoder == NULL)
+		   return 0;
 
       encoder->setLogFile(twoPass,total);
-      if(!encoder->configure(_incoming))
+
+	  if (encoder->isDualPass())
+	  {
+		  printf("Verifying log file\n");
+
+		  if (encoder->verifyLog(twoPass, total) && GUI_Question(QT_TR_NOOP("Reuse the existing log file?")))
+			  reuse = 1;
+	  }
+
+      if(!encoder->configure(_incoming, reuse))
               goto finishvcdff;
 
       _buffer=new uint8_t[_page]; // Might overflow if _page only
@@ -254,7 +194,7 @@ DIA_encoding  *encoding;
       ADM_assert(  _outbuffer);
 
       encoding =new DIA_encoding(_fps1000);
-      switch(current_codec)
+      switch (videoCodecGetType())
       {
           case CodecVCD:
             encoding->setCodec(QT_TR_NOOP("libmpeg2enc VCD"));
@@ -277,7 +217,9 @@ DIA_encoding  *encoding;
           case CodecRequant:
             encoding->setCodec(QT_TR_NOOP("MPEG Requantizer"));
             break;
-          
+          case CodecExternal:
+            encoding->setCodec(encoder->getDisplayName());
+            break;
           default:
             ADM_assert(0);
 	}
@@ -297,15 +239,6 @@ DIA_encoding  *encoding;
         // pass 1
         if(encoder->isDualPass()) //Cannot be requant
         {
-                        FILE *fd;
-                        uint8_t reuse=0;
-                        
-                        printf("Verifying log file\n");
-                        if(encoder->verifyLog(twoPass,total))
-                          if(GUI_Question(QT_TR_NOOP("Reuse log file ?")))
-                                {
-                                        reuse=1;
-                                }
                         if(!reuse)
                         {
                                 encoding->setPhasis (QT_TR_NOOP("Pass 1/2"));
@@ -505,7 +438,10 @@ DIA_encoding  *encoding;
         ret=1;
 finishvcdff:
         printf("[MPEGFF] Finishing..\n");
-        delete encoding;
+
+		if (encoding)
+			delete encoding;
+
         end();
 
         if(file)
@@ -566,4 +502,4 @@ AVDMGenericAudioStream *mpt_getAudioStream (void)
   return audio;
 }
 #endif	
-// EOF
+// EOF
\ No newline at end of file
