@@ -15,7 +15,7 @@ at amistry@am-productions.biz
 // Construction/Destruction
 //////////////////////////////////////////////////////////////////////
 
-#ifndef ADM_WIN32  // def __unix__
+#if defined(__unix__) || defined(__APPLE__)
 int CDirectorySearch::_findnext(unsigned long int hDir,_finddata_t *pfdData)
 {// begin _findnext
 	if(!hDir || hDir == 0xFFFFFFFF)
@@ -26,7 +26,7 @@ int CDirectorySearch::_findnext(unsigned long int hDir,_finddata_t *pfdData)
 	if(!pEntry)
 		return -1;
 	std::string sFilePath = "";
-#if defined( __linux__) || defined(__macosx__) || defined(ADM_WIN32)
+#if defined( __linux__) || defined(__macosx__) || defined(__MINGW32__)
 	strncpy(pfdData->name,pEntry->d_name,pEntry->d_reclen);
 	// append NULL terminator
 	pfdData->name[pEntry->d_reclen] = '\0';
@@ -51,7 +51,7 @@ int CDirectorySearch::_findnext(unsigned long int hDir,_finddata_t *pfdData)
 		pfdData->attrib |= _A_SUBDIR;
 	if(S_ISCHR(stInfo.st_mode) ||
 	S_ISBLK(stInfo.st_mode) ||
-#if !defined(ADM_WIN32)	
+#if !defined(__WIN32)	
 	S_ISLNK(stInfo.st_mode) ||
 	S_ISSOCK(stInfo.st_mode) ||
 #endif
@@ -101,7 +101,7 @@ char *s;
 	const char *old=sDirectory.c_str();
 	s=new char[strlen(old)+10];
 	strcpy(s,old);
-#ifdef ADM_WIN32	
+#ifdef __WIN32	
 	strcat(s,"\\*");
 #endif
 	
@@ -113,9 +113,7 @@ char *s;
 		printf("Find first failed\n");
 		return false;
 	}
-
 	m_sDirectory = sDirectory;
-
 	return true;
 }// end Init
 
@@ -148,7 +146,7 @@ std::string CDirectorySearch::GetFileDirectory(std::string sFilePath) const
 	for(int i = sFilePath.length()-1;i >= 0;i--)
 		if(sFilePath[i] == DIRECTORY_DELIMITOR)
 		{// begin copy directory name into buffer
-#ifdef ADM_WIN32
+#ifdef __WIN32
 			if(sFilePath[0] == DIRECTORY_DELIMITOR)
 			{
 				sFilePath.erase(0,1);
