@@ -20,9 +20,8 @@
 #include "config.h"
 
 #include <stdlib.h>
-//#include <glib.h>
 #include <signal.h>
-#ifndef ADM_WIN32
+#ifndef __WIN32
 #include <unistd.h>
 #endif
 #include <math.h>
@@ -37,19 +36,19 @@
 #include "prefs.h"
 #include "gtkgui.h"
 
-#include "ADM_toolkit/toolkit.hxx"
+
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME  MODULE_COMMANDLINE
 #include "ADM_osSupport/ADM_debug.h"
-#include "ADM_utilities/avidemutils.h"
+#include "ADM_libraries/ADM_utilities/avidemutils.h"
 
 #include "ADM_filter/vidVCD.h"
-
+#include "ADM_video/ADM_vidMisc.h"
 
 extern void filterListAll(void );
 
 extern uint8_t loadVideoCodecConf( const char *name);
-extern int A_saveJpg (char *name);
+extern int A_saveBunchJpg(const char *name);
 extern void filterLoadXml(const char *n);
 extern int A_appendAvi (const char *name);
 extern void A_saveAudio(char *name);
@@ -155,7 +154,7 @@ AUTOMATON reaction_table[]=
         {"svcd-res",		0,"set SVCD resolution",		(one_arg_type)setSVCD}              ,
         {"dvd-res",		0,"set DVD resolution",			(one_arg_type)setDVD}  ,
         {"halfd1-res",		0,"set 1/2 DVD resolution",		(one_arg_type)setHalfD1} ,  
-        {"save-jpg",		1,"save a jpeg",			(one_arg_type)A_saveJpg}        ,
+        {"save-jpg",		1,"save JPEG images",			(one_arg_type)A_saveBunchJpg},
         {"begin",		1,"set start frame",			setBegin},
         {"end",			1,"set end frame",			setEnd},
         {"save-unpacked-vop",	1,"save avi, unpacking vop",(one_arg_type)A_SaveUnpackedVop},
@@ -222,16 +221,30 @@ static codec_t codec = SOME_UNKNOWN;
 int automation(void )
 
 {
-static char **argv;
-static int argc;
-static int cur;
-static int myargc;
-static three_arg_type three;
-static two_arg_type two;
-static int index;
-          argv=global_argv;
-          argc=global_argc;
-          printf("\n *** Automated : %d entries*************\n",NB_AUTO);
+	char **argv;
+	int argc, cur, myargc, index;
+	three_arg_type three;
+	two_arg_type two;
+
+	argc = global_argc;
+
+#ifdef __WIN32
+	int utf8StringLength;
+
+	argv = new char*[argc];
+
+	for (int arg = 0; arg < argc; arg++)
+	{
+		utf8StringLength = ansiStringToUtf8(global_argv[arg], -1, NULL);
+		argv[arg] = new char[utf8StringLength];
+
+		ansiStringToUtf8(global_argv[arg], -1, argv[arg]);
+	}
+#else
+	argv = global_argv;
+#endif
+
+          printf("\n *** Automated : %d entries*************\n",(int)NB_AUTO);
           // we need to process
           argc-=1;
           cur=1;
@@ -240,20 +253,8 @@ static int index;
           {
                       if(( *argv[cur]!='-') || (*(argv[cur]+1)!='-'))
                       {
-                            if(cur==1) 
-                            {
-#ifdef __WIN32
-								int utf8StringLength = ansiStringToUtf8(argv[cur], -1, NULL);
-								char utf8FileName[utf8StringLength];
-
-								ansiStringToUtf8(argv[cur], -1, utf8FileName);
-
-								A_openAvi(utf8FileName);
-#else
+                            if(cur==1)
 								A_openAvi(argv[cur]);
-#endif
-	
-                            }
                             else
                                 printf("\n Found garbage %s\n",argv[cur]);
                             cur+=1;myargc-=1;				
@@ -296,6 +297,14 @@ static int index;
           } // end while
           GUI_Verbose();
           printf("\n ********** Automation ended***********\n");
+
+#ifdef __WIN32
+	for (int arg = 0; arg < argc; arg++)
+		delete [] argv[arg];
+
+	delete argv;
+#endif
+
           return 0; // Do not call me anymore
 }
 //_________________________________________________________________________
@@ -324,9 +333,9 @@ extern void audioSetResample(uint32_t fq);
 
 void call_normalize   (char *p)
 {
-  int32_t i;
+  int i;
   sscanf(p,"%d",&i);
-        audioFilterNormalizeMode(i);	
+        audioFilterNormalizeMode((uint8_t)i);	
 }
 void call_resample    (char *p)
 {
@@ -380,36 +389,30 @@ void call_setPP(char *v,char *s)
 void call_setAudio (char *p) 	
 {
 	
-		int32_t i;
-		sscanf(p,"%ld",&i);
-		audioFilterDelay(i);	
+		int i;
+		sscanf(p,"%d",&i);
+		audioFilterDelay((int32_t)i);	
 }
 void call_audiocodec(char *p)
 {
 	if(!strcasecmp(p,"MP2"))
-		audioCodecSetcodec( AUDIOENC_MP2 );
+		audio_selectCodecByTag(WAV_MP2);
 #ifdef USE_FAAC
 	else if(!strcasecmp(p,"AAC"))
 		audioCodecSetcodec( AUDIOENC_FAAC );
 #endif
 	else if(!strcasecmp(p,"AC3"))
-		audioCodecSetcodec( AUDIOENC_AC3 );
-#ifdef HAVE_LIBMP3LAME		
+		audio_selectCodecByTag( WAV_AC3 );
 	else if(!strcasecmp(p,"MP3"))
-		 audioCodecSetcodec( AUDIOENC_MP3 );
-#endif
-	else if(!strcasecmp(p,"NONE"))
-		audioCodecSetcodec( AUDIOENC_NONE );
-	else if(!strcasecmp(p,"TWOLAME"))
-		audioCodecSetcodec( AUDIOENC_2LAME );		
-#ifdef USE_VORBIS		
+		 audio_selectCodecByTag( WAV_MP3 );
+	else if(!strcasecmp(p,"PCM"))
+		audio_selectCodecByTag( WAV_PCM );
 	else if(!strcasecmp(p,"VORBIS"))
-		audioCodecSetcodec( AUDIOENC_VORBIS );		
-#endif		
+		audio_selectCodecByTag( WAV_OGG );		
 	else if(!strcasecmp(p,"COPY"))
-		audioCodecSetcodec( AUDIOENC_COPY );		
+		audio_setCopyCodec();		
 	else{
-		audioCodecSetcodec( AUDIOENC_NONE );
+		audio_selectCodecByTag( WAV_PCM );
 		fprintf(stderr,"audio codec \"%s\" unknown.\n",p);
 	}
 }
@@ -432,9 +435,9 @@ static void call_videoconf(char *p)
 void call_audiobitrate(char *p)
 {
 
-		int32_t i;
-		sscanf(p,"%ld",&i);
-		printf("\n Audio bitrate %ld\n",i);
+		int i;
+		sscanf(p,"%d",&i);
+		printf("\n Audio bitrate %d\n",i);
 		audioFilter_SetBitrate(i);
 }
 void call_fps(char *p)
@@ -459,9 +462,9 @@ void call_fps(char *p)
 void call_autosplit(char *p)
 {
 
-		int32_t i;
-		sscanf(p,"%ld",&i);
-		ADM_aviSetSplitSize(i);
+		int i;
+		sscanf(p,"%d",&i);
+		ADM_aviSetSplitSize((uint32_t)i);
 }
 
 void setBegin(char *p) 
@@ -685,7 +688,7 @@ char *script_getVar(char *in, int *r)
 
                 }
         }
-        printf("Warning: var [%s] is unknown !\n");
+        printf("Warning: var [%s] is unknown !\n",in);
         return NULL;
 
 }
