@@ -7,32 +7,17 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
-
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <string.h>
-#include <stdio.h>
 #include <math.h>
 
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-
-#include "default.h"
+#include "ADM_toolkitGtk.h"
 #include "prefs.h"
 
-#include "ADM_toolkit_gtk/ADM_gladeSupport.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit_gtk/toolkit_gtk.h"
-#include "ADM_toolkit_gtk/toolkit_gtk_include.h"
+#include "DIA_coreToolkit.h"
 #include "ADM_libraries/ADM_utilities/avidemutils.h"
 #include "ADM_userInterfaces/ADM_commonUI/DIA_working.h"
-#include "ADM_toolkit_gtk/ADM_tray_gtk.h"
-
-#include "ADM_assert.h" 
-
 #include "DIA_encoding.h"
+#include "ADM_video/ADM_vidMisc.h"
+#include "../ADM_toolkit_gtk/ADM_tray_gtk.h"
 
 static GtkWidget *dialog=NULL;
 static GtkWidget	*create_dialog1 (void);
@@ -44,7 +29,7 @@ static gint on_destroy_abort(GtkObject * object, gpointer user_data);
 static void DIA_stop( void);
 static void change_priority(void);
 
-#ifndef ADM_WIN32
+#ifndef __WIN32
 static void shutdown_toggled(void);
 #endif
 
@@ -67,7 +52,7 @@ uint32_t useTray=0;
         
         gtk_register_dialog(dialog);
 
-	#ifndef ADM_WIN32
+	#ifndef __WIN32
 		// check for root privileges
 		if (getuid() != 0)
 		{
@@ -95,7 +80,7 @@ uint32_t useTray=0;
 
 		prefs->get(PRIORITY_ENCODING,&priority);
 
-	#ifndef ADM_WIN32
+	#ifndef __WIN32
 		// check for root privileges
 		if (getuid() == 0)
 		{
@@ -153,7 +138,7 @@ void DIA_stop( void)
 
 void change_priority(void)
 {
-#ifndef ADM_WIN32
+#ifndef __WIN32
 	if (getuid() != 0)
 	{
 		gtk_signal_disconnect_by_func(GTK_OBJECT(WID(combobox_priority)), GTK_SIGNAL_FUNC(change_priority), NULL);
@@ -173,7 +158,7 @@ void change_priority(void)
 	setpriority(PRIO_PROCESS, 0, ADM_getNiceValue(priorityLevel));
 }
 
-#ifndef ADM_WIN32
+#ifndef __WIN32
 void shutdown_toggled(void)
 {
 	if (getuid() != 0)
@@ -382,7 +367,7 @@ uint32_t tim;
 
           sprintf(string,QT_TR_NOOP("%d%%"),(int)(100*f));
           
-          if(isQuiet()) printf("[Encoding]%s\n",string);
+          if(GUI_isQuiet()) printf("[Encoding]%s\n",string);
               gtk_progress_bar_set_text       (GTK_PROGRESS_BAR(WID(progressbar1)), string);
           
         _totalSize=_audioSize+_videoSize;
