@@ -543,52 +543,57 @@ void updateFilterList (void)
     gtk_list_store_clear (stores[0]);
     for (uint32_t i = 1; i < nb_active_filter; i++)
     {
-        gtk_list_store_append (stores[0], &iter);
-        fil=videofilters[i].tag;
-         const char * name = filterGetNameFromTag(fil);
-         const char * conf = videofilters[i].filter->printConf ();
-         int namelen = strlen (name);
-         while (*conf == ' ')
-             ++conf;
-         if (strncasecmp (name, conf, namelen) == 0)
-         {
-             conf += namelen;
-             while (*conf == ' ' || *conf == ':')
-                 ++conf;
-         }
-         const char * smallstart = "";
-         const char * smallend = "";
-         const char * namesmallstart = "";
-         const char * namesmallend = "";
-         int conflen = strlen (conf);
-         if (conflen > 120)
-         {
-             smallstart = "<small>";
-             smallend = "</small>";
-             if (conflen > 180)
-             {
-                 namesmallstart = smallstart;
-                 namesmallend = smallend;
-             }
-         }
+		fil = videofilters[i].tag;
 
-        str = g_strconcat("<span  weight=\"bold\">",
-                            namesmallstart,
-                            name,
-                            namesmallend,
-                            "</span>\n",
-                             "<span size=\"smaller\">",
-                             smallstart,
-                             conf,
-                             smallend,
-                             "</span>",  NULL);
+		if (fil != VF_INTERNAL)
+		{
+			gtk_list_store_append (stores[0], &iter);
 
-        gtk_list_store_set (stores[0], &iter,
-                            0, str,
-                            1, videofilters[i].tag,
-                            2, videofilters[i].conf,
-                            -1);
-        g_free(str);
+			const char * name = filterGetNameFromTag(fil);
+			const char * conf = videofilters[i].filter->printConf ();
+			int namelen = strlen (name);
+			while (*conf == ' ')
+				++conf;
+			if (strncasecmp (name, conf, namelen) == 0)
+			{
+				conf += namelen;
+				while (*conf == ' ' || *conf == ':')
+					++conf;
+			}
+			const char * smallstart = "";
+			const char * smallend = "";
+			const char * namesmallstart = "";
+			const char * namesmallend = "";
+			int conflen = strlen (conf);
+			if (conflen > 120)
+			{
+				smallstart = "<small>";
+				smallend = "</small>";
+				if (conflen > 180)
+				{
+					namesmallstart = smallstart;
+					namesmallend = smallend;
+				}
+			}
+
+			str = g_strconcat("<span  weight=\"bold\">",
+				namesmallstart,
+				name,
+				namesmallend,
+				"</span>\n",
+				"<span size=\"smaller\">",
+				smallstart,
+				conf,
+				smallend,
+				"</span>",  NULL);
+
+			gtk_list_store_set (stores[0], &iter,
+				0, str,
+				1, videofilters[i].tag,
+				2, videofilters[i].conf,
+				-1);
+			g_free(str);
+		}
     }
     g_signal_handler_unblock(stores[0], row_inserted_id);
     g_signal_handler_unblock(stores[0], row_deleted_id);
