@@ -14,41 +14,32 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include "default.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <math.h>
+#include "ADM_toolkitGtk.h"
 
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
+#include "../ADM_render/GUI_render.h"
+#include "gui_action.hxx"
 
-#include "../ADM_assert.h"
-#include "ADM_commonUI/GUI_render.h"
-#include "../gui_action.hxx"
-
-#include "../ADM_osSupport/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_UI
-#include "../ADM_osSupport/ADM_debug.h"
-#include "../ADM_toolkit_gtk/toolkit_gtk.h"
-#include "../ADM_toolkit_gtk/ADM_gladeSupport.h"
+#include "ADM_osSupport/ADM_debug.h"
 
-#include "../ADM_codecs/ADM_codec.h"
-#include "ADM_commonUI/GUI_ui.h"
+#include "ADM_codecs/ADM_codec.h"
+#include "../ADM_commonUI/GUI_ui.h"
 
-#include "../ADM_toolkit/filesel.h"
-#include "../ADM_editor/ADM_Video.h"
-#include "../ADM_osSupport/ADM_misc.h"
-#include "../prefs.h"
+#include "DIA_fileSel.h"
+#include "ADM_editor/ADM_Video.h"
+
+#include "prefs.h"
 #include "../ADM_toolkit_gtk/gtkmarkscale.h"
 #include "../ADM_toolkit_gtk/jogshuttle.h"
 #include "../ADM_toolkit_gtk/ADM_jogshuttle.h"
 #include "gtkgui.h"
-
+#include "DIA_coreToolkit.h"
+#include "ADM_userInterfaces/ADM_render/GUI_renderInternal.h"
 extern uint8_t UI_getPhysicalScreenSize(void* window, uint32_t *w,uint32_t *h);
-
-
+extern void ADM_initUIGtk(GtkWidget *guiRootWindow);
+extern  ADM_RENDER_TYPE UI_getPreferredRender(void);;
 #define WOD(x) lookup_widget (guiRootWindow,#x)
 
 void frame2time(uint32_t frame, uint32_t fps, uint16_t * hh, uint16_t * mm,
@@ -92,6 +83,9 @@ static int update_ui=0;
 void GUI_gtk_grow_off(int onff);
 static void GUI_initCustom(void);
 const char * GUI_getCustomScript(uint32_t nb);
+uint32_t audioEncoderGetNumberOfEncoders(void);
+const char  *audioEncoderGetDisplayName(uint32_t i);
+
 #ifdef HAVE_AUDIO
 extern uint8_t AVDM_setVolume(int volume);
 #endif
@@ -125,14 +119,12 @@ extern GtkWidget	*create_mainWindow (void);
 extern void guiCallback(GtkMenuItem * menuitem, gpointer user_data);
 extern void HandleAction(Action act);
 extern gboolean UI_on_key_press(GtkWidget *widget, GdkEventKey* event, gpointer user_data);
-extern void fileReadWrite(SELFILE_CB *cb, int rw, const char *name);
+extern char *actual_workbench_file;
+extern void FileSel_ReadWrite(SELFILE_CB *cb, int rw, const char *name, const char *actual_workbench_file);
 
 // To build vcodec
-extern uint32_t encoderGetNbEncoder(void);
+extern int encoderGetEncoderCount(void);
 extern const char* encoderGetIndexedName(uint32_t i);
-// To build a codec
-uint32_t audioFilterGetNbEncoder(void);
-const char* audioFilterGetIndexedName(uint32_t i);
 //
 static uint8_t  bindGUI( void );
 static gboolean destroyCallback(GtkWidget * widget,	  GdkEvent * event, gpointer user_data);
@@ -145,7 +137,7 @@ static void GUI_initCursor( void );
  void UI_BusyCursor( void );
  void UI_NormalCursor( void );
 // For checking if Slider shift key is pressed
-gboolean SliderIsShifted = FALSE;
+bool SliderIsShifted = FALSE;
 gboolean UI_SliderPressed(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 gboolean UI_SliderReleased(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 gboolean UI_returnFocus(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
@@ -314,7 +306,7 @@ uint32_t w,h;
 #endif
 
 		gtk_register_dialog(guiRootWindow);
-					
+		ADM_initUIGtk(guiRootWindow);			
 		// and seek global sub entity
 		ret= bindGUI();		
 		if(ret) gtk_widget_show(guiRootWindow);
@@ -333,6 +325,9 @@ uint32_t w,h;
                 physical_jog_shuttle = &(PhysicalJogShuttle::getInstance());
                 physical_jog_shuttle->registerCBs (NULL, jogButton, jogDial, jogRing);
 #endif 
+                
+                
+                
 	return ret;
 }
 
@@ -494,7 +489,7 @@ uint8_t  bindGUI( void )
 	const char *name;
         GtkComboBox     *combo_box;
 
-                nbVid=encoderGetNbEncoder();
+                nbVid=encoderGetEncoderCount();
                 combo_box=GTK_COMBO_BOX(lookup_widget(guiRootWindow,VIDEO_WIDGET));
                 gtk_combo_box_remove_text(combo_box,0);
                 printf("Found %d video encoder\n",nbVid);
@@ -509,18 +504,18 @@ uint8_t  bindGUI( void )
         // And A codec
         // Finally add video codec...
         uint32_t nbAud;
-
-                nbAud=audioFilterGetNbEncoder();
+                nbAud=audioEncoderGetNumberOfEncoders();
                 combo_box=GTK_COMBO_BOX(lookup_widget(guiRootWindow,AUDIO_WIDGET));
                 gtk_combo_box_remove_text(combo_box,0);
                 printf("Found %d audio encoder\n",nbAud);		       
                 for(uint32_t i=0;i<nbAud;i++)
                 {
-                        name=audioFilterGetIndexedName(i);
+                        name=audioEncoderGetDisplayName(i); //audioFilterGetIndexedName(i);
+                        printf("Found %d %s audio encoder\n",i,name);		       
                         gtk_combo_box_append_text      (combo_box,QT_TR_NOOP(name));	
                 }
         gtk_combo_box_set_active(combo_box,0);
-	on_audio_change();
+        on_audio_change();
         /*   Fill in output format window */
         uint32_t nbFormat;
 
@@ -631,7 +626,7 @@ void GUI_initCustom(void )
 
   for(int i=0;i<ADM_nbCustom;i++)
   {
-    go = gtk_menu_item_new_with_mnemonic (GetFileName(customNames[i]));
+    go = gtk_menu_item_new_with_mnemonic (ADM_GetFileName(customNames[i]));
     gtk_widget_show (go);
     gtk_container_add (GTK_CONTAINER (menu), go);
     rank=ACT_CUSTOM_BASE+i;
@@ -867,10 +862,10 @@ void UI_focusAfterActivate(GtkMenuItem * menuitem, gpointer user_data)
 	// return focus to window once Enter has been pressed
 	UNUSED_ARG(menuitem);
     Action act;
-    uint32_t aint;
+    intptr_t aint;
     if(update_ui) return; // no event sent
 
-    aint = (long int) user_data;
+    aint = (intptr_t) user_data;
     act = (Action) aint;
 
 	HandleAction(act);
@@ -933,10 +928,10 @@ void guiCallback(GtkMenuItem * menuitem, gpointer user_data)
 {
     UNUSED_ARG(menuitem);
     Action act;
-    uint32_t aint;
+    intptr_t aint;
     if(update_ui) return; // no event sent
 
-    aint = (long int) user_data;
+    aint = (intptr_t) user_data;
     act = (Action) aint;
     if(act==ACT_Scale)
     {
@@ -1201,12 +1196,13 @@ void DNDDataReceived( GtkWidget *widget, GdkDragContext *dc,
     for(int i=0;i<current-1;i++)
     {
       printf("DND : %d %s\n",i,names[i]);
+
       const char *filename = names[i];
 
 	  if (avifileinfo)
-		  fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_appendAvi), 0, filename);
+		  FileSel_ReadWrite(reinterpret_cast <void (*)(const char *)> (A_appendAvi), 0, filename, actual_workbench_file);
 	  else
-		  fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, filename);
+		  FileSel_ReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, filename, actual_workbench_file);
 
       ADM_dealloc(names[i]); 
     }
@@ -1302,12 +1298,30 @@ gboolean UI_SliderReleased(GtkWidget *widget, GdkEventButton *event, gpointer us
 	SliderIsShifted=FALSE;
 	return FALSE;
 }
+/****/
 extern int global_argc;
 extern char **global_argv;
 typedef gboolean GCALL       (void *);
 extern int automation(void );
+//********************************************
 extern void initTranslator(void);
+static const UI_FUNCTIONS_T UI_Hooks=
+    {
+        ADM_RENDER_API_VERSION_NUMBER,
+        UI_purge,
+        UI_getWindowInfo,
+        UI_updateDrawWindowSize,
+        UI_rgbDraw,
+        UI_getDrawWidget,
+        UI_getPreferredRender
+        
+    };
 
+/**
+ *      \fn UI_Init
+ *      \brief Entry point. Initialize renderLib.
+ * 
+ */
 int UI_Init(int argc, char **argv)
 {
 	initTranslator();
@@ -1321,23 +1335,36 @@ int UI_Init(int argc, char **argv)
     global_argc=argc;
     global_argv=argv;
       
+    
+
+    ADM_renderLibInit(&UI_Hooks);
+    
     gtk_init(&global_argc, &global_argv);
     gdk_rgb_init();
     
     
 }
 static void trampoline(void);
+static void gtk_fatalFunction(const char *title, const char *info)
+{
+    GUI_Info_HIG(ADM_LOG_IMPORTANT,title,info);
+}
+extern void saveCrashProject(void);
 int UI_RunApp(void)
 {
     if (global_argc >= 2)
     {
       g_timeout_add(200,(GCALL *)trampoline,NULL);
     }
+    // Install our crash handler
+    ADM_setCrashHook(&saveCrashProject, &gtk_fatalFunction);
     checkCrashFile();
     gtk_main();
     gdk_threads_leave();
 
 }
+
+
 void trampoline(void)
 {
     ADM_usleep(100000); // let gtk start
