@@ -11,40 +11,19 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
 
-
-#include "ui_props.h"
-#include "default.h"
-#include "avidemutils.h"
+#include "Q_props.h"
 #include "avi_vars.h"
-#include "ADM_osSupport/ADM_misc.h"
-#include "../ADM_toolkit/qtToolkit.h"
+#include "avidemutils.h"
+#include "ADM_video/ADM_vidMisc.h"
+#include "ADM_toolkitQt.h"
 
 static const char *yesno[2]={QT_TR_NOOP("No"),QT_TR_NOOP("Yes")};
 extern const char *getStrFromAudioCodec( uint32_t codec);
- class propWindow : public QDialog
- {
-     Q_OBJECT
 
- public:
-     propWindow(QWidget *parent);
-     Ui_Dialog ui;
- public slots:
-  
- private slots:
-   
-
- private:
-     
- };
-
-
-propWindow::propWindow(QWidget *parent)     : QDialog(parent)
+propWindow::propWindow(QWidget *parent) : QDialog(parent)
  {
      ui.setupUi(this);
      uint8_t gmc, qpel,vop;
@@ -97,10 +76,10 @@ propWindow::propWindow(QWidget *parent)     : QDialog(parent)
               switch (wavinfo->channels)
                 {
                 case 1:
-                    sprintf(text, QT_TR_NOOP("Mono"));
+		  sprintf(text, "%s", QT_TR_NOOP("Mono"));
                     break;
                 case 2:
-                    sprintf(text, QT_TR_NOOP("Stereo"));
+                    sprintf(text, "%s", QT_TR_NOOP("Stereo"));
                     break;
                 default:
                     sprintf(text, "%d",wavinfo->channels);
