@@ -1,19 +1,30 @@
-#include "config.h"
+/**
+    \file alert_qt4
+   copyright            : (C) 2007 by mean
+    email                : Mean/fixounet@free.fr
+ ***************************************************************************/
 
-#ifdef HAVE_GETTEXT
-#  include <libintl.h>
-#endif
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 
-#include <QMessageBox>
-
-#include "default.h"
+#include <QtGui/QDialog>
+#include <QtGui/QMessageBox>
+#include "ADM_default.h"
+#include "DIA_coreToolkit.h"
+#include "DIA_coreUI_internal.h"
 #include "prefs.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "../ADM_toolkit/qtToolkit.h"
+#include "ADM_toolkitQt.h"
 
 static int beQuiet=0;
 extern QWidget *QuiMainWindows;
-
+namespace ADM_Qt4CoreUIToolkit
+{
 //****************************************************************************************************
 void            GUI_Alert(const char *alertstring)
 {
@@ -32,7 +43,7 @@ void            GUI_Info(const char *alertstring)
 }
 
 //****************************************************************************************************
-void GUI_Info_HIG(const ADM_LOG_LEVEL level,const char *primary, const char *secondary_format, ...)
+void GUI_Info_HIG(const ADM_LOG_LEVEL level,const char *primary, const char *secondary_format)
 {
 	uint32_t msglvl = 2;
 	QString alertString;
@@ -49,15 +60,8 @@ void GUI_Info_HIG(const ADM_LOG_LEVEL level,const char *primary, const char *sec
 		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big>";
 	else
 	{
-		va_list ap;
-		va_start(ap, secondary_format);
-
-		alertString.vsprintf(secondary_format, ap);
-		alertString = QString::fromUtf8(alertString.toAscii().constData());
-		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + alertString;
+		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + QString::fromUtf8(secondary_format);
 		alertString.replace("\n", "<br>");
-
-		va_end(ap);
 	}
 
 	QMessageBox::StandardButton reply;
@@ -66,7 +70,7 @@ void GUI_Info_HIG(const ADM_LOG_LEVEL level,const char *primary, const char *sec
 		alertString, QMessageBox::Ok);
 }
 //****************************************************************************************************
-void GUI_Error_HIG(const char *primary, const char *secondary_format, ...)
+void GUI_Error_HIG(const char *primary, const char *secondary_format)
 {
 	uint32_t msglvl = 2;
 	QString alertString;
@@ -83,15 +87,8 @@ void GUI_Error_HIG(const char *primary, const char *secondary_format, ...)
 		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big>";
 	else
 	{
-		va_list ap;
-		va_start(ap, secondary_format);
-
-		alertString.vsprintf(secondary_format, ap);
-		alertString = QString::fromUtf8(alertString.toAscii().constData());
-		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + alertString;
+		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + QString::fromUtf8(secondary_format);
 		alertString.replace("\n", "<br>");
-
-		va_end(ap);
 	}
 
 	QMessageBox::StandardButton reply;
@@ -100,7 +97,7 @@ void GUI_Error_HIG(const char *primary, const char *secondary_format, ...)
 		alertString, QMessageBox::Ok);
 }
 //****************************************************************************************************
-int GUI_Confirmation_HIG(const char *button_confirm, const char *primary, const char *secondary_format, ...)
+int GUI_Confirmation_HIG(const char *button_confirm, const char *primary, const char *secondary_format)
 {
 	QString alertString;
 
@@ -114,15 +111,8 @@ int GUI_Confirmation_HIG(const char *button_confirm, const char *primary, const
 		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big>";
 	else
 	{
-		va_list ap;
-		va_start(ap, secondary_format);
-
-		alertString.vsprintf(secondary_format, ap);
-		alertString = QString::fromUtf8(alertString.toAscii().constData());
-		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + alertString;
+		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + QString::fromUtf8(secondary_format);
 		alertString.replace("\n", "<br>");
-
-		va_end(ap);
 	}
 
 	QMessageBox::StandardButton reply;
@@ -136,7 +126,7 @@ int GUI_Confirmation_HIG(const char *button_confirm, const char *primary, const
 	return 0;
 }
 //****************************************************************************************************
-int GUI_YesNo(const char *primary, const char *secondary_format, ...)
+int GUI_YesNo(const char *primary, const char *secondary_format)
 {
 	uint32_t msglvl = 2;
 	QString alertString;
@@ -151,15 +141,8 @@ int GUI_YesNo(const char *primary, const char *secondary_format, ...)
 		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big>";
 	else
 	{
-		va_list ap;
-		va_start(ap, secondary_format);
-
-		alertString.vsprintf(secondary_format, ap);
-		alertString = QString::fromUtf8(alertString.toAscii().constData());
-		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + alertString;
+		alertString = "<big><b>" + QString::fromUtf8(primary) + "</b></big><br><br>" + QString::fromUtf8(secondary_format);
 		alertString.replace("\n", "<br>");
-
-		va_end(ap);
 	}
 
 	QMessageBox::StandardButton reply;
@@ -226,7 +209,7 @@ uint8_t  GUI_getDoubleValue(double *valye, float min, float max, const char *tit
   return 0; 
 }
 //****************************************************************************************************
-uint8_t		isQuiet(void)
+uint8_t		GUI_isQuiet(void)
 {
     return beQuiet;
 }
@@ -241,4 +224,24 @@ void            GUI_Quiet(void)
   beQuiet=1;
 }
 //****************************************************************************************************
+}
+
+static CoreToolkitDescriptor Qt4CoreToolkitDescriptor=
+{
+		&ADM_Qt4CoreUIToolkit::GUI_Info_HIG,
+		&ADM_Qt4CoreUIToolkit::GUI_Error_HIG,
+		&ADM_Qt4CoreUIToolkit::GUI_Confirmation_HIG,
+		&ADM_Qt4CoreUIToolkit::GUI_YesNo,
+		&ADM_Qt4CoreUIToolkit::GUI_Question,
+		&ADM_Qt4CoreUIToolkit::GUI_Alternate,
+		&ADM_Qt4CoreUIToolkit::GUI_Verbose,
+		&ADM_Qt4CoreUIToolkit::GUI_Quiet,
+		&ADM_Qt4CoreUIToolkit::GUI_isQuiet
+};
+
+void InitCoreToolkit(void )
+{
+	DIA_toolkitInit(&Qt4CoreToolkitDescriptor);
+	
+}
 //EOF
