@@ -6,6 +6,8 @@
     * I.e.
     0--1000 : QT4 internal
     2000-3000: Filters
+                 Each family starts a category*100 then filter in the order they are in categories
+                 ** 10 Categories MAX !!
     3000-4000  filterFamilyClick Filter
     8000-9000  Active Filter
     
@@ -22,39 +24,25 @@
  ***************************************************************************/
 
 #include "config.h"
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include <vector>
-#include <QtGui>
 
-#define Ui_Dialog Ui_mainFilterDialog
-#include "ui_mainfilter.h"
-#undef Ui_Dialog
-
-#include "Q_seekablePreview.h"
-
-#include "default.h"
-#include "ADM_toolkit/filesel.h"
+#include "Q_mainfilter.h"
+#include "ADM_default.h"
+#include "DIA_fileSel.h"
 
 # include "prefs.h"
 #include "ADM_audiodevice/audio_out.h"
-#include "ADM_audio/ADM_audiodef.h"
 
-#include "ADM_assert.h"
-#include "GUI_render.h"
-#include "ADM_osSupport/ADM_cpuCap.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_userInterfaces/ADM_render/GUI_render.h"
+
+#include "DIA_coreToolkit.h"
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
 #include "ADM_video/ADM_vidPartial.h"
 #include "ADM_filter/vidVCD.h"
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
-#include "../ADM_toolkit/qtToolkit.h"
+#include "DIA_factory.h"
+#include "ADM_toolkitQt.h"
 
 /*******************************************************/
 #define NB_TREE 8
@@ -67,9 +55,11 @@ static int max=0;
 #define ACTIVE_FILTER_BASE    3000
 /******************************************************/
 extern QWidget *QuiMainWindows;
-extern FILTER videofilters[MAX_FILTER];
+extern FILTER videofilters[VF_MAX_FILTER];
 extern uint32_t nb_active_filter;
-extern std::vector <FILTER_ENTRY> allfilters;
+extern std::vector <FilterDescriptor *> allfilters;
+extern std::vector <FilterDescriptor *> filterCategories[VF_MAX];
+
 
 extern const char  *filterGetNameFromTag(VF_FILTERS tag);
 extern ADM_Composer *video_body;
@@ -77,124 +67,59 @@ extern AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *co
 extern uint32_t curframe;
 /*******************************************************/
 
-class FilterItemEventFilter : public QObject
+FilterItemEventFilter::FilterItemEventFilter(QWidget *parent) : QObject(parent) {}
+
+bool FilterItemEventFilter::eventFilter(QObject *object, QEvent *event) 
 {
-	Q_OBJECT
+	QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
 
-protected:
-	bool eventFilter(QObject *object, QEvent *event) 
+	if (event->type() == QEvent::KeyPress || event->type() == QEvent::MouseButtonPress)
 	{
-		QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
+		QCoreApplication::sendEvent(view, event);
 
-		if (event->type() == QEvent::KeyPress || event->type() == QEvent::MouseButtonPress)
-		{
-			QCoreApplication::sendEvent(view, event);
+		return true;
+	}
+	else if (event->type() == QEvent::FocusIn)
+	{
+		view->setFocus();
 
-			return true;
-		}
-		else if (event->type() == QEvent::FocusIn)
-		{
-			view->setFocus();
+		return true;
+	}
+	else
+		return QObject::eventFilter(object, event);
+}
 
-			return true;
-		}
+FilterItemDelegate::FilterItemDelegate(QWidget *parent) : QItemDelegate(parent)
+{
+	filter = new FilterItemEventFilter(parent);
+}
+
+void FilterItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+{
+	QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
+	QLabel *label;
+
+	if (view->indexWidget(index) == 0)
+	{
+		label = new QLabel();
+
+		label->installEventFilter(filter);
+		label->setAutoFillBackground(true);
+		label->setFocusPolicy(Qt::TabFocus);
+		label->setText(index.data().toString());
+		view->setIndexWidget(index, label);
+	}
+
+	label = (QLabel*)view->indexWidget(index);
+
+	if (option.state & QStyle::State_Selected)
+		if (option.state & QStyle::State_HasFocus)
+			label->setBackgroundRole(QPalette::Highlight);
 		else
-			return QObject::eventFilter(object, event);
-	};
-
-public:
-	FilterItemEventFilter(QWidget *parent = 0) : QObject(parent) {};
-};
-
-class FilterItemDelegate : public QItemDelegate
-{
-	Q_OBJECT
-
-private:
-	FilterItemEventFilter *filter;
-
-public:
-	FilterItemDelegate(QWidget *parent = 0) : QItemDelegate(parent)
-	{
-		filter = new FilterItemEventFilter(parent);
-	};
-
-	void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
-	{
-		QAbstractItemView *view = qobject_cast<QAbstractItemView*>(parent());
-		QLabel *label;
-
-		if (view->indexWidget(index) == 0)
-		{
-			label = new QLabel();
-
-			label->installEventFilter(filter);
-			label->setAutoFillBackground(true);
-			label->setFocusPolicy(Qt::TabFocus);
-			label->setText(index.data().toString());
-			view->setIndexWidget(index, label);
-		}
-
-		label = (QLabel*)view->indexWidget(index);
-
-		if (option.state & QStyle::State_Selected)
-			if (option.state & QStyle::State_HasFocus)
-				label->setBackgroundRole(QPalette::Highlight);
-			else
-				label->setBackgroundRole(QPalette::Window);
-		else
-			label->setBackgroundRole(QPalette::Base);
-	};
-};
-
-class filtermainWindow : public QDialog
-{
-     Q_OBJECT
-
- public:
-     filtermainWindow(QWidget *parent);
-	 ~filtermainWindow();
-     void             buildActiveFilterList(void);
-     Ui_mainFilterDialog ui;
-     
-     
-     
-     QListWidget      *availableList;
-     QListWidget      *activeList;
-     
-     
-     
- public slots:
-        void VCD(bool b);
-        void DVD(bool b);
-        void SVCD(bool b);
-        void halfD1(bool b);
-        void add(bool b);
-        void up(bool b);
-        void down(bool b);
-        void remove(bool b);
-        void configure(bool b);
-        void partial(bool b);
-		void loadScript(bool b);
-		void saveScript(bool b);
-        void activeDoubleClick( QListWidgetItem  *item);
-		void activeItemChanged(QListWidgetItem *current, QListWidgetItem *previous);
-        void allDoubleClick( QListWidgetItem  *item);
-		void filterFamilyItemChanged(QListWidgetItem *current, QListWidgetItem *previous);
-		void preview(bool b);
-		void closePreview();
-
- private:
-		uint32_t previewFrameIndex;
-		int previewDialogX, previewDialogY;
-		Ui_seekablePreviewWindow *previewDialog;
-
-        int startFilter[NB_TREE];
-        int filterSize[NB_TREE];
-        void setSelected(int sel);
-        void displayFamily(uint32_t family);
-        void setupFilters(void);
-};
+			label->setBackgroundRole(QPalette::Window);
+	else
+		label->setBackgroundRole(QPalette::Base);
+}
 
 void filtermainWindow::preview(bool b)
 {
@@ -261,8 +186,13 @@ void filtermainWindow::add( bool b)
      int itag=item->type();
      if(itag>=ALL_FILTER_BASE && itag < EXTERNAL_FILTER_BASE)
      {
-       tag=allfilters[itag-ALL_FILTER_BASE].tag;
-       
+    	 // Extract family & index
+    	 itag-=ALL_FILTER_BASE;
+    	 int index=itag%100;
+    	 int family=(itag-index)/100;
+    	 ADM_assert(family<VF_MAX);
+    	 ADM_assert(index<filterCategories[family].size());
+         tag=filterCategories[family][index]->tag;
      }else
      {
         ADM_assert(0); 
@@ -326,6 +256,7 @@ void filtermainWindow::remove( bool b)
                     videofilters[itag].conf = NULL;
             }
         // recreate derivated filters
+
         for (uint32_t i = itag ; i < nb_active_filter-1; i++)
         {
                     delete videofilters[i ].filter;
@@ -335,6 +266,7 @@ void filtermainWindow::remove( bool b)
                     videofilters[i ].conf = videofilters[i+1].conf;
                     videofilters[i ].tag = videofilters[i+1].tag;
         }
+        
         /* Delete last filter which is now at last filter -1 */
             delete videofilters[nb_active_filter - 1].filter;
             videofilters[nb_active_filter - 1].filter = NULL;
@@ -505,30 +437,23 @@ void filtermainWindow::filterFamilyItemChanged(QListWidgetItem *current, QListWi
 
 void filtermainWindow::displayFamily(uint32_t family)
 {
-  printf("Family :%u\n",family);
-  
   availableList->clear();
+  printf("Family :%u\n",family);
+  if (family >= VF_MAX) return;
+  std::vector <FilterDescriptor *> vec=filterCategories[family];
   QSize sz;
   
-  for (uint32_t i = 0; i < filterSize[family]; i++)
+  for (uint32_t i = 0; i < vec.size(); i++)
     {
-      int r=startFilter[family]+i;
-
-      if (allfilters[r].viewable==1)
-        {
-			QString str = QString("<b>") + QString::fromUtf8(allfilters[r].name) + QString("</b><br>\n<small>") + QString::fromUtf8(allfilters[r].description) + QString("</small>");
+		QString str = QString("<b>") + QString::fromUtf8(vec[i]->name) + QString("</b><br>\n<small>") + QString::fromUtf8(vec[i]->description) + QString("</small>");
          
           QListWidgetItem *item;
-          if(family==NB_TREE-1)
-                item=new QListWidgetItem(str,availableList,EXTERNAL_FILTER_BASE+i);
-          else
-                item=new QListWidgetItem(str,availableList,ALL_FILTER_BASE+r);
-		  item->setToolTip(QString::fromUtf8(allfilters[r].description));
+          item=new QListWidgetItem(str,availableList,ALL_FILTER_BASE+i+family*100);
+          item->setToolTip(QString::fromUtf8(vec[i]->description));
           availableList->addItem(item);
-        }
      }
 
-  if (filterSize[family])
+  if (vec.size())
 	  availableList->setCurrentRow(0);
 }
 
@@ -587,15 +512,17 @@ void filtermainWindow::partial( bool b)
         AVDMGenericVideoStream *replace;
         CONFcouple *conf;
         conf = videofilters[itag].conf;
-        if (videofilters[itag].tag == VF_PARTIAL)	// cannot recurse
+        if (videofilters[itag].tag == VF_PARTIAL_FILTER)	// cannot recurse
         {
             GUI_Error_HIG (QT_TR_NOOP("The filter is already partial"), NULL);
             return;
         }
+
         replace =new ADMVideoPartial (videofilters[itag - 1].
                                       filter,
                                       videofilters[itag].tag,
                                       conf);
+        
         if(replace->configure (videofilters[itag - 1].filter))
         {
 			bool previewDialogOpen = (previewDialog != NULL);
@@ -607,7 +534,7 @@ void filtermainWindow::partial( bool b)
             videofilters[itag].filter = replace;
             replace->getCoupledConf (&conf);
             videofilters[itag].conf = conf;
-            videofilters[itag].tag = VF_PARTIAL;
+            videofilters[itag].tag = VF_PARTIAL_FILTER;
             getFirstVideoFilter ();
             buildActiveFilterList ();
 			setSelected(itag);
@@ -658,34 +585,7 @@ void filtermainWindow::saveScript(bool)
 */
 void filtermainWindow::setupFilters(void)
 {
-  int current_tree=-1;
-  int current_raw=0;;
   
-  max=0;
-  
-  for (uint32_t i = 0; i < allfilters.size(); i++)
-    {
-      if (allfilters[i].viewable==1)
-        {
-          current_raw++;
-          
-        }else 
-        {
-                current_tree++;
-                if(current_tree) filterSize[current_tree-1]=current_raw;
-                if(current_tree>=NB_TREE) break;
-                startFilter[current_tree]=i+1;
-                current_raw=0;
-                
-        }
-    }
-    ADM_assert(NB_TREE==8);
-    startFilter[NB_TREE-1]=2000;
-    filterSize[NB_TREE-1]=0;
-    for(int i=0;i<NB_TREE;i++)
-    {
-             printf("%d Start at %d size :%d\n",i,startFilter[i],filterSize[i]);
-    }
 }
 
 /**
@@ -698,32 +598,33 @@ void filtermainWindow::buildActiveFilterList(void)
 
 	for (uint32_t i = 1; i < nb_active_filter; i++)
 	{
-		const char *name = filterGetNameFromTag(videofilters[i].tag);
-		const char *conf = videofilters[i].filter->printConf ();
-		int namelen = strlen (name);
-
-		while (*conf == ' ')
-			++conf;
-
-		if (strncasecmp (name, conf, namelen) == 0)
+		if (videofilters[i].tag != VF_INTERNAL)
 		{
-			conf += namelen;
-			while (*conf == ' ' || *conf == ':')
-				++conf;
-		}
+			const char *name = filterGetNameFromTag(videofilters[i].tag);
+			const char *conf = videofilters[i].filter->printConf ();
+			int namelen = strlen (name);
 
-		QString str = QString("<b>") + QString::fromUtf8(name) + QString("</b><br>\n<small>") + QString::fromUtf8(conf) + QString("</small>");
-		QListWidgetItem *item=new QListWidgetItem(str,activeList,ACTIVE_FILTER_BASE+i);
-		activeList->addItem(item);
+			while (*conf == ' ')
+				++conf;
+
+			if (strncasecmp (name, conf, namelen) == 0)
+			{
+				conf += namelen;
+				while (*conf == ' ' || *conf == ':')
+					++conf;
+			}
+
+			QString str = QString("<b>") + QString::fromUtf8(name) + QString("</b><br>\n<small>") + QString::fromUtf8(conf) + QString("</small>");
+			QListWidgetItem *item=new QListWidgetItem(str,activeList,ACTIVE_FILTER_BASE+i);
+			activeList->addItem(item);
+		}
 	}
 }
   /**
   */
 filtermainWindow::filtermainWindow(QWidget* parent) : QDialog(parent)
  {
-        memset( startFilter,0,sizeof(int)*NB_TREE);
-        memset( filterSize,0,sizeof(int)*NB_TREE);
- 
+        
     ui.setupUi(this);
     setupFilters();
 
@@ -829,4 +730,3 @@ uint8_t DIA_getPartial(PARTIAL_CONFIG *param,AVDMGenericVideoStream *son,AVDMGen
         return diaFactoryRun(QT_TR_NOOP("Partial Video Filter"),3,tabs);
 }
 //EOF
-
