@@ -13,37 +13,25 @@
  ***************************************************************************/
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-
-#include <QtCore/QFileInfo>
 #include <QtCore/QUrl>
-#include <QtCore/QVariant>
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QFrame>
-#include <QtGui/QGraphicsView>
-#include <QtGui/QMainWindow>
-#include <QtGui/QSlider>
-#include <QtGui/QStatusBar>
-#include <QtGui/QWidget>
+#include <QtCore/QDir>
 #include <QtGui/QKeyEvent>
-#include <QtGui/QValidator>
+#include <QtGui/QGraphicsView>
 
-#include "T_thumbSlider.h"
-#include "../ADM_toolkit/qtToolkit.h"
+#include "ADM_default.h"
+#include "Q_gui2.h"
+#include "ADM_toolkitQt.h"
 #include "ADM_qslider.h"
-#include "default.h"
-#include "ADM_osSupport/ADM_misc.h"
 #include "ADM_codecs/ADM_codec.h"
 #include "gui_action.hxx"
 #include "ADM_editor/ADM_outputfmt.h"
-#include "ADM_toolkit/filesel.h"
+#include "DIA_fileSel.h"
+#include "ADM_video/ADM_vidMisc.h"
 #include "prefs.h"
 #include "avi_vars.h"
-#include "../ADM_commonUI/GUI_render.h"
 #include "gtkgui.h"
+#include "DIA_coreToolkit.h"
+#include "ADM_userInterfaces/ADM_render/GUI_renderInternal.h"
 
 extern int global_argc;
 extern char **global_argv;
@@ -51,18 +39,23 @@ extern char **global_argv;
 extern uint8_t UI_getPhysicalScreenSize(void* window, uint32_t *w,uint32_t *h);
 extern int automation(void );
 extern void HandleAction(Action a);
-extern uint32_t encoderGetNbEncoder (void);
+extern bool isVideoCodecConfigurable(void);
+extern int encoderGetEncoderCount (void);
 extern const char *encoderGetIndexedName (uint32_t i);
-extern uint32_t audioFilterGetNbEncoder(void);
-extern const char* audioFilterGetIndexedName(uint32_t i);
+uint32_t audioEncoderGetNumberOfEncoders(void);
+const char  *audioEncoderGetDisplayName(uint32_t i);
 extern void checkCrashFile(void);
 extern void UI_QT4VideoWidget(QFrame *frame);
 extern void loadTranslator(void);
 extern void initTranslator(void);
 extern void destroyTranslator(void);
+extern ADM_RENDER_TYPE UI_getPreferredRender(void);
 extern int A_openAvi(const char *name);
 extern int A_appendAvi(const char *name);
-extern void fileReadWrite(SELFILE_CB *cb, int rw, const char *name);
+extern char *actual_workbench_file;
+extern void FileSel_ReadWrite(SELFILE_CB *cb, int rw, const char *name, const char *actual_workbench_file);
+extern bool A_parseECMAScript(const char *name);
+extern void saveCrashProject(void);
 
 int SliderIsShifted=0;
 static void setupMenus(void);
@@ -75,13 +68,13 @@ static uint32_t ADM_nbCustom=0;
 static int currentFps = 0;
 static int frameCount = 0;
 static int currentFrame = 0;
+ADM_OUT_FORMAT UI_GetCurrentFormat(void);
+void UI_setVideoCodec(int i);
 
 #ifdef HAVE_AUDIO
 extern uint8_t AVDM_setVolume(int volume);
 #endif
 
-#include "ui_gui2.h"
-
 #define WIDGET(x)  (((MainWindow *)QuiMainWindows)->ui.x)
 
 #define CONNECT(object,zzz) connect( (ui.object),SIGNAL(triggered()),this,SLOT(buttonPressed()));
@@ -110,145 +103,119 @@ static Action searchTranslationTable(const char *name);
 int UI_readCurTime(uint16_t &hh, uint16_t &mm, uint16_t &ss, uint16_t &ms);
 void UI_updateFrameCount(uint32_t curFrame);
 void UI_updateTimeCount(uint32_t curFrame,uint32_t fps);
-
+extern void UI_purge(void);
 /*
     Declare the class that will be our main window
 
 */
-class MainWindow : public QMainWindow
+
+void MainWindow::comboChanged(int z)
 {
-	Q_OBJECT
-
-public:
-	MainWindow();
-	virtual ~MainWindow();	
-	void buildCustomMenu(void);
-	
-	Ui_MainWindow ui;
-
-protected:
-	ThumbSlider *thumbSlider;
-
-public slots:
-	void timeChanged(int);
-	void buttonPressed(void);
-	void custom(void);
-	void toolButtonPressed(bool z);
-
-	void comboChanged(int z)
+	if (sender() == ui.comboBoxVideo)
 	{
-		const char *source=qPrintable(sender()->objectName());
+		bool b = (ui.comboBoxVideo->currentIndex() != 0);
 
-		if(!strcmp(source,"comboBoxVideo"))  
+		ui.pushButtonVideoFilter->setEnabled(b);
+		HandleAction (ACT_VideoCodecChanged);
+
+		ui.pushButtonVideoConf->setEnabled(b && isVideoCodecConfigurable());
+	}
+	else if (sender() == ui.comboBoxAudio)
+	{
+		bool b = (ui.comboBoxAudio->currentIndex() != 0);
+
+		ui.pushButtonAudioConf->setEnabled(b);
+		ui.pushButtonAudioFilter->setEnabled(b);
+		HandleAction(ACT_AudioCodecChanged);
+	}
+	else if (sender() == ui.comboBoxFormat)
+	{
+		ADM_OUT_FORMAT fmt = UI_GetCurrentFormat();
+
+		if (fmt == ADM_AVI_UNP || fmt == ADM_AVI_PAK)
 		{
-			bool b=FALSE;
-			if(ui.comboBoxVideo->currentIndex())
-			{
-				b=TRUE;
-			}
-			ui.pushButtonVideoConf->setEnabled(b);
-			ui.pushButtonVideoFilter->setEnabled(b);
-			HandleAction (ACT_VideoCodecChanged) ;
-		}
-		else if(!strcmp(source,"comboBoxAudio"))  
-		{
-			bool b=FALSE;
-			if(ui.comboBoxAudio->currentIndex())
-			{
-				b=TRUE;
-			}
-			ui.pushButtonAudioConf->setEnabled(b);
-			ui.pushButtonAudioFilter->setEnabled(b);
-			HandleAction (ACT_AudioCodecChanged) ;
+			ui.comboBoxVideo->setEnabled(false);
+			UI_setVideoCodec(0);
 		}
 		else
-			printf("From +: %s\n",source);
+		{
+			ui.comboBoxVideo->setEnabled(true);
+		}
 	}
+}
 
-	void sliderValueChanged(int u) 
-	{
-		if(!_upd_in_progres)
-			HandleAction(ACT_Scale);
-	}
+void MainWindow::sliderValueChanged(int u) 
+{
+	if(!_upd_in_progres)
+		HandleAction(ACT_Scale);
+}
 
-	void sliderMoved(int value)
-	{
-		SliderIsShifted = shiftKeyHeld;
-	}
+void MainWindow::sliderMoved(int value)
+{
+	SliderIsShifted = shiftKeyHeld;
+}
 
-	void sliderReleased(void)
-	{
-		SliderIsShifted = 0;
-	}
+void MainWindow::sliderReleased(void)
+{
+	SliderIsShifted = 0;
+}
 
-	void thumbSlider_valueEmitted(int value)
-	{
-		if (value > 0)
-			nextIntraFrame();
-		else
-			previousIntraFrame();
-	}
+void MainWindow::thumbSlider_valueEmitted(int value)
+{
+	if (value > 0)
+		nextIntraFrame();
+	else
+		previousIntraFrame();
+}
 
-	void volumeChange( int u )
-	{
+void MainWindow::volumeChange( int u )
+{
 #ifdef HAVE_AUDIO
-		if (_upd_in_progres || !ui.toolButtonAudioToggle->isChecked())
-			return;
+	if (_upd_in_progres || !ui.toolButtonAudioToggle->isChecked())
+		return;
 
-		_upd_in_progres++;
+	_upd_in_progres++;
 
-		int vol = ui.horizontalSlider_2->value();
+	int vol = ui.horizontalSlider_2->value();
 
-		AVDM_setVolume(vol);
-		_upd_in_progres--;
+	AVDM_setVolume(vol);
+	_upd_in_progres--;
 #endif
-	}
+}
 
-	void audioToggled(bool checked)
-	{
+void MainWindow::audioToggled(bool checked)
+{
 #ifdef HAVE_AUDIO
-		if (checked)
-			AVDM_setVolume(ui.horizontalSlider_2->value());
-		else
-			AVDM_setVolume(0);
+	if (checked)
+		AVDM_setVolume(ui.horizontalSlider_2->value());
+	else
+		AVDM_setVolume(0);
 #endif
-	}
+}
 
-	void previewModeChanged(QAction *action)
-	{
-		HandleAction(ACT_PreviewChanged);
-	}
+void MainWindow::previewModeChanged(QAction *action)
+{
+	HandleAction(ACT_PreviewChanged);
+}
 
-	void previousIntraFrame(void);
-	void nextIntraFrame(void);
+void MainWindow::timeChangeFinished(void)
+{
+	this->setFocus(Qt::OtherFocusReason);
+}
 
-	void timeChangeFinished(void)
-	{
-		this->setFocus(Qt::OtherFocusReason);
-	}
+void MainWindow::currentFrameChanged(void)
+{
+	HandleAction(ACT_JumpToFrame);
 
-	void currentFrameChanged(void)
-	{
-		HandleAction(ACT_JumpToFrame);
+	this->setFocus(Qt::OtherFocusReason);
+}
 
-		this->setFocus(Qt::OtherFocusReason);
-	}
+void MainWindow::currentTimeChanged(void)
+{
+	HandleAction(ACT_JumpToTime);
 
-	void currentTimeChanged(void)
-	{
-		HandleAction(ACT_JumpToTime);
-
-		this->setFocus(Qt::OtherFocusReason);
-	}
-
-protected:
-	void clearCustomMenu(void);
-	bool eventFilter(QObject* watched, QEvent* event);
-	void mousePressEvent(QMouseEvent* event);
-	void dragEnterEvent(QDragEnterEvent *event);
-	void dropEvent(QDropEvent *event);
-	void closeEvent(QCloseEvent *event);
-};
+	this->setFocus(Qt::OtherFocusReason);
+}
 
 
 MainWindow::MainWindow() : QMainWindow()
@@ -297,8 +264,9 @@ MainWindow::MainWindow() : QMainWindow()
 	connect(ui.actionNext_intra_frame, SIGNAL(triggered()), this, SLOT(nextIntraFrame()));
 
 	//ACT_VideoCodecChanged
-	connect( ui.comboBoxVideo,SIGNAL(activated(int)),this,SLOT(comboChanged(int)));
-	connect( ui.comboBoxAudio,SIGNAL(activated(int)),this,SLOT(comboChanged(int)));
+	connect( ui.comboBoxVideo,SIGNAL(currentIndexChanged(int)),this,SLOT(comboChanged(int)));
+	connect( ui.comboBoxAudio,SIGNAL(currentIndexChanged(int)),this,SLOT(comboChanged(int)));
+	connect(ui.comboBoxFormat, SIGNAL(currentIndexChanged(int)), this, SLOT(comboChanged(int)));
 
 	// Slider
 	slider=ui.horizontalSlider;
@@ -349,6 +317,7 @@ MainWindow::MainWindow() : QMainWindow()
 
 	/* Build the custom menu */
 	buildCustomMenu();
+	buildAutoMenu();
 
 	this->installEventFilter(this);
 	slider->installEventFilter(this);
@@ -532,9 +501,9 @@ void MainWindow::dropEvent(QDropEvent *event)
 			if (info.isFile())
 			{
 				if (avifileinfo)
-					fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_appendAvi), 0, fileName.toUtf8().data());
+					FileSel_ReadWrite(reinterpret_cast <void (*)(const char *)> (A_appendAvi), 0, fileName.toUtf8().data(), actual_workbench_file);
 				else
-					fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, fileName.toUtf8().data());
+					FileSel_ReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, fileName.toUtf8().data(), actual_workbench_file);
 			}
 		}
 	}
@@ -599,7 +568,7 @@ void MainWindow::buildCustomMenu(void)
 
 		for(int i=0; i < ADM_nbCustom; i++)
 		{
-			customActions[i] = new QAction(QString::fromUtf8(GetFileName(customNames[i])), NULL);
+			customActions[i] = new QAction(QString::fromUtf8(ADM_GetFileName(customNames[i])), NULL);
 			ui.menuCustom->addAction(customActions[i]);
 			connect(customActions[i], SIGNAL(triggered()), this, SLOT(custom()));
 		}
@@ -610,6 +579,76 @@ void MainWindow::buildCustomMenu(void)
 	printf("Custom menu built\n");
 }
 
+void MainWindow::autoMenuHandler(void)
+{
+	QObject *obj = sender();
+	QString filePath = ((QAction*)obj)->text() + ".js";
+
+	while (obj->parent() != ui.menuAuto)
+	{
+		obj = obj->parent();
+		filePath = ((QMenu*)obj)->title() + QDir::separator() + filePath;
+	}
+
+	char *scriptDir = ADM_getScriptPath();
+
+	A_parseECMAScript((QString::fromUtf8(scriptDir) + "auto" + QDir::separator() + filePath).toUtf8().constData());
+
+	delete scriptDir;
+}
+
+void MainWindow::addDirEntryToMenu(QMenu *parentMenu, QString path)
+{
+	QFileInfo info(path);
+
+	if (info.isDir())
+	{
+		QDir dir(info.path() + QDir::separator());
+
+		dir.setSorting(QDir::DirsFirst | QDir::Name);
+
+		QFileInfoList fileList = dir.entryInfoList();
+
+		for (int x = 0; x < fileList.count(); x++)
+		{
+			if (fileList[x].fileName() != "." && fileList[x].fileName() != "..")
+			{
+				QMenu *menu = parentMenu;
+
+				if (fileList[x].isDir())
+				{
+					menu = parentMenu->addMenu(QDir(fileList[x].filePath()).dirName());
+
+					addDirEntryToMenu(menu, fileList[x].filePath() + QDir::separator());
+				}
+				else
+					addDirEntryToMenu(menu, fileList[x].filePath());
+			}
+		}
+	}
+	else
+	{
+		QAction *action = new QAction(info.completeBaseName(), parentMenu);
+
+		parentMenu->addAction(action);
+		connect(action, SIGNAL(triggered()), this, SLOT(autoMenuHandler()));
+	}
+}
+
+void MainWindow::buildAutoMenu(void)
+{
+	char *scriptDir = ADM_getScriptPath();
+	QFileInfo autoDirInfo = QFileInfo(QString::fromUtf8(scriptDir) + QString("auto") + QDir::separator());
+
+	delete scriptDir;
+
+	if (autoDirInfo.isDir())
+		addDirEntryToMenu(ui.menuAuto, autoDirInfo.filePath());
+
+	if (ui.menuAuto->isEmpty())
+		ui.menuAuto->setEnabled(false);
+}
+
 void MainWindow::closeEvent(QCloseEvent *event)
 {
 	HandleAction(ACT_Exit);
@@ -621,14 +660,24 @@ MainWindow::~MainWindow()
 	clearCustomMenu();
 	renderDestroy();
 }
-
+static const UI_FUNCTIONS_T UI_Hooks=
+    {
+        ADM_RENDER_API_VERSION_NUMBER,
+        UI_purge,
+        UI_getWindowInfo,
+        UI_updateDrawWindowSize,
+        UI_rgbDraw,
+        UI_getDrawWidget,
+        UI_getPreferredRender
+        
+    };
 int UI_Init(int nargc,char **nargv)
 {
 	initTranslator();
 
 	global_argc=nargc;
 	global_argv=nargv;
-
+	ADM_renderLibInit(&UI_Hooks);
 	return 0;
 }
 QWidget *QuiMainWindows=NULL;
@@ -687,6 +736,11 @@ void UI_setCurrentPreview(int ne)
 	}
 }
 
+static void FatalFunctionQt(const char *title, const char *info)
+{
+	GUI_Info_HIG(ADM_LOG_IMPORTANT, title, info);
+}
+
 /**
     \fn UI_RunApp(void)
     \brief Main entry point for the GUI application
@@ -714,6 +768,7 @@ int UI_RunApp(void)
 	UI_QT4VideoWidget(mw->ui.frame_video);  // Add the widget that will handle video display
 	UI_updateRecentMenu();
 	setupMenus();
+	ADM_setCrashHook(&saveCrashProject, &FatalFunctionQt);
 	checkCrashFile();
 
 	if (global_argc >= 2)
@@ -779,7 +834,7 @@ void setupMenus(void)
 	uint32_t nbVid;
 	const char *name;
 
-	nbVid=encoderGetNbEncoder();
+	nbVid=encoderGetEncoderCount();
 	printf("Found %d video encoder(s)\n",nbVid);
 	for(uint32_t i=1;i<nbVid;i++)
 	{
@@ -791,13 +846,14 @@ void setupMenus(void)
 
 	uint32_t nbAud;
 
-	nbAud=audioFilterGetNbEncoder();
+    nbAud=audioEncoderGetNumberOfEncoders();
 	printf("Found %d audio encoder(s)\n",nbAud);		       
 	for(uint32_t i=1;i<nbAud;i++)
 	{
-		name=audioFilterGetIndexedName(i);
+		name=audioEncoderGetDisplayName(i);
 		WIDGET(comboBoxAudio)->addItem(name);
 	}
+
 	/*   Fill in output format window */
 	uint32_t nbFormat;
 
@@ -1027,11 +1083,7 @@ int 	UI_getCurrentVCodec(void)
 
 void UI_setVideoCodec( int i)
 {
-	int b=!!i;
 	WIDGET(comboBoxVideo)->setCurrentIndex(i);
-
-	WIDGET(pushButtonVideoConf)->setEnabled(b);
-	WIDGET(pushButtonVideoFilter)->setEnabled(b);
 }
 /**
     \fn     UI_getCurrentACodec(void)
