@@ -1,6 +1,9 @@
 #ifndef T_THUMBSLIDER_H
 #define T_THUMBSLIDER_H
 
+#include <QtGui/QPainter>
+#include <QtGui/QPaintEvent>
+#include <QtGui/QMouseEvent>
 #include <QtGui/QSlider>
 
 class ThumbSlider : public QAbstractSlider
