@@ -12,35 +12,25 @@
  *                                                                         *
  ***************************************************************************/
 
-
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <string.h>
-#include <stdio.h>
-
 #include "config.h"
-#include "default.h"
-
+#include "ADM_default.h"
 # include "prefs.h"
+
 #include "ADM_audiodevice/audio_out.h"
-
 #include "ADM_assert.h"
-#include "GUI_render.h"
-#include "ADM_osSupport/ADM_cpuCap.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_commonUI/DIA_factory.h"
+#include "ADM_userInterfaces/ADM_render/GUI_render.h"
 
-#ifdef ADM_WIN32
-#include "ADM_userInterfaces/ADM_commonUI/GUI_sdlRender.h"
+
+#include "DIA_factory.h"
+
+#ifdef __WIN32
+#include "ADM_userInterfaces/ADM_render/GUI_sdlRender.h"
 #endif
 
 extern void 		AVDM_audioPref( void );
 extern const char* getNativeRendererDesc();
 
 
-// FIXME
-
 
 uint8_t DIA_Preferences(void);
 
@@ -52,7 +42,6 @@ uint8_t DIA_Preferences(void)
 {
 uint32_t olddevice,newdevice;
 
-uint32_t	lavcodec_mpeg=0;
 uint32_t        use_odml=0;
 uint32_t	autosplit=0;
 uint32_t render;
@@ -61,7 +50,7 @@ uint32_t useMaster=0;
 uint32_t useAutoIndex=0;
 uint32_t useSwap=0;
 uint32_t useNuv=0;
-uint32_t lavcThreads=0,x264Threads=0,xvidThreads=0;
+uint32_t lavcThreads=0;
 uint32_t encodePriority=2;
 uint32_t indexPriority=2;
 uint32_t playbackPriority=0;
@@ -96,9 +85,9 @@ char     *globalGlyphName=NULL;
     DOME(4,dring);
      
 // Cpu caps
-#define CPU_CAPS(x)    	if(CpuCaps::myCpuMask & ADM_CPU_##x) caps##x=1; else caps##x=0;
+#define CPU_CAPS(x)    	if(CpuCaps::myCpuMask & ADM_CPUCAP_##x) caps##x=1; else caps##x=0;
     
-    	if(CpuCaps::myCpuMask==ADM_CPU_ALL) capsAll=1; else capsAll=0;
+    	if(CpuCaps::myCpuMask==ADM_CPUCAP_ALL) capsAll=1; else capsAll=0;
     	CPU_CAPS(MMX);
     	CPU_CAPS(MMXEXT);
     	CPU_CAPS(3DNOW);
@@ -138,8 +127,6 @@ char     *globalGlyphName=NULL;
 
         // Multithreads
         prefs->get(FEATURE_THREADING_LAVC, &lavcThreads);
-        prefs->get(FEATURE_THREADING_X264, &x264Threads);
-        prefs->get(FEATURE_THREADING_XVID, &xvidThreads);
 
 		// Encoding priority
 		if(!prefs->get(PRIORITY_ENCODING, &encodePriority))
@@ -155,8 +142,6 @@ char     *globalGlyphName=NULL;
         if(!prefs->get(SETTINGS_MPEGSPLIT, &autosplit))
                 autosplit=690;		
                         
-        if(!prefs->get(FEATURE_USE_LAVCODEC_MPEG2, &lavcodec_mpeg))
-                lavcodec_mpeg=0;
         // Open DML (Gmv)
         if(!prefs->get(FEATURE_USE_ODML, &use_odml))
           use_odml=0;
@@ -189,7 +174,6 @@ char     *globalGlyphName=NULL;
         /************************ Build diaelems ****************************************/
         diaElemToggle useSysTray(&useTray,QT_TR_NOOP("_Use systray while encoding"));
         diaElemToggle allowAnyMpeg(&mpeg_no_limit,QT_TR_NOOP("_Accept non-standard audio frequency for DVD"));
-        diaElemToggle useLavcodec(&lavcodec_mpeg,QT_TR_NOOP("_Use libavcodec MPEG-2 decoder"));
         diaElemToggle openDml(&use_odml,QT_TR_NOOP("Create _OpenDML files"));
         diaElemToggle autoIndex(&useAutoIndex,QT_TR_NOOP("Automatically _index MPEG files"));
         diaElemToggle autoSwap(&useSwap,QT_TR_NOOP("Automatically _swap A and B if A>B"));
@@ -231,13 +215,9 @@ char     *globalGlyphName=NULL;
 		frameSimd.swallow(&capsToggleSSSE3);
 
 		diaElemThreadCount lavcThreadCount(&lavcThreads, QT_TR_NOOP("_lavc threads:"));
-		diaElemThreadCount x264ThreadCount(&x264Threads, QT_TR_NOOP("_x264 threads:"));
-		diaElemThreadCount xvidThreadCount(&xvidThreads, QT_TR_NOOP("X_vid threads:"));
 
 		diaElemFrame frameThread(QT_TR_NOOP("Multi-threading"));
 		frameThread.swallow(&lavcThreadCount);
-		frameThread.swallow(&x264ThreadCount);
-		frameThread.swallow(&xvidThreadCount);
 
 		diaMenuEntry priorityEntries[] = {
                              {0,       QT_TR_NOOP("High"),NULL}
@@ -264,7 +244,7 @@ char     *globalGlyphName=NULL;
                              ,{RENDER_XV,   QT_TR_NOOP("XVideo (best)"),NULL}
 #endif
 #ifdef USE_SDL
-#ifdef ADM_WIN32
+#ifdef __WIN32
                              ,{RENDER_SDL,      QT_TR_NOOP("SDL (MS Windows GDI)"),NULL}
 							 ,{RENDER_DIRECTX,      QT_TR_NOOP("SDL (MS Windows DirectX)"),NULL}
 #else
@@ -299,53 +279,21 @@ char     *globalGlyphName=NULL;
                               ,{3,      QT_TR_NOOP("Pro Logic II"),NULL}
          };
         diaElemMenu menuMixer(&downmix,QT_TR_NOOP("_Local playback downmixing:"), sizeof(mixerEntries)/sizeof(diaMenuEntry),mixerEntries,"");
-
-		diaMenuEntry audioEntries[] =
-		{
-		#ifdef ALSA_SUPPORT
-			{DEVICE_ALSA, QT_TR_NOOP("ALSA")},
-		#endif
-		#ifdef USE_ARTS
-			{DEVICE_ARTS, QT_TR_NOOP("aRts")},
-		#endif
-		#ifdef CONFIG_DARWIN
-			{DEVICE_COREAUDIO, QT_TR_NOOP("Core Audio")},
-		#endif
-		#ifdef USE_ESD
-			{DEVICE_ESD, QT_TR_NOOP("ESD")},
-		#endif
-		#ifdef USE_JACK
-			{DEVICE_JACK, QT_TR_NOOP("JACK")},
-		#endif
-		#ifdef OSS_SUPPORT
-			{DEVICE_OSS, QT_TR_NOOP("OSS")},
-		#endif
-		#ifdef USE_PULSE_SIMPLE
-			{DEVICE_PULSE_SIMPLE, QT_TR_NOOP("Pulse Audio")},
-		#endif
-
-		#if	defined(USE_SDL) && !defined(ADM_WIN32)
-			{DEVICE_SDL, QT_TR_NOOP("SDL")},
-		#endif
-		#ifdef ADM_WIN32
-			{DEVICE_WIN32, QT_TR_NOOP("Win32")},
-		#endif
-			{DEVICE_DUMMY, QT_TR_NOOP("None")}
-		};
-
-        diaElemMenu menuAudio(&newdevice,QT_TR_NOOP("_Audio output:"), sizeof(audioEntries)/sizeof(diaMenuEntry),audioEntries,"");
-                
-#ifdef ALSA_SUPPORT
-		diaElemText entryAlsaDevice(&alsaDevice,QT_TR_NOOP("ALSA _device:"),NULL);
-
-          int z,m;
-          m=sizeof(audioEntries)/sizeof(diaMenuEntry);
-          for(z=0;z<m;z++)
-          {
-            if(audioEntries[z].val==DEVICE_ALSA)
-                menuAudio.link(&(audioEntries[z]),1,&entryAlsaDevice);
-          }
-#endif
+//*********** AV_
+		
+//***AV
+        uint32_t nbAudioDevice=ADM_av_getNbDevices();
+        diaMenuEntryDynamic *audioDeviceItems[nbAudioDevice+1];
+        audioDeviceItems[0]=new diaMenuEntryDynamic(0,"Dummy","Dummy");
+        for(int i=0;i<nbAudioDevice;i++)
+        {
+            const char *name;
+            uint32_t major,minor,patch;
+            ADM_av_getDeviceInfo(i, &name, &major,&minor,&patch);
+            audioDeviceItems[i+1]=new diaMenuEntryDynamic(i+1,name,name);
+        }
+        diaElemMenuDynamic menuAudio(&newdevice,QT_TR_NOOP("_AudioDevice"), nbAudioDevice+1, 
+                    audioDeviceItems,NULL);
         // default Post proc
      diaElemToggle     fhzd(&hzd,QT_TR_NOOP("_Horizontal deblocking"));
      diaElemToggle     fvzd(&vzd,QT_TR_NOOP("_Vertical deblocking"));
@@ -360,7 +308,7 @@ char     *globalGlyphName=NULL;
      
         // Filter path
         if( prefs->get(FILTERS_AUTOLOAD_PATH, &filterPath) != RC_OK )
-#ifndef ADM_WIN32
+#ifndef __WIN32
                filterPath = ADM_strdup("/tmp");
 #else
                filterPath = ADM_strdup("c:\\");
@@ -382,24 +330,28 @@ char     *globalGlyphName=NULL;
         diaElemTabs tabAuto(QT_TR_NOOP("Automation"),5,diaAuto);
         
         /* Input */
-        diaElem *diaInput[]={&nuvAudio,&useLavcodec};
-        diaElemTabs tabInput(QT_TR_NOOP("Input"),2,(diaElem **)diaInput);
+        diaElem *diaInput[]={&nuvAudio};
+        diaElemTabs tabInput(QT_TR_NOOP("Input"),1,(diaElem **)diaInput);
         
         /* Output */
         diaElem *diaOutput[]={&autoSplit,&openDml,&allowAnyMpeg,&togTagMp3};
         diaElemTabs tabOutput(QT_TR_NOOP("Output"),4,(diaElem **)diaOutput);
         
         /* Audio */
-#if defined(ALSA_SUPPORT)
+
+#if 0 //defined(ALSA_SUPPORT)
         diaElem *diaAudio[]={&menuMixer,&menuVolume,&menuAudio,&entryAlsaDevice};
         diaElemTabs tabAudio(QT_TR_NOOP("Audio"),4,(diaElem **)diaAudio);
-#elif defined(OSS_SUPPORT)
+//#elif defined(OSS_SUPPORT)
         diaElem *diaAudio[]={&menuMixer,&menuVolume,&menuAudio};
         diaElemTabs tabAudio(QT_TR_NOOP("Audio"),3,(diaElem **)diaAudio);
-#else
+#endif
+
+#if 1
         diaElem *diaAudio[]={&menuMixer,&menuAudio};
         diaElemTabs tabAudio(QT_TR_NOOP("Audio"),2,(diaElem **)diaAudio);
 #endif
+
         
         /* Video */
         diaElem *diaVideo[]={&menuVideoMode,&framePP};
@@ -429,12 +381,12 @@ char     *globalGlyphName=NULL;
         	// cpu caps
         		if(capsAll)
         		{
-        			CpuCaps::myCpuMask=ADM_CPU_ALL;
+        			CpuCaps::myCpuMask=ADM_CPUCAP_ALL;
         		}else
         		{
         			CpuCaps::myCpuMask=0;
 #undef CPU_CAPS
-#define CPU_CAPS(x)    	if(caps##x) CpuCaps::myCpuMask|= ADM_CPU_##x;        	    	
+#define CPU_CAPS(x)    	if(caps##x) CpuCaps::myCpuMask|= ADM_CPUCAP_##x;        	    	
         	    	CPU_CAPS(MMX);
         	    	CPU_CAPS(MMXEXT);
         	    	CPU_CAPS(3DNOW);
@@ -489,8 +441,6 @@ char     *globalGlyphName=NULL;
                 prefs->set(FEATURE_MPEG_NO_LIMIT, mpeg_no_limit);
                 // Video render
                 prefs->set(DEVICE_VIDEODEVICE,render);
-                // Mpeg /lavcodec
-                prefs->set(FEATURE_USE_LAVCODEC_MPEG2, lavcodec_mpeg);
                 // Odml
                 prefs->set(FEATURE_USE_ODML, use_odml);
 				// Split
@@ -498,8 +448,6 @@ char     *globalGlyphName=NULL;
                 
                 // number of threads
                 prefs->set(FEATURE_THREADING_LAVC, lavcThreads);
-				prefs->set(FEATURE_THREADING_X264, x264Threads);
-				prefs->set(FEATURE_THREADING_XVID, xvidThreads);
 
 				// Encoding priority
 				prefs->set(PRIORITY_ENCODING, encodePriority);
@@ -525,11 +473,16 @@ char     *globalGlyphName=NULL;
                 // Alternate mp3 tag (haali)
                 prefs->set(FEATURE_ALTERNATE_MP3_TAG,alternate_mp3_tag);
 
-			#if defined(ADM_WIN32) && defined(USE_SDL)
+			#if defined(__WIN32) && defined(USE_SDL)
 				// Initialise SDL again as driver may have changed
-				initSdl();
+				initSdl(render);
 			#endif
 	}
+        for(int i=0;i<nbAudioDevice+1;i++)
+        {
+            
+            delete audioDeviceItems[i];
+        }
 
 	ADM_dealloc(filterPath);
 	ADM_dealloc(globalGlyphName);
