@@ -25,13 +25,12 @@
 #include <errno.h>
 
 #include "ADM_lavcodec.h"
-
 #include "fourcc.h"
 #include "avi_vars.h"
 #include "ADM_assert.h"
-#include "ADM_toolkit/filesel.h"
+#include "DIA_fileSel.h"
 #include "prototype.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "DIA_coreToolkit.h"
 #include "ADM_toolkit/bitmap.h"
 
 #include "ADM_audio/aviaudio.hxx"
@@ -39,37 +38,33 @@
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "gui_action.hxx"
 #include "gtkgui.h"
-//#include "ADM_gui/GUI_vars.h"
-#include "oplug_avi/GUI_mux.h"
-#include "oplug_mpegFF/oplug_vcdff.h"
+
+#include "ADM_outputs/oplug_avi/GUI_mux.h"
+#include "ADM_outputs/oplug_mpegFF/oplug_vcdff.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "prefs.h"
 #include "ADM_encoder/adm_encConfig.h"
-#include "GUI_render.h"
-#include "GUI_ui.h"
-#include "ADM_colorspace/colorspace.h"
+#include "ADM_userInterfaces/ADM_render/GUI_render.h"
+#include "ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
+
 #include "ADM_audiodevice/audio_out.h"
 
-#include "DIA_busy.h"
-#include "DIA_working.h"
-
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
+#include "ADM_userInterfaces/ADM_commonUI/DIA_busy.h"
+#include "ADM_userInterfaces/ADM_commonUI/DIA_working.h"
+#include "DIA_factory.h"
 #include "DIA_enter.h"
 
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-
-
 #include "ADM_codecs/ADM_ffmpeg.h"
-
-#include "ADM_libmpeg2enc/ADM_mpeg2enc.h"
-
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
-
-static AudioSource currentAudioSource = AudioAvi;
-static AudioSource secondAudioSource = AudioNone;
-static char *currentAudioName = NULL;
-static char *secondAudioName = NULL;
+#include "ADM_libraries/ADM_libmpeg2enc/ADM_mpeg2enc.h"
+#include "ADM_video/ADM_vidMisc.h"
+#include "ADM_preview.h"
+AudioSource currentAudioSource = AudioAvi;
+AudioSource secondAudioSource = AudioNone;
+char *currentAudioName = NULL;
+char *secondAudioName = NULL;
 
 void A_handleSecondTrack (int tracktype);
 int A_delete(uint32_t start, uint32_t end);
@@ -137,7 +132,7 @@ extern uint8_t DIA_gotoTime(uint16_t *hh, uint16_t *mm, uint16_t *ss);
 extern uint8_t GUI_getFrame(uint32_t frameno,  uint32_t *flags);
 extern int A_SaveUnpackedVop(const char *name);
 extern int A_SavePackedVop(const char *name);
-extern void      videoCodecConfigureUI(void);
+extern void videoCodecConfigureUI(int codecIndex = -1);
 extern void audioCodecChanged(int newcodec);
 extern void videoCodecChanged(int newcodec);
 extern void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate );
@@ -166,7 +161,7 @@ void GUI_avsProxy(void);
 uint8_t GUI_close(void);
 extern void A_jog(void);
 extern void DIA_glyphEdit(void);
-
+extern uint8_t DIA_pluginsInfo(void);
 //___________________________________________
 // serialization of user event through gui
 //
@@ -193,7 +188,7 @@ int nw;
   }
   switch (action)
     {
-        case ACT_GLYPHEDIT:
+        case ACT_GLYPHEDIT: 
                                 DIA_glyphEdit();
                                 return;
         case ACT_AVS_PROXY:
@@ -209,10 +204,11 @@ int nw;
                                 GUI_jobs();
                                 return;
         case ACT_RECENT0:
-        case ACT_RECENT1:
+        case ACT_RECENT1:        
         case ACT_RECENT2:
         case ACT_RECENT3:
                         const char **name;
+						char* fileName;
                         int rank;
                                 name=prefs->get_lastfiles();
                                 rank=(int)action-ACT_RECENT0;
@@ -240,16 +236,18 @@ int nw;
 		return;
    case ACT_AudioCodecChanged:
                 nw=UI_getCurrentACodec();
-   		audioCodecChanged(nw);
-
+                audioCodecSetByIndex(nw);
+    		
 		return;
-
+    case ACT_PLUGIN_INFO:
+            DIA_pluginsInfo();
+            return;
     case ACT_RunScript:
                 GUI_FileSelRead (QT_TR_NOOP("Select ECMAScript to Run"),(SELFILE_CB *) A_parseECMAScript);
-
+                        
                         //
     		return;
-
+		
     case ACT_RecentFiles:
     	char *file;
 		if(		DIA_RecentFiles(&file))
@@ -269,45 +267,39 @@ int nw;
       audioCodecConfigure();
       return;
 
-    case ACT_AudioFilters:
-      audioFilter_configureFilters ();
-      return;
+	case ACT_AudioFilters:
+		if (audioProcessMode())
+		{
+			audioFilter_configureFilters();
+		}
+		else
+		{
+			GUI_Error_HIG(QT_TR_NOOP("Audio filters cannot be applied in Copy mode"), QT_TR_NOOP("To apply filters the audio must be transcoded."));
+		}
+
+		return;
     case ACT_Pref:
         if(playing) return;
     	if(DIA_Preferences())
 	{
 	saveEncoderConfig ();
- 	#ifdef HAVE_AUDIO
+ 	#ifdef HAVE_AUDIO     
       		AVDM_audioSave();
- 	#endif
-      	prefs->save ();
-	}
+ 	#endif     
+      	prefs->save ();	
+	}      
 	return;
     case ACT_SavePref:
       saveEncoderConfig ();
- #ifdef HAVE_AUDIO
+ #ifdef HAVE_AUDIO     
       AVDM_audioSave();
- #endif
+ #endif     
       prefs->save ();
       return;
     case ACT_SetMuxParam:
       ADM_aviUISetMuxer();
       return;
       break;
-#ifdef HAVE_AUDIO
-    	case ACT_SelectDevOSS:
-				   AVDM_switch (DEVICE_OSS);
-				   return;break;
-    	case ACT_SelectDevDummy:
-				   AVDM_switch (DEVICE_DUMMY);
-				   return;break;
-    	case ACT_SelectDevArts:
-				   AVDM_switch (DEVICE_ARTS);
-				   return;break;
-	case ACT_SelectDevALSA:
-				   AVDM_switch (DEVICE_ALSA);
-				   return;break;
-#endif
     case ACT_Fast:
       ADM_assert(0);
       break;
@@ -317,11 +309,11 @@ int nw;
          if( saveprefsonexit )
             prefs->save ();
       }
-      cleanUp ();
+      cleanUp (); 
       exit (0);
       break;
 /*			case ACT_SelectEncoder:
-
+				
 						A_selectEncoder();
   	  			return;
 						break;*/
@@ -333,7 +325,7 @@ int nw;
       break;
 
     }
-//------------------------------------------------
+//------------------------------------------------                                      
 
   if (playing)			// only allow some action
     {
@@ -375,7 +367,7 @@ int nw;
       return;
     }
 
-//#define TEST_UNPACK
+//#define TEST_UNPACK    
   // we have an AVI loaded
   switch (action)
     {
@@ -423,16 +415,16 @@ int nw;
     			break;
     case ACT_SaveUnpackedMpeg4:
       if(GUI_Question(QT_TR_NOOP("This is to be used to undo packed VOP on MPEG-4.\nContinue ?")))
-			{
+			{ 
                           GUI_FileSelWrite (QT_TR_NOOP("Select AVI File to Write"), (SELFILE_CB *)A_SaveUnpackedVop);
-
+				
 			}
     			break;
-
+			
     case ACT_SaveOGM:
                         GUI_FileSelWrite (QT_TR_NOOP("Select OGM File to Write"), (SELFILE_CB *)ogmSave);
     			break;
-
+				
     case ACT_SaveWork:
       GUI_FileSelWrite (QT_TR_NOOP("Select Workbench to Save"), A_saveWorkbench);
 	  UI_refreshCustomMenu();
@@ -450,8 +442,8 @@ int nw;
 		UI_refreshCustomMenu();
       }
       break;
-        case ACT_JumpToFrame:
-                // read value
+        case ACT_JumpToFrame: 
+                // read value	
                 nf=UI_readCurFrame();
 				if(nf< avifileinfo->nb_frames)
 					GUI_GoToFrame(nf);
@@ -494,7 +486,7 @@ int nw;
     case ACT_SaveWave:
       	{
           GUI_FileSelWrite (QT_TR_NOOP("Select File to Save Audio"),(SELFILE_CB *)A_audioSave);
-
+	
 	}
       break;
 
@@ -527,7 +519,7 @@ int nw;
       break;
 
     case ACT_SaveBunchJPG:
-      GUI_FileSelWrite (QT_TR_NOOP("Select JPEG Sequence to Save"), A_saveBunchJpg);
+      GUI_FileSelWrite (QT_TR_NOOP("Select JPEG Sequence to Save"), A_saveBunchJpg);      
     	break;
     case ACT_SaveImg:
       GUI_FileSelWrite (QT_TR_NOOP("Select BMP to Save"), A_saveImg);
@@ -537,7 +529,7 @@ int nw;
       GUI_FileSelWrite (QT_TR_NOOP("Select JPEG to Save"), (SELFILE_CB *)A_saveJpg);
       	//GUI_FileSelWrite ("Select Jpg to save ", A_saveJpg);
       	break;
-
+    
     case ACT_Scale:
       if (!ignore_change)
 	{
@@ -555,7 +547,7 @@ int nw;
     {
         ADM_PREVIEW_MODE oldpreview=getPreviewMode(),newpreview=(ADM_PREVIEW_MODE)UI_getCurrentPreview();
           printf("Old preview %d, New preview mode : %d\n",oldpreview,newpreview);
-
+          
           if(oldpreview==newpreview)
           {
             return;
@@ -574,25 +566,43 @@ int nw;
       A_setPostproc();
       break;
 
-    case ACT_NextFrame:
-      GUI_NextFrame ();
-      break;
-    case ACT_NextKFrame:
-      GUI_NextKeyFrame ();
-      break;
+	case ACT_NextFrame:
+		if (!ignore_change)
+		{
+			ignore_change++;
+			GUI_NextFrame();
+			ignore_change--;
+		}
+
+		break;
+	case ACT_NextKFrame:
+		if (!ignore_change)
+		{
+			ignore_change++;
+			GUI_NextKeyFrame();
+			ignore_change--;
+		}
+
+		break;
     case ACT_NextBlackFrame:
       GUI_NextPrevBlackFrame(1);
       break;
     case ACT_PrevBlackFrame:
       GUI_NextPrevBlackFrame(-1);
       break;
-    case ACT_AllBlackFrames:
+    case ACT_AllBlackFrames:    
       GUI_FileSelWrite (QT_TR_NOOP("Select File to Save"), (SELFILE_CB *)A_ListAllBlackFrames);
-        break;
+        break;                        
+    
+	case ACT_PreviousFrame:
+		if (!ignore_change)
+		{
+			ignore_change++;
+			GUI_PrevFrame();
+			ignore_change--;
+		}
 
-    case ACT_PreviousFrame:
-        GUI_PrevFrame();
-      break;
+		break;
     case ACT_Forward100Frames:
       GUI_GoToKFrame (curframe + (avifileinfo->fps1000 / 1000 * 4));
       break;
@@ -629,9 +639,15 @@ int nw;
 	}
       break;
 
-    case ACT_PreviousKFrame:
-      GUI_PreviousKeyFrame ();
-      break;
+	case ACT_PreviousKFrame:
+		if (!ignore_change)
+		{
+			ignore_change++;
+			GUI_PreviousKeyFrame();
+			ignore_change--;
+		}
+
+		break;
     case ACT_AudioSourceAvi:
       //currentaudiostream=aviaudiostream;
       A_changeAudioStream (aviaudiostream, AudioAvi,NULL);
@@ -652,7 +668,7 @@ int nw;
        A_changeAudioStream((AVDMGenericAudioStream *) NULL, AudioNone,NULL);
       break;
 
-
+  
     case ACT_MarkA:
     case ACT_MarkB:
       uint32_t swapit;
@@ -681,12 +697,14 @@ int nw;
       GUI_GoToFrame (nf);
       break;
     case ACT_Goto:
-      uint32_t fn;
-      fn=curframe;
-      if (DIA_GetIntegerValue ((int *)&fn,0,avifileinfo->nb_frames,QT_TR_NOOP("Go to Frame"),QT_TR_NOOP("_Go to frame:")))
+	int fn;
+
+	fn = curframe;
+
+	if (DIA_GetIntegerValue(&fn, 0, avifileinfo->nb_frames, QT_TR_NOOP("Go to Frame"), QT_TR_NOOP("_Go to frame:")))
 	{
 		if (fn < avifileinfo->nb_frames)
-			GUI_GoToFrame (curframe);
+			GUI_GoToFrame(fn);
 		else
 			GUI_Error_HIG (QT_TR_NOOP("Out of bounds"), NULL);
 	}
@@ -746,10 +764,15 @@ int nw;
 	}
 	break;
 
+	case ACT_Cut:
+		if (frameEnd < frameStart)
+		{
+			GUI_Error_HIG(QT_TR_NOOP("Marker A > B"), QT_TR_NOOP("Cannot cut."));
+			break;
+		}
+		else
+			video_body->copyToClipBoard(frameStart, frameEnd);
     case ACT_Delete:
-    case ACT_Cut:
-
-
       old=frameStart;
       if( A_delete(frameStart,frameEnd))
       {
@@ -757,11 +780,11 @@ int nw;
 	{			// we removed too much
 	  old = avifileinfo->nb_frames - 1;
 	}
-      	curframe=old;
-      	GUI_GoToFrame (old);
+      	curframe=old;	 
+      	GUI_GoToFrame (old);      
       }
-
-
+      
+      
       break;
 
     case ACT_AudioMap:
@@ -824,24 +847,35 @@ int nw;
       video_body->setDecodeParam ( curframe);
 
       break;
-    case ACT_VideoParameter:
-      // first remove current viewer
-      if (getPreviewMode()!=ADM_PREVIEW_NONE)
-        {
-	         admPreview::stop();
-        }
-      GUI_handleVFilter();
-      if( getLastVideoFilter()->getInfo()->width % 8 ){
-        GUI_Error_HIG(QT_TR_NOOP("Width is not a multiple of 8"),
-                      QT_TR_NOOP("This will make trouble for AVI files."));
-      }
-      if (getPreviewMode()!=ADM_PREVIEW_NONE)
-      {
-         admPreview::start();
-         admPreview::update (curframe);
-      }
-      break;
+	case ACT_VideoParameter:
+		if (videoProcessMode())
+		{
+			// first remove current viewer
+			if (getPreviewMode() != ADM_PREVIEW_NONE)
+			{
+				admPreview::stop();
+			}
 
+			GUI_handleVFilter();
+
+			if (getLastVideoFilter()->getInfo()->width % 8)
+			{
+				GUI_Error_HIG(QT_TR_NOOP("Width is not a multiple of 8"),
+					QT_TR_NOOP("This will make trouble for AVI files."));
+			}
+
+			if (getPreviewMode() != ADM_PREVIEW_NONE)
+			{
+				admPreview::start();
+				admPreview::update (curframe);
+			}
+		}
+		else
+		{
+			GUI_Error_HIG(QT_TR_NOOP("Video filters cannot be applied in Copy mode"), QT_TR_NOOP("To apply filters the video must be transcoded."));
+		}
+
+		break;
     case ACT_RebuildKF:
       if (GUI_Question (QT_TR_NOOP("Rebuild all Keyframes?")))
 	{
@@ -853,7 +887,7 @@ int nw;
    case ACT_HEX_DUMP:
       GUI_showCurrentFrameHex();
       break;
-
+      
     default:
       printf ("\n unhandled action %d\n", action);
       ADM_assert (0);
@@ -882,7 +916,7 @@ A_openAvi (const char *name)
 extern void GUI_PreviewEnd (void);
 int A_openAvi2 (const char *name, uint8_t mode)
 {
-	char *path = fixupPath(name);
+	char *path = ADM_fixupPath(name);
   uint8_t res;
   char *longname;
   uint32_t magic[4];
@@ -918,12 +952,12 @@ int A_openAvi2 (const char *name, uint8_t mode)
 
 
   GUI_close(); // Cleanup
-
+  
   DIA_StartBusy ();
   /*
   ** we may get a relative path by cmdline
   */
-  longname = PathCanonize(path);
+  longname = ADM_PathCanonize(name);
   delete [] path;
 
   if (mode)
@@ -943,11 +977,11 @@ int A_openAvi2 (const char *name, uint8_t mode)
   if (res!=ADM_OK)			// an error occured
     {
 		delete[] longname;
-    	if(ADM_IGN==res)
+    	if(ADM_IGN==res) 
 	{
 		return 0;
 	}
-
+	
 	if( fourCC::check(id,(uint8_t *)"//AD") ){
           GUI_Error_HIG(QT_TR_NOOP("Cannot open project using the video loader."),
                         QT_TR_NOOP(  "Try 'File' -> 'Load/Run Project...'"));
@@ -995,7 +1029,7 @@ int A_openAvi2 (const char *name, uint8_t mode)
             setCurrentMixerFromString("NONE");
         }
 	for(i=strlen(longname);i>=0;i--)
-#ifdef ADM_WIN32
+#ifdef __WIN32
 		if( longname[i] == '\\' || longname[i] == '/' ){
 #else
 		if( longname[i] == '/' ){
@@ -1048,7 +1082,7 @@ void  updateLoaded ()
 
   // Init renderer
     admPreview::setMainDimension(avifileinfo->width, avifileinfo->height);
-  curframe = 0;
+  curframe = 0;  
 
   // Draw first frame
   rebuild_status_bar();
@@ -1057,7 +1091,7 @@ void  updateLoaded ()
   UI_setMarkers (frameStart, frameEnd);
 
   getFirstVideoFilter(); // Rebuild filter if needed
-
+  
   /* Zoom out if needed */
   uint32_t phyW,phyH;
   UI_getPhysicalScreenSize(NULL, &phyW,&phyH);
@@ -1077,12 +1111,12 @@ void  updateLoaded ()
       currentZoom=ZOOM_1_1;
       changePreviewZoom(currentZoom);
   }
-
-
-
+        
+  
+  
       admPreview::update (curframe);
       update_status_bar();
-
+   
    printf("\n** conf updated **\n");
 }
 
@@ -1092,7 +1126,7 @@ void  updateLoaded ()
 int
 A_appendAvi (const char *name)
 {
-	char *path = fixupPath(name);
+	char *path = ADM_fixupPath(name);
 
   if (playing)
     return 0;
@@ -1179,18 +1213,18 @@ A_saveAudio (char *name)
       return;
     }
 
-
+  
   out = fopen (name, "wb");
   if (!out) return;
-
+  
   work=new DIA_working(QT_TR_NOOP("Saving audio"));
-
+  
   uint32_t timeEnd,timeStart,sample,hold,len;
   uint64_t tgt_sample,cur_sample;
   double   duration;
 
   // compute start position and duration in samples
-
+    
    timeStart=video_body->getTime (frameStart);
    timeEnd=video_body->getTime (frameEnd+1);
 
@@ -1198,12 +1232,12 @@ A_saveAudio (char *name)
    duration=timeEnd-timeStart;
    printf("Duration:%f ms\n",duration);
    if(duration<0) duration=-duration;
-
-   duration/=1000;
+  
+   duration/=1000;   
    duration*=currentaudiostream->getInfo()->frequency;
-
-   tgt_sample=(uint64_t)floor(duration);
-
+   
+   tgt_sample=(uint64_t)floor(duration);  
+   
    cur_sample=0;
    written = 0;
    hold=0;
@@ -1217,19 +1251,19 @@ A_saveAudio (char *name)
 	if(hold>ONE_STRIKE)
 	{
 		fwrite(buffer,hold,1,out);
-		hold=0;
+		hold=0;		
 	}
 	if(cur_sample>tgt_sample)
-		break;
+		break;   
       work->update(cur_sample>>10, tgt_sample>>10);
       if(!work->isAlive()) break;
     };
   if(hold)
   {
   	fwrite(buffer,hold,1,out);
-	hold=0;
+	hold=0;  
   }
-
+  
   fclose (out);
   delete work;
   delete[] buffer;
@@ -1261,7 +1295,7 @@ int A_saveJpg (char *name)
     if(!GUI_getFrameContent(&image, curframe))
     {
       GUI_Error_HIG(QT_TR_NOOP("Get Frame"),QT_TR_NOOP("Cannot get this frame to save"));
-      return 0;
+      return 0; 
     }
     return (int) image.saveAsJpg (name);
 }
@@ -1277,7 +1311,7 @@ static int b=1;
          video_body->changeAudioStream(0,b);
         b^=1;
         return 1;
-
+ 	
 }
 #endif
 
@@ -1295,22 +1329,22 @@ void A_saveBunchJpg(const char *name)
   char *baseName;
   DIA_working *working;
   uint8_t success=0;
-
+  
         if(frameStart>frameEnd)
                 {
                   GUI_Error_HIG(QT_TR_NOOP("Mark A > B"), QT_TR_NOOP("Set your markers correctly."));
                         return;
                 }
         // Split name into base + extension
-        PathSplit(name,&baseName,&ext);
-
+        ADM_PathSplit(name,&baseName,&ext);
+        
         src=new ADMImage(avifileinfo->width,avifileinfo->height);
         ADM_assert(src);
 
         working=new DIA_working(QT_TR_NOOP("Saving as set of jpegs"));
         for(curImg=frameStart;curImg<=frameEnd;curImg++)
-        {
-                working->update(curImg-frameStart,frameEnd-frameStart);
+        {	
+                working->update(curImg-frameStart,frameEnd-frameStart);	
                 if (!GUI_getFrameContent (src,curImg ))
                 {
                   GUI_Error_HIG(QT_TR_NOOP("Cannot decode frame"), QT_TR_NOOP("Aborting."));
@@ -1321,7 +1355,7 @@ void A_saveBunchJpg(const char *name)
                 if(!src->saveAsJpg(fullName)) goto _bunch_abort;
         }
         success=1;
-
+        
 _bunch_abort:
         if(success)
             GUI_Info_HIG(ADM_LOG_INFO,QT_TR_NOOP("Done"),QT_TR_NOOP( "Saved %d images."), curImg-frameStart);
@@ -1339,13 +1373,13 @@ _bunch_abort:
 */
 void A_saveImg (const char *name)
 {
-
+  
   ADMImage image(avifileinfo->width,avifileinfo->height);
   GUI_getFrameContent(&image, curframe);
   if(image.saveAsBmp(name))
-        GUI_Info_HIG (ADM_LOG_INFO,QT_TR_NOOP("Done"),QT_TR_NOOP( "Saved \"%s\"."), GetFileName(name));
+        GUI_Info_HIG (ADM_LOG_INFO,QT_TR_NOOP("Done"),QT_TR_NOOP( "Saved \"%s\"."), ADM_GetFileName(name));
   else
-        GUI_Error_HIG (QT_TR_NOOP("BMP op failed"),QT_TR_NOOP( "Saving %s as a BMP file failed."), GetFileName(name));
+        GUI_Error_HIG (QT_TR_NOOP("BMP op failed"),QT_TR_NOOP( "Saving %s as a BMP file failed."), ADM_GetFileName(name));
 }
 
 //_____________________________________________________________
@@ -1357,7 +1391,7 @@ void A_saveImg (const char *name)
 int
 A_loadAC3 (char *name)
 {
-	char *path = fixupPath(name);
+	char *path = ADM_fixupPath(name);
 
   if (!avifileinfo)
     return 0;
@@ -1368,7 +1402,7 @@ A_loadAC3 (char *name)
   if (ac3->open (path) == 0)
     {
       GUI_Error_HIG (QT_TR_NOOP("Failed to open the file"), QT_TR_NOOP("Not a WAV file?"));
-      printf (QT_TR_NOOP("WAV open file failed..."));
+      printf ("%s", QT_TR_NOOP("WAV open file failed..."));
       delete ac3;
 	  delete [] path;
       return 0;
@@ -1392,7 +1426,7 @@ int A_loadNone( void )
 //_____________________________________________________________
 int A_loadMP3(char *name)
 {
-	char *path = fixupPath(name);
+	char *path = ADM_fixupPath(name);
 
     if (!avifileinfo)
         return 0;
@@ -1415,14 +1449,14 @@ int A_loadMP3(char *name)
 //_____________________________________________________________
 //
 //              Load wave
-//
+//              
 //
 //_____________________________________________________________
 
 int
 A_loadWave (char *name)
 {
-	char *path = fixupPath(name);
+	char *path = ADM_fixupPath(name);
 
   if (!avifileinfo)
   {
@@ -1492,9 +1526,9 @@ A_saveAudioDecodedTest (char *name)
   uint32_t written = 0;
   FILE *out;
   AVDMGenericAudioStream *saveFilter;
-
+  
   uint64_t sampleTarget,sampleCurrent;
-
+  
 #undef BITT
 #define BITT 4*1152
 #define OUTCHUNK 1024*1024
@@ -1550,7 +1584,7 @@ A_saveAudioDecodedTest (char *name)
 			ADM_dealloc(outbuffer);
 			return;
 		}
-
+   
     	DIA_working *work=new DIA_working(QT_TR_NOOP("Saving audio"));
 
 
@@ -1565,11 +1599,11 @@ A_saveAudioDecodedTest (char *name)
   duration=(tend-tstart);
   duration*=saveFilter->getInfo()->frequency;
   duration/=1000.;
-
+  
   sampleTarget=(uint64_t)floor(duration);
   sampleCurrent=0;
   gauge=0;
-
+  
   if( frameStart == frameEnd ){
      /* JSC: we will write some bytes, but nobody should expect useful data */
     GUI_Error_HIG(QT_TR_NOOP("No frames to encode"),QT_TR_NOOP("Please check markers. Is \"A>\" == \">B\"?"));
@@ -1585,23 +1619,23 @@ A_saveAudioDecodedTest (char *name)
       //      printf("Got : %lu\n",len2);
       gauge += len;
       sampleCurrent+=samples;
-      // update GUI
+      // update GUI                   
 	// JSC: if "A>" == ">B" we will get >100% here => assert in work->update()
 	if (work->update ((sampleCurrent>>10 > sampleTarget>>10 ? sampleTarget>>10 : sampleCurrent>>10), sampleTarget>>10))	// abort request ?
 	    break;;
-      if (gauge > OUTCHUNK)	// either out buffer is full
+      if (gauge > OUTCHUNK)	// either out buffer is full	
 	{
-	  fwrite (outbuffer, 1, gauge, out);
+	  fwrite (outbuffer, 1, gauge, out);	  
 	  written += gauge;
 	  gauge = 0;
-	}
+	}   	
     };
 // Clean up
 	if(gauge)
 	{
-		fwrite (outbuffer,  gauge,1, out);
+		fwrite (outbuffer,  gauge,1, out);	  
 		written += gauge;
-		gauge = 0;
+		gauge = 0;	
 	}
   saveFilter->endWrite (out, written);
   fclose (out);
@@ -1735,7 +1769,7 @@ uint8_t ADM_saveRaw (const char *name)
                 }
                 ADM_assert (video_body->getFlags (i, &flags));
         }
-
+      
       if (flags & AVI_B_FRAME)	// oops
 	{
 	  // se search for the next i /p
@@ -1802,7 +1836,7 @@ A_saveWorkbench (const char *name)
 
 void A_parseECMAScript(const char *name){
   bool ret;
-  char *longname = PathCanonize(name);
+  char *longname = ADM_PathCanonize(name);
    if (playing){
       GUI_PlayAvi();
       curframe = 0;
@@ -1920,7 +1954,7 @@ uint32_t count;
       aviInfo info;
       ADM_assert (video_body->getVideoInfo (&info));
       count = end - start;
-
+     
       if( end < start ){
         GUI_Error_HIG(QT_TR_NOOP("Marker A > B"), QT_TR_NOOP("Cannot delete the selection."));
          return 0;
@@ -1943,7 +1977,7 @@ uint32_t count;
 	{
           GUI_Error_HIG (QT_TR_NOOP("Something bad happened (II)"), NULL);
 	}
-
+      
 
 
       frameEnd=avifileinfo->nb_frames-1;
@@ -1952,7 +1986,7 @@ uint32_t count;
       UI_setMarkers (frameStart, frameEnd);
       ReSync ();
      return 1;
-
+      
 
 
 }
@@ -1968,7 +2002,7 @@ uint32_t frame;
                 return 0;
         }
         return GUI_GoToFrame(frame);
-
+        
 }
 
 //
@@ -1976,7 +2010,7 @@ void	A_setPostproc( void )
 {
 uint32_t type,strength,swap;
 	if(!avifileinfo) return;
-
+	
 	video_body->getPostProc(&type,&strength,&swap);
 
  	if(DIA_getMPParams( &type, &strength,&swap))
@@ -1995,8 +2029,8 @@ void A_audioTrack( void )
 {
         uint32_t nb;
         audioInfo *infos=NULL;
-
-        uint32_t old,nw;
+        
+        uint32_t old,nw;        
         uint8_t r=0;
         uint32_t oldtrack,newtrack;
         char *newtrackname=ADM_strdup(currentAudioName);
@@ -2008,7 +2042,7 @@ void A_audioTrack( void )
         }
         newtrack=oldtrack=(uint32_t)video_body->getCurrentAudioStreamNumber(0);
         nw=old=currentAudioSource;
-
+        
         /* Build dialog factory widget */
         diaMenuEntry sourcesStream[]={
             {AudioAvi,QT_TR_NOOP("Video"),QT_TR_NOOP("Take audio from video file")},
@@ -2017,14 +2051,14 @@ void A_audioTrack( void )
             {AudioMP3,QT_TR_NOOP("External MP3"),QT_TR_NOOP("Take audio from external MP3 file")},
             {AudioWav,QT_TR_NOOP("External WAV"),QT_TR_NOOP("Take audio from external WAV file")}
         };
-
-
+        
+        
         diaElemMenu   sourceMenu(&nw,QT_TR_NOOP("_Audio source:"),5,sourcesStream,NULL);
-
-
-
+        
+        
+        
         diaElemFile  sourceName(0,&newtrackname,QT_TR_NOOP("_External file:"), NULL, QT_TR_NOOP("Select file"));
-
+        
         // Now build the list of embedded track
 #define MAX_AUDIO_TRACK 10
 #define MAX_AUDIO_TRACK_NAME 100
@@ -2037,24 +2071,24 @@ void A_audioTrack( void )
            sourceavitracks[i]=new diaMenuEntryDynamic(i,string,NULL);
         }
          if(infos) delete [] infos;
-
+         
          diaElemMenuDynamic   sourceFromVideo(&newtrack,QT_TR_NOOP("_Track from video:"),nb,sourceavitracks);
          diaElem *allWidgets[]={&sourceMenu,&sourceFromVideo,&sourceName};
-
+         
          /* Link..*/
          sourceMenu.link(&(sourcesStream[0]),1,&sourceFromVideo);
          sourceMenu.link(&(sourcesStream[2]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[3]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[4]),1,&sourceName);
-
-
+         
+         
          if( diaFactoryRun(QT_TR_NOOP("Main Audio Track"),3,allWidgets))
          {
            if(nw!=AudioNone && nw!=AudioAvi)
            {
               if( !ADM_fileExist(newtrackname))
               {
-                GUI_Info_HIG(ADM_LOG_INFO,QT_TR_NOOP("Cannot load"),QT_TR_NOOP("The selected audio file does not exist."));
+                GUI_Info_HIG(ADM_LOG_INFO,QT_TR_NOOP("Cannot load"),QT_TR_NOOP("The selected audio file does not exist.")); 
                 goto roger_and_out;
               }
            }
@@ -2093,7 +2127,7 @@ void A_audioTrack( void )
                             ADM_assert(0);
         }
          }
-roger_and_out:
+roger_and_out:         
          /* Clean up */
          for(int i=0;i<nb;i++)
             delete sourceavitracks[i];
@@ -2116,7 +2150,7 @@ void A_externalAudioTrack( void )
             {AudioMP3,QT_TR_NOOP("External MP3"),QT_TR_NOOP("Take audio from external MP3 file")},
             {AudioWav,QT_TR_NOOP("External WAV"),QT_TR_NOOP("Take audio from external WAV file")}
         };
-
+        
         old=nw=secondAudioSource;
 
         diaElemMenu     sourceMenu(&nw,QT_TR_NOOP("_Audio source:"),4,sourcesStream,NULL);
@@ -2124,7 +2158,7 @@ void A_externalAudioTrack( void )
         diaElem *allWidgets[]={&sourceMenu,&sourceName};
 
   /* Link..*/
-
+        
          sourceMenu.link(&(sourcesStream[2]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[3]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[1]),1,&sourceName);
@@ -2162,11 +2196,11 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
                         {
                                 delete tmp;
                                 GUI_Error_HIG(QT_TR_NOOP("Error loading the MP3 file"), NULL);
-
+                                
                         }
                         else
                         {
-                                secondaudiostream = tmp;
+                                secondaudiostream = tmp;     
                                 secondAudioSource=AudioMP3;
                                 secondAudioName=ADM_strdup(name);
                                 printf ("\n MP3 loaded\n");
@@ -2188,7 +2222,7 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
                         }
                         else
                         {
-                                secondaudiostream = tmp;
+                                secondaudiostream = tmp;     
                                 secondAudioSource=AudioAC3;
                                 secondAudioName=ADM_strdup(name);
                                 printf ("\n AC3 loaded\n");
@@ -2210,7 +2244,7 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
                         }
                         else
                         {
-                                secondaudiostream = tmp;
+                                secondaudiostream = tmp;     
                                 secondAudioSource=AudioAC3;
                                 secondAudioName=ADM_strdup(name);
                                 printf ("\n AC3 loaded\n");
@@ -2223,7 +2257,7 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
         }
         return 0;
 }
-
+             
 
 //****************
 uint8_t A_TimeShift(void)
@@ -2249,7 +2283,7 @@ void A_Resync(void)
 // Just in case update file info
         if(!avifileinfo) return;
         rebuild_status_bar();
-
+        
         if(curframe>avifileinfo->nb_frames) curframe=frameEnd;
         UI_setMarkers (frameStart, frameEnd);
         GUI_GoToFrame(curframe);
@@ -2265,7 +2299,7 @@ void A_addJob(void)
 
         base=ADM_getJobDir();
         fullname=new char[strlen(name)+strlen(base)+2+4];
-
+        
         strcpy(fullname,base);
         strcat(fullname,"/");
         strcat(fullname,name);
@@ -2285,11 +2319,11 @@ int A_SaveWrapper(char *name)
 
         if(A_Save(name))
         {
-          GUI_Info_HIG (ADM_LOG_INFO,QT_TR_NOOP("Done"),QT_TR_NOOP( "File %s has been successfully saved."),GetFileName(name));
+          GUI_Info_HIG (ADM_LOG_INFO,QT_TR_NOOP("Done"),QT_TR_NOOP( "File %s has been successfully saved."),ADM_GetFileName(name));
         }
         else
         {
-          GUI_Error_HIG (QT_TR_NOOP("Failed"), QT_TR_NOOP("File %s was NOT saved correctly."),GetFileName(name));
+          GUI_Error_HIG (QT_TR_NOOP("Failed"), QT_TR_NOOP("File %s was NOT saved correctly."),ADM_GetFileName(name));
         }
         return 1;
 }
@@ -2323,7 +2357,7 @@ uint32_t GUI_GetScale(void)
 
     percent = UI_readScale();
     tg= (avifileinfo->nb_frames-1) * percent / 100.;
-
+    
     return (uint32_t)floor(tg);;
 
 
@@ -2342,20 +2376,20 @@ void  update_status_bar(void)
 
     //    if(!guiReady) return ;
     text[0] = 0;
-
+ 
 	UI_updateFrameCount( curframe);
 	UI_updateTimeCount( curframe,avifileinfo->fps1000);
-
+       
     // progress bar
     len = 100;
     if(avifileinfo->nb_frames>1)
     	len=len / (double) (avifileinfo->nb_frames-1);
     len *= (double) curframe;
 
-
+   
 
      UI_setScale(len);
-
+   	
 }
 
 ///
@@ -2369,10 +2403,10 @@ void rebuild_status_bar(void)
 
     //    if(!guiReady) return ;
     text[0] = 0;
-
+ 
 	UI_setFrameCount( curframe, avifileinfo->nb_frames);
 	UI_setTimeCount( curframe, avifileinfo->nb_frames,avifileinfo->fps1000);
-
+	
     // progress bar
     len = 100;
     if(avifileinfo->nb_frames>1)
@@ -2392,7 +2426,7 @@ uint8_t GUI_getFrameContent(ADMImage *image, uint32_t frame)
 {
   uint32_t flags;
   if(!video_body->getUncompressedFrame(frame,image,&flags)) return 0;
-  return 1;
+  return 1; 
 }
 /**
     \fn GUI_close
@@ -2474,26 +2508,200 @@ void GUI_showCurrentFrameHex(void)
  uint32_t fullLen,flags;
  char sType[5];
  char sSize[15];
-
+ 
  if (!avifileinfo) return;
-
+ 
  buffer=new uint8_t [avifileinfo->width*avifileinfo->height*3];
- video_body->getRaw (curframe, buffer, &fullLen);
+ video_body->getRaw (curframe, buffer, &fullLen);  
  video_body->getFlags (curframe, &flags);
-
+ 
  diaElemHex binhex("*****",fullLen,buffer);
-
+      
  if(flags==AVI_KEY_FRAME) sprintf(sType,"I");
   else if(flags==AVI_B_FRAME) sprintf(sType,"B");
     else sprintf(sType,"P");
  sprintf(sSize,"%d bytes",fullLen);
-
+ 
  diaElemReadOnlyText Type(sType,QT_TR_NOOP("Frame type:"));
  diaElemReadOnlyText Size(sSize,QT_TR_NOOP("Frame size:"));
  diaElem *elems[]={&Type,&Size,&binhex   };
  if(diaFactoryRun(QT_TR_NOOP("Frame Hex Dump"),3,elems))
-
+ 
  delete [] buffer;
 }
+// Temporary place...
 
+/**
+    \fn saveAsBmp
+    \brief save current image into filename, into bmp format
+*/
+uint8_t  ADMImage::saveAsBmp(const char *filename)
+{
+  ADM_BITMAPFILEHEADER bmfh;
+  ADM_BITMAPINFOHEADER bmph;
+  FILE *fd;
+  uint32_t sz;
+  uint16_t s16;
+  uint32_t s32;
+  
+  sz = _width* _height * 3;
+
+  bmfh.bfReserved1 = bmfh.bfReserved2 = 0;
+  bmfh.bfOffBits = sizeof (bmfh) + sizeof (bmph);
+//_________________________________________
+  bmph.biSize = sizeof (bmph);
+  bmph.biWidth = _width;
+  bmph.biHeight = _height;
+  bmph.biPlanes = 1;
+  bmph.biBitCount = 24;
+  bmph.biCompression = 0;	// COMPRESSION NONE
+  bmph.biSizeImage = sz;
+  bmph.biXPelsPerMeter = 0;
+  bmph.biYPelsPerMeter = 0;
+  bmph.biClrUsed = 0;
+  bmph.biClrImportant = 0;
+/*
+	bmph.resolutionUnits=0;
+	bmph.origin=0;
+	bmph.colorEncoding=0;
+*/
+
+  ADMImage image(_width,_height);
+  
+
+  printf ("\n %u x %u=%u\n", bmph.biWidth, bmph.biHeight, sz);
+
+  uint8_t *out;
+
+        out=(uint8_t *)ADM_alloc(sz);
+        if(!out)
+        {
+            GUI_Error_HIG(QT_TR_NOOP("Memory error"), NULL);
+//            ADM_dealloc(out);
+            return 0;
+        }
+
+        if(!COL_yv12rgbBMP(bmph.biWidth, bmph.biHeight,data, out))
+        {
+              GUI_Error_HIG(QT_TR_NOOP("Error converting to BMP"), NULL);
+              ADM_dealloc(out);
+              return 0;
+        }
+        fd = fopen (filename, "wb");
+        if (!fd)
+        {
+                GUI_Error_HIG (QT_TR_NOOP("Something bad happened"), NULL);
+                ADM_dealloc(out);
+                return 0;
+        }
+
+	// Bitmpap file header, not using tructure due to gcc padding it
+#ifdef ADM_BIG_ENDIAN
+	s16 = 0x424D;
+#else	
+  	s16 = 0x4D42;
+#endif	
+  	s32 = 14 + sizeof (bmph) + sz;
+#ifdef ADM_BIG_ENDIAN	
+	#define SWAP32(x) x=R32(x)	
+#else
+	#define SWAP32(x) ; 
+#endif
+        SWAP32(s32);	
+        fwrite (&s16, 2, 1, fd);
+        fwrite (&s32, 4, 1, fd);
+        s32 = 0;
+        fwrite (&s32, 4, 1, fd);
+        s32 = 14 + sizeof (bmph);
+        SWAP32(s32);
+        fwrite (&s32, 4, 1, fd);
+#ifdef ADM_BIG_ENDIAN
+	Endian_BitMapInfo(&bmph);
+#endif
+        fwrite (&bmph, sizeof (bmph), 1, fd);
+        fwrite (out, sz, 1, fd);
+  
+        fclose(fd);
+        ADM_dealloc(out);
+        return 1;
+}
+/**
+    \fn saveAsJpg
+    \brief save current image into filename, into jpg format
+*/
+uint8_t  ADMImage::saveAsJpg(const char *filename)
+{
+ ffmpegEncoderFFMjpeg *codec=NULL;
+  FILE *fd;
+  uint8_t *buffer=NULL;
+  uint32_t sz;
+  
+
+        sz = _width*_height*3;
+        ADMBitstream bitstream(sz);
+        buffer=new uint8_t[sz];
+        bitstream.data=buffer;
+        codec=new  ffmpegEncoderFFMjpeg(_width,_height,FF_MJPEG)  ;
+        codec->init( 95,25000);
+        if(!codec->encode(this,&bitstream))
+        {
+                GUI_Error_HIG(QT_TR_NOOP("Cannot encode the frame"), NULL);
+                delete [] buffer;
+                delete codec;
+                return 0;
+        }
+        delete codec;
+        fd=fopen(filename,"wb");
+        if(!fd)
+        {
+                GUI_Error_HIG(QT_TR_NOOP("File error"),QT_TR_NOOP( "Cannot open \"%s\" for writing."), filename);
+                delete [] buffer;
+                return 0;
+        }
+        fwrite (buffer, bitstream.len, 1, fd);
+        fclose(fd);
+        delete [] buffer;
+        return 1;
+}
+/**
+ *      \fn UI_getPreferredRender
+ *      \brief Returns to render lib the user preferred rendering method
+ * 
+ */
+ADM_RENDER_TYPE UI_getPreferredRender(void)
+{
+  char *displ;
+  unsigned int renderI;
+  ADM_RENDER_TYPE render;
+
+#if !defined __WIN32 && !defined(__APPLE__)
+        // First check if local
+        // We do it in a very wrong way : If DISPLAY!=:0.0 we assume remote display
+        // in that case we do not even try to use accel
+        
+        // Win32 and Mac/Qt4 don't have DISPLAY
+        displ=getenv("DISPLAY");
+        if(!displ)
+        {
+                return RENDER_GTK;
+        }
+        if(strcmp(displ,":0") && strcmp(displ,":0.0"))
+        {
+                printf("Looks like remote display, no Xv :%s\n",displ);
+                return RENDER_GTK;
+        }
+#endif  
+ 
+        if(prefs->get(DEVICE_VIDEODEVICE,&renderI)!=RC_OK)
+        {       
+                render=RENDER_GTK;
+        }else
+        {
+                render=(ADM_RENDER_TYPE)renderI;
+        }
+
+        return render;
+}
+
+//
 // EOF
