@@ -20,14 +20,11 @@
 
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
 
-
 #include "avi_vars.h"
-#include "GUI_ui.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
+#include "DIA_coreToolkit.h"
 #include "ADM_assert.h"
 
 #include "ADM_audiodevice/audio_out.h"
@@ -36,7 +33,6 @@
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "gui_action.hxx"
 
-
 #include "ADM_encoder/adm_encConfig.h"
 #include "ADM_filter/vidVCD.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
@@ -58,10 +54,6 @@ uint8_t A_autoDrive(Action action)
         switch(action)
         {
                 case ACT_AUTO_IPOD:
-#if !defined(USE_XVID_4) || !defined(USE_FAAC)
-					GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
-						QT_TR_NOOP( "Xvid4 and FAAC support is required for the iPod profile."));
-#else
 					if(!setIPOD())
 						return 0;
 
@@ -72,21 +64,27 @@ uint8_t A_autoDrive(Action action)
 						GUI_Error_HIG(QT_TR_NOOP("Codec Error"),QT_TR_NOOP( "Cannot select the MPEG-4 SP codec."));
 						return 0;
 					}
-					setIpod_Xvid4Preset();
+                    GUI_Info_HIG(ADM_LOG_INFO,"CODE DISABLED","XVID4 PROFILE FOR IPOD");
+					//setIpod_Xvid4Preset();
 					// Set mode & bitrate
 					setVideoEncoderSettings(COMPRESS_CBR,400,0,NULL);
 					// Audio Codec
 					if((currentaudiostream->getInfo()->channels == 2)&& currentaudiostream->getInfo()->encoding == WAV_AAC)
-						audioCodecSetcodec(AUDIOENC_COPY);
+						audio_setCopyCodec();
 					else
 					{
-						audioCodecSetcodec(AUDIOENC_FAAC);
-						audioFilter_SetBitrate(128);
+						if(audio_selectCodecByTag(WAV_AAC))
+                        {
+                            GUI_Error_HIG(QT_TR_NOOP("Codec Error"),QT_TR_NOOP( "No AAC audio encoder plugin found."));
+                        }else
+                        {
+                            audioFilter_SetBitrate(128);
 
-						if (currentaudiostream->getInfo()->channels != 2)
-							setCurrentMixerFromString("STEREO");
+                            if (currentaudiostream->getInfo()->channels != 2)
+                                setCurrentMixerFromString("STEREO");
+                        }
 					}
-#endif
+
                       break;
 //******************************** IPOD *******************************
                           
@@ -99,20 +97,24 @@ uint8_t A_autoDrive(Action action)
         				fq=currentaudiostream->getInfo()->frequency;
         				if(currentaudiostream->getInfo()->encoding==WAV_MP3 && (fq==44100 || fq==22050 || fq==11025))
         						{
-        	                		audioCodecSetcodec(AUDIOENC_COPY);
+        	                		audio_setCopyCodec();
         						}
         				else
         				{
-#ifdef HAVE_LIBMP3LAME
-        					audioCodecSetcodec(AUDIOENC_MP3);
-        					audioFilter_SetBitrate(128);
-                                                audioFilter_MP3DisableReservoir(1);
-        					// set fq
-        					
-#else
+                            if(audio_selectCodecByTag(WAV_MP3))
+                            {
+                                    audioFilter_SetBitrate(128);
+                                    if(!audioSetOption("MP3DisableReservoir",1))
+                                    {
+        					 GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
+        					        QT_TR_NOOP( "The MP3 codec does not allow disabling reservoir.\nInstall lame plugin"));
+
+                                    }
+        					}else
+        					{
         					 GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
         					        QT_TR_NOOP( "You don't have LAME!.\nIt is needed to create FLV  video."));
-#endif
+                             }
         					 if(fq==44100 || fq==22050 || fq==11025)
         					         						{}
         					 else
@@ -146,11 +148,7 @@ uint8_t A_autoDrive(Action action)
                     {
                     case ACT_AUTO_PSP:
                           {
-#ifdef USE_XVID_4
-                            if(!videoCodecSelectByName("XVID4")) 
-#else
                             if(!videoCodecSelectByName("FFMpeg4"))            
-#endif
                             {
                               GUI_Error_HIG(QT_TR_NOOP("Codec Error"),QT_TR_NOOP( "Cannot select mpeg4 sp codec."));
                                 return 0;
@@ -162,11 +160,12 @@ uint8_t A_autoDrive(Action action)
                           break;
                     case ACT_AUTO_PSP_H264:
                     {
-#ifdef USE_X264
+						// FIXME
+/*#ifdef USE_X264
                           videoCodecSelectByName("X264"); 
                           setPSP_X264Preset(); 
                           setVideoEncoderSettings(COMPRESS_CBR,768,0,NULL);
-#endif
+#endif */
                           fq=48000;
                     }
                     break;
@@ -179,16 +178,15 @@ uint8_t A_autoDrive(Action action)
                         (currentaudiostream->getInfo()->channels==2)&&
                         (currentaudiostream->getInfo()->encoding==WAV_AAC))
                     {
-                        audioCodecSetcodec(AUDIOENC_COPY);
+                        audio_setCopyCodec();
                     }
                     else
                     {
-#ifdef USE_FAAC
-                          audioCodecSetcodec(AUDIOENC_FAAC);
-#else
-                          GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
+
+
+                          if(!audio_selectCodecByTag(WAV_AAC))
+                            GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
                                         QT_TR_NOOP( "You don't have FAAC!.\nIt is needed to create PSP compatible video."));
-#endif
                                     // ? Needed ?
                           if(currentaudiostream->getInfo()->frequency!=fq)
                           {
@@ -209,11 +207,11 @@ uint8_t A_autoDrive(Action action)
                                                 (currentaudiostream->getInfo()->encoding==WAV_MP2)&&
                                                         (currentaudiostream->getInfo()->byterate==28000))
                                 {
-                                        audioCodecSetcodec(AUDIOENC_COPY);
+                                        audio_setCopyCodec();
                                 }
                                 else
                                 {
-                                        audioCodecSetcodec(AUDIOENC_2LAME);
+                                        audio_selectCodecByTag(WAV_MP2);
                                         if(currentaudiostream->getInfo()->frequency!=44100)
                                         {
                                                 audioFilterResample(44100);
@@ -239,11 +237,11 @@ uint8_t A_autoDrive(Action action)
                                         (currentaudiostream->getInfo()->channels==2)&&
                                                 (currentaudiostream->getInfo()->encoding==WAV_MP2))
                                 {
-                                        audioCodecSetcodec(AUDIOENC_COPY);
+                                        audio_setCopyCodec();
                                 }
                                 else
                                 {
-                                        audioCodecSetcodec(AUDIOENC_2LAME);
+                                        audio_selectCodecByTag(WAV_MP2);
                                         if(currentaudiostream->getInfo()->frequency!=44100)
                                         {
                                                 audioFilterResample(44100);
@@ -272,7 +270,7 @@ uint8_t A_autoDrive(Action action)
                                         || (currentaudiostream->getInfo()->encoding!=WAV_MP2 &&
                                          currentaudiostream->getInfo()->encoding!=WAV_AC3))
                                 {
-                                        audioCodecSetcodec(AUDIOENC_2LAME);
+                                        audio_selectCodecByTag(WAV_MP2);
                                         audioFilterResample(48000);
                                         audioFilter_SetBitrate(160);
                                         if(currentaudiostream->getInfo()->channels!=2)
@@ -285,7 +283,7 @@ uint8_t A_autoDrive(Action action)
                                 }
                                 else
                                 {
-                                        audioCodecSetcodec(AUDIOENC_COPY);
+                                        audio_setCopyCodec();
                                 }
                                 break;
 
