@@ -17,36 +17,24 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
-#include <stdio.h>
-#include <stdlib.h>
-
-#include "default.h"
-
-#ifdef ADM_WIN32
-#define WIN32_CLASH
+#ifdef __MINGW32__
 #include <windows.h>
-#include <wingdi.h>
 #include <excpt.h>
 #endif
 
+#include "config.h"
+#include "ADM_default.h"
+#include "ADM_threads.h"
+
 #define __DECLARE__
 #include "avi_vars.h"
 
 #include "ADM_encoder/adm_encConfig.h"
 #include "prefs.h"
 #include "ADM_audiodevice/audio_out.h"
-#include "ADM_toolkit/ADM_intfloat.h"
-#include "ADM_libraries/ADM_libwrapper/libwrapper_global.h"
-
-#ifdef USE_XVID_4
-extern void xvid4_init(void);
-#endif
-
-extern uint8_t filterDynLoad(const char *path);
 
 extern void  ADM_lavInit();
-extern void  ADM_lavDestroy();
+
 extern "C" {
      extern uint8_t     ADM_InitMemcpy(void);
 };
@@ -56,11 +44,9 @@ extern "C" {
 	#include "SDL.h"
 }
 
-#include "ADM_userInterfaces/ADM_commonUI/GUI_sdlRender.h"
+#include "ADM_userInterfaces/ADM_render/GUI_sdlRender.h"
 #endif
 
-#include "ADM_osSupport/ADM_cpuCap.h"
-#include "ADM_osSupport/ADM_threads.h"
 
 void onexit( void );
 //extern void automation(int argc, char **argv);
@@ -69,26 +55,32 @@ extern void registerVideoFilters( void );
 extern void filterCleanUp( void );
 extern void register_Encoders( void )  ;
 
-extern void  buildDistMatrix( void );
-extern void initScaleTab( void );
 extern uint8_t initGUI( void );
 extern void destroyGUI(void);
-extern void COL_init(void);
 extern uint8_t initFileSelector(void);
 extern void AUDMEncoder_initDither(void);
 extern void ADM_memStat( void );
 extern void ADM_memStatInit( void );
 extern void ADM_memStatEnd( void );
 extern void getUIDescription(char*);
-
-#ifdef ADM_WIN32
+extern uint8_t ADM_ad_loadPlugins(const char *path);
+extern uint8_t ADM_vf_loadPlugins(const char *path);
+extern uint8_t ADM_av_loadPlugins(const char *path);
+extern uint8_t ADM_ae_loadPlugins(const char *path);
+extern void loadPlugins(void);
+extern void InitFactory(void);
+extern void InitCoreToolkit(void);
+#ifdef __MINGW32__
 extern EXCEPTION_DISPOSITION exceptionHandler(struct _EXCEPTION_RECORD* pExceptionRec, void* pEstablisherFrame, struct _CONTEXT* pContextRecord, void* pDispatcherContext);
-extern bool getWindowsVersion(char* version);
-extern void redirectStdoutToFile(void);
 #else
 extern void installSigHandler(void);
 #endif
 
+#ifdef __WIN32
+extern bool getWindowsVersion(char* version);
+extern void redirectStdoutToFile(void);
+#endif
+
 extern uint8_t  quotaInit(void);
 extern void ADMImage_stat( void );
 extern uint8_t win32_netInit(void);
@@ -101,8 +93,6 @@ bool SpidermonkeyInit(void);
 void SpidermonkeyDestroy(void);
 
 extern pthread_mutex_t g_pSpiderMonkeyMutex;
-uint32_t CpuCaps::myCpuCaps=0;
-uint32_t CpuCaps::myCpuMask=0xffffffff;
 
 #if defined(ADM_DEBUG) && defined(FIND_LEAKS)
 extern const char* new_progname;
@@ -111,7 +101,7 @@ extern int check_leaks();
 
 int main(int argc, char *argv[])
 {
-#ifdef ADM_WIN32
+#if defined(__WIN32) && defined(USE_SDL)
 	redirectStdoutToFile();
 #endif
 
@@ -119,12 +109,12 @@ int main(int argc, char *argv[])
 	new_progname = argv[0];
 #endif
 
-#ifndef ADM_WIN32
+#ifndef __MINGW32__
 	// thx smurf uk :)
     installSigHandler();
 #endif
 
-    printf("***************************\n");
+    printf("*************************\n");
     printf("  Avidemux v" VERSION);
 
   	if(ADM_SUBVERSION)
@@ -132,7 +122,7 @@ int main(int argc, char *argv[])
 		printf(" (r%04u)", ADM_SUBVERSION);
 	}
 
-    printf("\n***************************\n");
+    printf("\n*************************\n");
     printf(" http://www.avidemux.org\n");
     printf(" Code      : Mean, JSC, Gruntster \n");
     printf(" GFX       : Nestor Di , nestordi@augcyl.org\n");
@@ -148,7 +138,7 @@ int main(int argc, char *argv[])
 
 	printf("Build Target: ");
 
-#if defined(ADM_WIN32)
+#if defined(__WIN32)
 	printf("Microsoft Windows");
 #elif defined(__APPLE__)
 	printf("Apple");
@@ -156,11 +146,11 @@ int main(int argc, char *argv[])
 	printf("Linux");
 #endif
 
-#if defined(ARCH_X86_32)
+#if defined(ADM_CPU_X86_32)
 	printf(" (x86)");
-#elif defined(ARCH_X86_64)
+#elif defined(ADM_CPU_X86_64)
 	printf(" (x86-64)");
-#elif defined(ARCH_POWERPC)
+#elif defined(ADM_CPU_PPC)
 	printf(" (PowerPC)");
 #endif
 
@@ -170,7 +160,7 @@ int main(int argc, char *argv[])
 	getUIDescription(uiDesc);
 	printf("User Interface: %s\n", uiDesc);
 
-#ifdef ADM_WIN32
+#ifdef __WIN32
 	char version[250];
 
 	if (getWindowsVersion(version))
@@ -181,88 +171,116 @@ int main(int argc, char *argv[])
 	printf("\nLarge file available: %d offset\n", __USE_FILE_OFFSET64);
 #endif
 
-   // Start counting memory
+	// Start counting memory
 	ADM_memStatInit();
-	ADM_intFloatInit();
     ADM_InitMemcpy();
 	printf("\nInitialising prefs\n");
 	initPrefs();
 	prefs->load();
     CpuCaps::init();
-    
+
 	register_Encoders();
 
 #ifdef USE_SDL
-	initSdl();
+	uint32_t videoDevice = RENDER_LAST;
+
+	prefs->get(DEVICE_VIDEODEVICE, &videoDevice);
+
+	initSdl(videoDevice);
 #endif
 
 	atexit(onexit);
 
-#ifdef ADM_WIN32
+#ifdef __MINGW32__
     win32_netInit();
 #endif
 
     UI_Init(argc,argv);
     AUDMEncoder_initDither();
 
-#ifdef USE_XVID_4
-    xvid4_init();
-#endif
-
+    // Hook our UI...
+    InitFactory();
+    InitCoreToolkit();
     initFileSelector();
 
 
 	// Load .avidemuxrc
     quotaInit();
 
-	if(!initGUI())
-	{
-		printf("\n Fatal : could not init GUI\n");
-		exit(-1);
-	}
-
     video_body = new ADM_Composer;
 
 #ifdef HAVE_ENCODER
      registerVideoFilters();
 #endif
 
-	// Try load load external filter
-	uint32_t loadpref=0;
-	char *dynloadPath=NULL;
+	//***************Plugins *********************
+	// Load system wide audio decoder plugin
+#ifdef _WIN32
+	const char *startDir="";
+	const char *pluginDir="plugins";
+#else
+	const char *pluginDir="ADM_plugins";
 
-	prefs->get(FILTERS_AUTOLOAD_ACTIVE,&loadpref);
-	prefs->get(FILTERS_AUTOLOAD_PATH,&dynloadPath);
+#ifdef __APPLE__
+    const char *startDir="../lib";
+#else
+    const char *startDir="lib";
+#endif
+#endif
 
-	if(loadpref && dynloadPath)
+	char *adPlugins = ADM_getInstallRelativePath(startDir,pluginDir,"audioDecoder");
+	char *vfPlugins = ADM_getInstallRelativePath(startDir,pluginDir,"videoFilter");
+    char *avPlugins = ADM_getInstallRelativePath(startDir,pluginDir,"audioDevices");
+    char *aePlugins = ADM_getInstallRelativePath(startDir,pluginDir,"audioEncoders");
+
+	ADM_ad_loadPlugins(adPlugins);
+	delete [] adPlugins;
+
+	ADM_vf_loadPlugins(vfPlugins);
+	delete [] vfPlugins;
+
+    ADM_av_loadPlugins(avPlugins);
+    delete [] avPlugins;
+
+    ADM_ae_loadPlugins(aePlugins);
+    delete [] aePlugins;
+
+	// load local audio decoder plugins
+	adPlugins=ADM_getHomeRelativePath("plugins","audioDecoder");
+	ADM_ad_loadPlugins(adPlugins);
+	delete [] adPlugins;
+
+	// load local video filter plugins
+	vfPlugins=ADM_getHomeRelativePath("plugins","videoFilter");
+	ADM_vf_loadPlugins(vfPlugins);
+	delete [] vfPlugins;
+	// load encoder plugins...
+	loadPlugins();
+	//***************Plugins *********************
+
+	if(!initGUI())
 	{
-		filterDynLoad(dynloadPath);
+		printf("\n Fatal : could not init GUI\n");
+		exit(-1);
 	}
-	ADM_dealloc(dynloadPath);
 
     ADM_lavInit();
 #ifdef HAVE_AUDIO
     AVDM_audioInit();
 #endif
 
-    buildDistMatrix();
-    initScaleTab();
-
-    COL_init();
-	initLibWrappers();
-	
     if(SpidermonkeyInit() == true)
         printf("Spidermonkey initialized.\n");
     else
 		ADM_assert(0); 
 
-#ifdef ADM_WIN32
+#ifdef __MINGW32__
 	__try1(exceptionHandler);
 #endif
 
     UI_RunApp();
 
-#ifdef ADM_WIN32
+#ifdef __MINGW32__
 	__except1(exceptionHandler);
 #endif
 
@@ -282,8 +300,6 @@ void onexit( void )
     pthread_mutex_unlock(&g_pSpiderMonkeyMutex);
     destroyPrefs();
     filterCleanUp();
-	destroyLibWrappers();
-	ADM_lavDestroy();
 
 #ifdef USE_SDL
 	quitSdl();
@@ -305,3 +321,8 @@ void onexit( void )
 	check_leaks();
 #endif
 }
+extern void checkCrashFile(void);
+void dummyXref(void)
+{
+    checkCrashFile();
+}
